/**************
 * GNOME Crap *
 *************/

ApDocView, /* Abiword */
EogScrollView, /* Eog */
CheeseThumbView /* Cheese */
{
    -EogScrollView-shadow-type: none;
}

CcNetworkPanel GtkNotebook > .frame {
    border: none;
}


/********
* Geary *
********/

ConversationListView {
    -GtkWidget-focus-line-width: 1px;
    -GtkTreeView-grid-line-width: 0;
}
 
ConversationListView.view.cell {
    border-style: solid;
    border-width: 0 0 1px 0;
    border-color: alpha (#000, 0.2);
}
 
ConversationListView.view.cell:selected:focus {
    border-style: solid;
    border-width: 0 0 1px 0;
    border-color: shade (@colorAccent, 0.8);
}

/* for overlay-scrollbars */
ComposerWidget {
    background-color: @bg_color;
}
