style "notify-window"
{
    bg[NORMAL] = "#4d4d4d" 
    XfceNotifyWindow::border-color = "#ffffff"
    XfceNotifyWindow::border-radius = 10.0
    XfceNotifyWindow::border-width = 0.0
}

style "notify-button"
{
    bg[NORMAL] = "#202020"
    bg[PRELIGHT] = "#404040"
    fg[NORMAL] = "#ffffff"
    fg[PRELIGHT] = "#ffffff"
}

style "notify-text"
{
    fg[NORMAL] = "#ffffff"
    GtkWidget::link-color = "#a7a7a7"
}

class "XfceNotifyWindow" style "notify-window"
widget_class "XfceNotifyWindow.*.GtkButton*" style "notify-button"
widget_class "XfceNotifyWindow.*.<GtkLabel>" style "notify-text"