.libreoffice-toolbar {
    background-image: none;
    border: none;
    box-shadow: none;
}
.libreoffice-toolbar button:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@focus_color, 1.5)),
                                     color-stop (0.5, shade (@focus_color, 1.33)),
                                     to (shade (@focus_color, 1.28)));
    border-image-source: url("assets/button-hover.png");
}
.libreoffice-toolbar button:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 1.5)),
                                     color-stop (0.5, shade (@selected_bg_color, 1.33)),
                                     to (shade (@selected_bg_color, 1.28)));
    border-image-source: url("assets/button-active-hover.png");
}
