style "nautilus-window-base"
{
	bg[NORMAL]	= @base_color
}

style "nautilus-sidebar" = "sidebar"
{
	GtkTreeView::horizontal_separator	= 15
	GtkTreeView::vertical_separator		= 2
}

style "nautilus-sidebar-other" = "nautilus-sidebar"
{
	xthickness				= 0
	bg[NORMAL]				= @sidebar_color
}

style "nautilus-view"
{
	xthickness		= 0
	ythickness		= 0
}

style "nautilus-handle"
{
	GtkPaned::handle-size         = 2
	
	engine "pixmap"
	{
		image # for the thin gray line separating the sidepane and viewpane
		{
		    function		= HANDLE
		    recolorable		= TRUE
		    file		= "/Sidebar/handle.png"
		    stretch		= TRUE
		    border 		= { 0, 0, 0, 0 }
		}
	}
}

style "nautilus-extra-view"
{

	xthickness		= 0
	ythickness		= 0

	bg_pixmap[NORMAL]	= "/nautilus/extra-widget.png"

}

style "nautilus-statusbar"
{
	xthickness	= 4

	bg[NORMAL]	= @base_color
	bg[PRELIGHT]	= shade (1.16, mix (0.1, @bg_color, @selected_bg_color))
	bg[SELECTED]	= @fg_color

	base[SELECTED]	= shade (0.8, @selected_bg_color)

	fg[NORMAL]	= mix (0.4, @base_color, @text_color)
	fg[PRELIGHT]	= mix (0.4, @base_color, @text_color)
	fg[SELECTED]	= mix (0.4, @base_color, @text_color)
	fg[ACTIVE]	= mix (0.4, @base_color, @text_color)
	fg[INSENSITIVE]	= mix (0.4, @base_color, @text_color)

	engine "pixmap" 
	{

	    image
	    {
	     	function	= RESIZE_GRIP
		recolorable	= TRUE
		detail		= "statusbar"
		overlay_file	= "/nautilus/resize_grip.png"
		overlay_border	= {0,0,0,0 }
		overlay_stretch	= FALSE
	    }
      }
}

style "nautilus-notebook" 
{
	xthickness		= 0
	ythickness		= 0
}

style "nautilus-scale"
{
	ythickness = 0

	GtkRange		::trough-border				= 0
	GtkScale		::trough-side-details			= 0
	
	engine "pixmap" 
	{
		image 
		{
			function		= BOX
			detail			= "trough"
			file			= "/Range/trough.png"
			border			= { 10, 10, 5, 15 }
		}	
		image 
		{
			function		= SLIDER
			overlay_file		= "/Range/slider.png"
			overlay_stretch		= FALSE
    }
  }
}


style "nautilus-mode-button"
{

	engine "pixmap"
	{	
		image
		{
			function        	= BOX
			recolorable     	= TRUE
			state				= PRELIGHT
			file				= "/nautilus/mode_prelight.png"
			border				= { 3, 13, 3, 3 }
			stretch         	= TRUE
		}
	  
		image
		{
			function        	= BOX
			recolorable     	= TRUE
			state				= NORMAL
			file				= "/nautilus/mode_normal.png"
			border				= { 3, 13, 3, 3 }
			stretch         	= TRUE
		}
	
		image
		{
			function        	= BOX
			recolorable     	= TRUE
			state				= ACTIVE
			file				= "/nautilus/mode_pressed.png"
			border				= { 3, 13, 3, 3 }
			stretch         	= TRUE
		}  

		image
		{
			function        	= BOX
			recolorable     	= TRUE
			state				= INSENSITIVE
			file				= "/nautilus/mode_normal.png"
			border				= { 3, 13, 3, 3 }
			stretch         	= TRUE
		} 

		image
		{
			function        	= BOX
			recolorable     	= TRUE
			state				= SELECTED
			file				= "/nautilus/mode_pressed.png"
			border				= { 3, 13, 3, 3 }
			stretch         	= TRUE
		}
	}

}

style "nautilus-right-slider"
{	
	xthickness = 0
	ythickness = 0
	
	engine "pixmap"
	{
		image {
			function 		= BOX
			file			= "/nautilus/right_slider_normal.png"
			border			= { 3, 3, 3, 3 }
			stretch			= TRUE
		}
	}
}

widget		"*NautilusNavigationWindow"	style "nautilus-window-base"
widget		"*Nautilus*Splitter"		style "nautilus-handle"
widget_class	"*Nautilus*View*"		style "nautilus-view"
widget_class	"*Nautilus*NautilusSidePane*"	style "nautilus-sidebar"
widget_class	"*Nautilus*Statusbar*"		style "nautilus-statusbar"
widget_class	"*Nautilus*Scale*"		style "nautilus-scale"

widget_class	"*Nautilus*Notebook"		style "nautilus-notebook"

widget		"*GtkModeButton*"		style "nautilus-mode-button"

widget "*.nautilus-extra-view-widget" 		style : highest "nautilus-extra-view"

widget_class "*NautilusPathBar.*ToggleButton*" style "nautilus-breadcrumbs" 
widget "Nautilus*left_slider*" style "nautilus-left-slider" 
widget "Nautilus*right_slider*" style "nautilus-right-slider"

