########################################################################
# Arrow
########################################################################

style "arrow" {
	# UP
	engine "pixmap" {
    image
    {
      function		= ARROW
      state		= NORMAL
      recolorable	= TRUE
      overlay_file	= "images/arrow-up-combo.png"
      overlay_border	= { 0, 0, 0, 0 }
      overlay_stretch	= FALSE
      arrow_direction	= UP
    }
    image
    {
      function		= ARROW
      state		= PRELIGHT
      recolorable	= TRUE
      overlay_file	= "images/arrow-up-combo.png"
      overlay_border	= { 0, 0, 0, 0 }
      overlay_stretch	= FALSE
      arrow_direction	= UP
    }
    image
    {
      function		= ARROW
      state		= ACTIVE
      recolorable	= TRUE
      overlay_file	= "images/arrow-up-active-combo.png"
      overlay_border	= { 0, 0, 0, 0 }
      overlay_stretch	= FALSE
      arrow_direction	= UP
    }
    image
    {
      function		= ARROW
      state		= INSENSITIVE
      recolorable	= TRUE
      overlay_file	= "images/arrow-up-ins-combo.png"
      overlay_border	= { 0, 0, 0, 0 }
      overlay_stretch	= FALSE
      arrow_direction	= UP
    }
	
	# DOWN
    image
    {
      function		= ARROW
      state		= NORMAL
      recolorable	= TRUE
      overlay_file	= "images/arrow-down-combo.png"
      overlay_border	= { 0, 0, 0, 0 }
      overlay_stretch	= FALSE
      arrow_direction	= DOWN
    }
    image
    {
      function		= ARROW
      state		= PRELIGHT
      recolorable	= TRUE
      overlay_file	= "images/arrow-down-combo.png"
      overlay_border	= { 0, 0, 0, 0 }
      overlay_stretch	= FALSE
      arrow_direction	= DOWN
    }
    image
    {
      function		= ARROW
      state		= ACTIVE
      recolorable	= TRUE
      overlay_file	= "images/arrow-down-active-combo.png"
      overlay_border	= { 0, 0, 0, 0 }
      overlay_stretch	= FALSE
      arrow_direction	= DOWN
    }
    image
    {
      function		= ARROW
      state		= INSENSITIVE
      recolorable	= TRUE
      overlay_file	= "images/arrow-down-ins-combo.png"
      overlay_border	= { 0, 0, 0, 0 }
      overlay_stretch	= FALSE
      arrow_direction	= DOWN
    }
    
    image # used for dialog bg. in apps. like Inkscape 
    {
     function		= BOX
     recolorable	= TRUE
     file        	= "images/null.png"
     border      	= { 2, 2, 2, 2 }
     stretch         	= TRUE
     }
	}
}

class "GtkArrow*" style "arrow"
