style "default" {

	GtkScrollbar		::has-backward-stepper		= 0  
	GtkScrollbar		::has-forward-stepper		= 1
	GtkScrollbar		::min-slider-length		= 30
	GtkScrollbar		::slider-width			= 9
	GtkScrollbar		::trough-border			= 3
	GtkScrollbar		::activate-slider 		= FALSE
	GtkScrollbar		::trough-side-details		= 0
	GtkScrollbar		::stepper-size          	= 1
	
	GtkScrolledWindow	::scrollbar-spacing		= 0
	GtkScrolledWindow	::scrollbars-within-bevel	= 1

}

style "scrollbar" {
	bg[SELECTED]	= shade (0.70, @base_color)		# color indicador
	bg[NORMAL]	= shade (0.90, @bg_color)		# color borde indicador

	fg[NORMAL]	= shade (1.00, @base_color)
	fg[PRELIGHT]	= shade (1.00, @base_color)
	fg[ACTIVE]	= shade (1.00, @base_color)
	fg[SELECTED]	= shade (1.00, @base_color)
	fg[INSENSITIVE]	= shade (1.00, @base_color)
	
	engine "murrine" {
        roundness               = 10
        gradient_shades		= {1.0,1.0,1.0,1.0}
        highlight_shade		= 1.0
        glow_shade              = 1.0
        #reliefstyle            = 0
        prelight_shade          = .75
        gradient_colors         = FALSE
        lightborder_shade       = 1.0
        lightborderstyle        = 0
        trough_shades           = {1.05, 1.13}
        border_shades           = {1.32, 1.32}
        contrast                = 0.00
	colorize_scrollbar	= TRUE
	scrollbarstyle = 0
	}
}

style "hscrollbar" {
}

style "vscrollbar" {
}

style "overlay_scrollbar"
{
	bg[SELECTED] = shade (1.0, @selected_bg_color)
	bg[INSENSITIVE] = shade (0.85, @bg_color)
	bg[ACTIVE] = shade (0.6, @bg_color)
}

style "scale" = "button" {
	bg[NORMAL] = @bg_color
	bg[PRELIGHT] = shade (1.06, @bg_color)
	bg[ACTIVE] = shade (0.94, @bg_color)

	engine "murrine" {
		contrast = 0.6
		border_shades = {0.9, 0.8}
		roundness = 5
		lightborder_shade = 1.32
		gradient_shades = {1.1, 1.0, 1.0, 0.8}
		handlestyle = 2
		trough_border_shades = {0.9, 1.4}
		glow_shade = 1.0
#		reliefstyle = 2
#		shadow_shades = { 1.0, 0.9 }
	}
}
