/*********
 * Menus *
 *********/
.menu {
	padding: 0;
	background-image: none;
	background-color: @theme_base_color;
	border-color: @inactive_frame_color;
	color: @theme_fg_color;
}

/* menuitem */
.menuitem {
	padding: 2;
	border-width: 0;
	border-radius: 0;
	text-shadow: 0 1 alpha (shade (@button_bg_color, 1.25), 0.4);
	border-style: solid;
	color: @theme_fg_color;
	background-image: -gtk-gradient (linear, left top, left bottom,
		from (shade (@menuitem_background_a, 1.0)),
		to (shade (@menuitem_background_b, 1.0)));

	-unico-bullet-color: @dark_fg_color;
	-unico-border-gradient: -gtk-gradient (linear, left top, left bottom,
		from (alpha (@theme_selected_bg_color, 0.0)),
		to (alpha (@theme_selected_bg_color, 0.0)));
	-unico-inner-stroke-style: none;
}

.menubar.menuitem:prelight {
    background-image: none;
    background-color: @menu_bg_color;
    color: @menu_fg_color;
    border-style: solid;
    border-radius: 0;
    border-width: 0;
    border-color: @inactive_frame_color;
}

.menuitem:insensitive,
.menuitem *:insensitive {
	color: mix (@theme_fg_color, @theme_bg_color, 0.5);
	text-shadow: 0 1 shade (@bg_color, 1.1);
}

.menuitem.check:active,
.menuitem.radio:active {
	color: @theme_fg_color;
	-unico-bullet-color: @theme_fg_color;
}

.menuitem.check:active:prelight,
.menuitem.radio:active:prelight {
	color: @selected_fg_color;
	-unico-bullet-color: @selected_fg_color;
}

/* menubar */
.menubar {
	-GtkWidget-window-dragging: true;
	color: @theme_fg_color;
	text-shadow: 0 1 alpha (shade (@button_bg_color, 1.25), 0.4);
	background-image: -gtk-gradient (linear,
		left top,
		left bottom,
		from (@toolbar_gradient_base),
		to (@toolbar_gradient_final));
	-unico-border-gradient: -gtk-gradient (linear, left top, left bottom,
		from (alpha (@toolbar_border, 0.0)),
		to (alpha (@toolbar_border, 1.0)));
	border-style: solid;
	border-width: 1;
}

.menubar.menuitem {
	border-radius: 0;
	border-width: 1;
}

.menubar.menuitem:prelight {
	color: @theme_fg_color;
	text-shadow: none;
	background-image: none;
	background-color: @theme_base_color;
	border-width: 1;
	border-color: @inactive_frame_color;
	border-style: solid;
	-unico-inner-stroke-style: none;
	-unico-border-gradient: -gtk-gradient (linear, left top, left bottom,
		from (alpha (@inactive_frame_color, 1.0)),
		to (alpha (@inactive_frame_color, 1.0)));
}
