
style "pcmanfm-sidebar" {
	GtkTreeView::even_row_color   = @sidepane_color
}

style "pcmanfm-handle" {
	GtkPaned::handle-size = 2
	engine "pixmap" {
		image {	function	= HANDLE
			recolorable	= FALSE
			file		= "../images/handle-vert.png"
			stretch		= TRUE
			border 		= { 0, 0, 0, 0 }	}
	}
}

style "pcmanfm-notebook" {
	xthickness = 1
	ythickness = 1
}

style "pcman-padding" {	
	xthickness = 3
  	ythickness = 3
}

style "treeview" {
	engine "clearlooks" {
		hint = "treeview"
	}
}

style "treeview_header" = "default" {
	xthickness = 2
	ythickness = 1
	engine "clearlooks" {
		hint = "treeview-header"
	}
}

widget_class	"*FmMainWin*GtkToolbar*"	style "pcman-padding"
widget_class	"*FmPlacesView*"		style "pcmanfm-sidebar"
widget		"*FmMainWin*GtkHPaned"		style "pcmanfm-handle"
widget		"*FmMainWin*GtkNotebook"	style "pcmanfm-notebook"

widget_class "*.<GtkTreeView>*" style "treeview"
widget_class "*.<GtkTreeView>.<GtkButton>" style "treeview_header"
widget_class "*.<GtkCTree>.<GtkButton>" style "treeview_header"
widget_class "*.<GtkList>.<GtkButton>" style "treeview_header"
widget_class "*.<GtkCList>.<GtkButton>" style "treeview_header"

widget_class "*.<GtkComboBox>.<GtkCellView>" style "text_is_fg_color_workaround"
widget "*.gtk-combobox-popup-menu.*" style "menuitem_text_is_fg_color_workaround"
widget_class "*<GtkListItem>*" style "fg_is_text_color_workaround"
widget_class "*<GtkCList>" style "fg_is_text_color_workaround"
widget_class "*<EelEditableLabel>" style "fg_is_text_color_workaround"

widget_class "*.<ETable>.<ECanvas>" style "treeview_header"
widget_class "*.<ETree>.<ECanvas>" style "treeview_header"
