@define-color cluebar_color shade (mix (@bg_color, @base_color, 0.5), 0.95);

NautilusWindow * {
    -GtkPaned-handle-size: 1;
}

NautilusDesktopWindow GtkWidget {
    background-color: @transparent;
}

.nautilus-canvas-item {
    border-radius: 4px;
}

/* desktop mode */
.nautilus-desktop.nautilus-canvas-item {
    color: @bg_color;
    text-shadow: 1px 1px alpha (#000000, 0.8);
}

.nautilus-desktop.nautilus-canvas-item:active {
    background-image: none;
    background-color: alpha (@bg_color, 0.84);

    color: @fg_color;
}

.nautilus-desktop.nautilus-canvas-item:selected {
    background-image: none;
    background-color: alpha (@selected_bg_color, 0.84);

    color: @selected_fg_color;
}

.nautilus-desktop.nautilus-canvas-item:active,
.nautilus-desktop.nautilus-canvas-item:prelight,
.nautilus-desktop.nautilus-canvas-item:selected {
    text-shadow: none;
}

/* browser window */
NautilusTrashBar.info,
NautilusXContentBar.info,
NautilusSearchBar.info,
NautilusQueryEditor.info {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@cluebar_color, 1.02)),
                                     to (shade (@cluebar_color, 0.98)));
    background-color: @cluebar_color;
    border-bottom-color: shade (@cluebar_color, 0.92);
    border-radius: 0;
    border-style: solid;
    border-width: 0px 0px 1px 0px;

    box-shadow: inset -1px 0px shade (@cluebar_color, 1.02),
                inset 1px 0px shade (@cluebar_color, 1.02),
                inset 0 1px shade (@cluebar_color, 1.04),
                inset 0 -1px shade (@cluebar_color, 1.01);
}

NautilusTrashBar.info:backdrop,
NautilusXContentBar.info:backdrop,
NautilusSearchBar.info:backdrop,
NautilusQueryEditor.info:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@cluebar_color, 1.01)),
                                     to (shade (@cluebar_color, 0.99)));
    background-color: @cluebar_color;
    border-bottom-color: shade (@cluebar_color, 0.92);

    box-shadow: inset -1px 0px shade (@cluebar_color, 1.01),
                inset 1px 0px shade (@cluebar_color, 1.01),
                inset 0 1px shade (@cluebar_color, 1.02),
                inset 0 -1px shade (@cluebar_color, 1.0);
}

NautilusSearchBar .entry {
}

.nautilus-cluebar-label {
    font: bold;
    text-shadow: 0 1px shade (@cluebar_color, 1.06);
}

.nautilus-cluebar-label:backdrop {
    color: mix (@fg_color, @cluebar_color, 0.2);
    text-shadow: 0 1px shade (@cluebar_color, 1.02);
}

#nautilus-search-button *:active,
#nautilus-search-button *:active:prelight {
    color: @dark_fg_color;
}

NautilusFloatingBar {
    background-color: @info_bg_color;
    border-radius: 3px 3px 0 0;
    border-style: solid;
    border-width: 1px;
    border-color: darker (@info_bg_color);
}

NautilusFloatingBar .button {
    -GtkButton-image-spacing: 0;
    -GtkButton-inner-border: 0;
}

/* sidebar */
NautilusWindow .sidebar,
NautilusWindow .sidebar .view {
    background-color: shade (@bg_color, 0.95);

    /*background-color: @bg_color;*/

    color: @fg_color;
    text-shadow: 0 1px shade (shade (@bg_color, 0.95), 1.04); 
}

NautilusWindow .sidebar .frame {
    border-width: 1px 0 0 0;
    border-style: solid;
    border-color: shade (@bg_color, 0.86);
    border-radius: 0;
}

NautilusWindow .sidebar:backdrop,
NautilusWindow .sidebar .view:backdrop {
    color: mix (@fg_color, shade (@bg_color, 0.95), 0.2);
    text-shadow: 0 1px shade (shade (@bg_color, 0.95), 1.02); 
}

NautilusWindow .sidebar row:selected {
    color: @selected_fg_color;
    text-shadow: 0 1px shade (@selected_bg_color, 0.8); 
}

NautilusWindow .sidebar row:selected:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (shade (@bg_color, 0.95), 0.94)),
                                     to (shade (shade (@bg_color, 0.95), 0.86)));
    border-top-color: shade (shade (@bg_color, 0.95), 0.88);

    color: @fg_color;
    text-shadow: 0 1px shade (shade (@bg_color, 0.95), 0.96); 
}

NautilusWindow .pane-separator {
    background-color: shade (shade (@bg_color, 0.95), 0.94);
    border-color: @dark_bg_color;
    border-style: solid;
    border-width: 0;
    box-shadow: none;
}

NautilusWindow .pane-separator:backdrop {
    background-color: shade (shade (@bg_color, 0.95), 0.96);
}
