style "thunar-sidepane"
{
	GtkTreeView::vertical-separator = 2

	base[NORMAL]		= @sidepane_color
	base[INSENSITIVE]	= @bg_color

	text[NORMAL]		= mix (0.7, @text_color, @base_color)
	text[ACTIVE]		= @selected_fg_color
	text[SELECTED]		= @selected_fg_color

	engine "pixmap" {
		
	image {
		function	= FLAT_BOX
		state		= SELECTED
	        recolorable	= TRUE
		file		= "/images/sidebar_active.png"		
		border		= { 0, 0, 0, 0 }
		stretch		= TRUE
        	}
	
	image {
		function	= FOCUS
		recolorable	= TRUE
		file		= "/images/sidebar_active.png"
		border		= { 0, 0, 0, 0 }
		stretch		= TRUE
		} 
	}
}

style "thunar-handle" {
	GtkPaned::handle-size = 1
	engine "pixmap" {
		image { function = HANDLE file = "/images/handle.png" stretch = TRUE border = { 0, 0, 0, 0 } }
	}
}

#style "thunar-statusbar" {
#	bg[NORMAL] = @base_color
#
#	engine "pixmap"	{
#		image {
#			function	= RESIZE_GRIP
#			recolorable	= FALSE
#			detail		= "statusbar"
#			overlay_file	= "/images/null.png"
#			overlay_border	= {0,0,0,0 }
#			overlay_stretch	= FALSE
#		}
#        }
#}

style "thunar-location" {
	ThunarLocationButtons::spacing = 0
}

style "thunar-frame" {
	xthickness = 0
	ythickness = 0
}

widget_class "*ThunarLocationEntry*" style "entry"
widget_class "*ThunarWindow*.<GtkScrolledWindow>" style "thunar-frame"
widget_class "*ThunarLocationButtons*" style "thunar-location"
widget_class "*ThunarShortcutsView*" style "thunar-sidepane"
widget_class "*ThunarTreeView*" style "thunar-sidepane"
widget_class "*ThunarWindow*.<GtkHPaned>" style "thunar-handle"
#widget_class "*ThunarStatusbar*" style "thunar-statusbar"
