/* Make the calendar focus ring appear around the selected day */
calendar-view  {
    outline-style: dashed;
    outline-color: @selected_bg_color;
    outline-width: 2px;
    -gtk-outline-radius: 8px;
    outline-offset: -4px;
}
