# ==============================================================================
# GNOME TERMINAL SPECIFIC SETTINGS
# ==============================================================================

style "terminal_menubar"
{
	engine "murrine" {
	}
}

style "terminal_notebook"
{
	engine "murrine" {
		contrast = 1.0
	}
}

style "terminal_scrollbar" = "scrollbar"
{
	engine "murrine" {
	}
}

style "terminal_screen"
{
	text[NORMAL] = "#ffffff"
	base[NORMAL] = "#300A24"

	TerminalScreen::background-darkness = 0.95
}

#widget "*TerminalWindow*"                               style "terminal_window"
#widget "*TerminalWindow.*.*enu?ar"                     style "terminal_menubar"
widget "*TerminalWindow.*.GtkNotebook*"                 style "terminal_notebook"
#widget "*TerminalWindow.*.GtkNotebook.*.GtkVScrollbar*" style "terminal_scrollbar"
#widget "*TerminalWindow.*.GtkNotebook*utton*"           style "terminal_button"
widget "*TerminalWindow.*.TerminalScreen*"              style "terminal_screen"





