########################################################################
# Scale
########################################################################

style "scale"
{
	GtkRange::slider_width = 16
	engine "pixmap"
	{
		image	{
			function = BOX
			detail = "trough"
			file = "images/scale-trough-horiz.png"
			border = {19, 19, 5, 6}
			stretch	= TRUE
			orientation	= HORIZONTAL	}

		image	{
			function = BOX
			detail = "trough"
			file = "images/scale-trough-vert.png"
			border = {5, 6, 19, 19}
			stretch	= TRUE
			orientation	= VERTICAL	}

		image	{
			function = SLIDER
			state = NORMAL
			overlay_file = "images/scale-slider.png"
			overlay_stretch	= FALSE
			orientation	= HORIZONTAL	}

		image	{
			function = SLIDER
			state = NORMAL
			overlay_file = "images/scale-slider.png"
			overlay_stretch	= FALSE
			orientation	= VERTICAL	}
		
		image	{
			function = SLIDER
			state = PRELIGHT
			overlay_file = "images/scale-slider-sel.png"
			overlay_stretch	= FALSE
			orientation	= HORIZONTAL	}

		image	{
			function = SLIDER
			state = PRELIGHT
			overlay_file = "images/scale-slider-sel.png"
			overlay_stretch	= FALSE
			orientation	= VERTICAL	}
		
		image	{
			function = SLIDER
			state = INSENSITIVE
			overlay_file = "images/scale-slider.png"
			overlay_stretch	= FALSE
			orientation	= HORIZONTAL	}

		image	{
			function = SLIDER
			state = INSENSITIVE
			overlay_file = "images/scale-slider.png"
			overlay_stretch	= FALSE
			orientation	= VERTICAL	}
		
		image 	{
			function = FOCUS
			file = "images/null.png"	} 
	}
}

style "vscale" {
	engine "clearlooks" {
		hint = "vscale"
	}
}

style "hscale" {
	engine "clearlooks" {
		hint = "hscale"
	}
}

class "GtkRange*" style "scale"

