menu check {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-unselected.png"),
                                  url("assets/check-menuitem-unselected@2.png"));
}

menu radio {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-unselected.png"),
                                  url("assets/check-menuitem-unselected@2.png"));
}

menu check:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-dark.png"),
                                  url("assets/check-menuitem-dark@2.png"));
}

menu check:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-insensitive-dark.png"),
                                  url("assets/check-menuitem-insensitive-dark@2.png"));
}

menu radio:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-dark.png"),
                                  url("assets/radio-menuitem-dark@2.png"));
}

menu radio:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-insensitive-dark.png"),
                                  url("assets/radio-menuitem-insensitive-dark@2.png"));
}
