/***************
 * Resize grip *
 ***************/

.grip {
    background-color: transparent;
    /*background-image: url("assets/resize-grip.svg");*/
}

/*************************
 * Check and Radio items *
 *************************/

/* draw regular check and radio items using our SVG assets */
.check {
    -gtk-icon-source: url("assets/check-unselected.png");
}

.check:hover {
    -gtk-icon-source: url("assets/check-unselected-hover.png");
}

.check row,
.check row:selected,
.check row:selected:focus {
    -gtk-icon-source: url("assets/check-unselected-alt.png");
}

.check row:hover,
.check row:selected:hover,
.check row:selected:focus:hover {
    -gtk-icon-source: url("assets/check-unselected-hover-alt.png");
}

.check:insensitive {
    -gtk-icon-source: url("assets/check-unselected-disabled.png");
}

.check row:insensitive {
    background-color: transparent;
}

.check row:insensitive,
.check row:selected:insensitive,
.check row:selected:focus:insensitive {
    background-color: transparent;
    -gtk-icon-source: url("assets/check-unselected-disabled-alt.png");
}

.check:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-unselected.png");
}

.check:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-unselected-hover.png");
}

.check row:backdrop,
.check row:selected:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-unselected-alt.png");
}

.check row:hover:backdrop,
.check row:selected:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-unselected-hover-alt.png");
}

.check:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-unselected-disabled.png");
}

.check row:selected:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-unselected-disabled-alt.png");
}

.check:checked {
    -gtk-icon-source: url("assets/check-selected.png");
}

.check:checked:hover {
    -gtk-icon-source: url("assets/check-selected-hover.png");
}

.check row:checked,
.check row:selected:checked,
.check row:selected:focus:checked {
    -gtk-icon-source: url("assets/check-selected-alt.png");
}

.check row:checked:hover,
.check row:selected:checked:hover,
.check row:selected:checked:focus:hover {
    -gtk-icon-source: url("assets/check-selected-hover-alt.png");
}

.check:checked:insensitive {
    -gtk-icon-source: url("assets/check-selected-disabled.png");
}

.check row:checked:insensitive,
.check row:selected:checked:insensitive,
.check row:selected:focus:checked:insensitive {
    -gtk-icon-source: url("assets/check-selected-disabled-alt.png");
}

.check:checked:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-selected.png");
}

.check:checked:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-selected-hover.png");
}

.check row:checked:backdrop,
.check row:selected:checked:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-selected-alt.png");
}

.check row:checked:hover:backdrop,
.check row:selected:checked:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-selected-hover-alt.png");
}

.check:checked:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-selected-disabled.png");
}

.check row:selected:checked:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-selected-disabled-alt.png");
}

.check:inconsistent {
    -gtk-icon-source: url("assets/check-mixed.png");
}

.check:inconsistent:hover {
    -gtk-icon-source: url("assets/check-mixed-hover.png");
}

.check row:inconsistent,
.check row:selected:inconsistent,
.check row:selected:focus:inconsistent {
    -gtk-icon-source: url("assets/check-mixed-alt.png");
}

.check row:inconsistent:hover,
.check row:selected:inconsistent:hover,
.check row:selected:focus:inconsistent:hover {
    -gtk-icon-source: url("assets/check-mixed-hover-alt.png");
}

.check:inconsistent:insensitive {
    -gtk-icon-source: url("assets/check-mixed-disabled.png");
}

.check row:inconsistent:insensitive,
.check row:selected:inconsistent:insensitive,
.check row:selected:focus:inconsistent:insensitive {
    -gtk-icon-source: url("assets/check-mixed-disabled-alt.png");
}

.check:inconsistent:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-mixed.png");
}

.check:inconsistent:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-mixed-hover.png");
}

.check row:inconsistent:backdrop,
.check row:selected:inconsistent:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-mixed-alt.png");
}

.check row:inconsistent:hover:backdrop,
.check row:selected:inconsistent:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-mixed-hover-alt.png");
}

.check:inconsistent:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-mixed-disabled.png");
}

.check row:selected:inconsistent:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-check-mixed-disabled-alt.png");
}

.radio {
    -gtk-icon-source: url("assets/radio-unselected.png");
}

.radio:hover {
    -gtk-icon-source: url("assets/radio-unselected-hover.png");
}

.radio row,
.radio row:selected,
.radio row:selected:focus {
    -gtk-icon-source: url("assets/radio-unselected-alt.png");
}

.radio row:hover,
.radio row:selected:hover,
.radio row:selected:focus:hover {
    -gtk-icon-source: url("assets/radio-unselected-hover-alt.png");
}

.radio:insensitive {
    -gtk-icon-source: url("assets/radio-unselected-disabled.png");
}

.radio row:insensitive {
    background-color: transparent;
}

.radio row:insensitive,
.radio row:selected:insensitive,
.radio row:selected:focus:insensitive {
    -gtk-icon-source: url("assets/radio-unselected-disabled-alt.png");
}

.radio:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-unselected.png");
}

.radio:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-unselected-hover.png");
}

.radio row:backdrop,
.radio row:selected:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-unselected-alt.png");
}

.radio row:hover:backdrop,
.radio row:selected:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-unselected-hover-alt.png");
}

.radio:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-unselected-disabled.png");
}

.radio row:selected:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-unselected-disabled-alt.png");
}

.radio:checked {
    -gtk-icon-source: url("assets/radio-selected.png");
}

.radio:checked:hover {
    -gtk-icon-source: url("assets/radio-selected-hover.png");
}

.radio row:checked,
.radio row:selected:checked,
.radio row:selected:focus:checked {
    -gtk-icon-source: url("assets/radio-selected-alt.png");
}

.radio row:checked:hover,
.radio row:selected:checked:hover,
.radio row:selected:focus:checked:hover {
    -gtk-icon-source: url("assets/radio-selected-hover-alt.png");
}

.radio:checked:insensitive {
    -gtk-icon-source: url("assets/radio-selected-disabled.png");
}

.radio row:insensitive,
.radio row:selected:checked:insensitive,
.radio row:selected:focus:checked:insensitive {
    -gtk-icon-source: url("assets/radio-selected-disabled-alt.png");
}

.radio:checked:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-selected.png");
}

.radio:checked:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-selected-hover.png");
}

.radio row:checked:backdrop,
.radio row:selected:checked:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-selected-alt.png");
}

.radio row:checked:hover:backdrop,
.radio row:selected:checked:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-selected-hover-alt.png");
}

.radio:checked:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-selected-disabled.png");
}

.radio row:selected:checked:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-selected-disabled-alt.png");
}

.radio:inconsistent {
    -gtk-icon-source: url("assets/radio-mixed.png");
}

.radio:inconsistent:hover {
    -gtk-icon-source: url("assets/radio-mixed-hover.png");
}

.radio row:inconsistent,
.radio row:selected:inconsistent,
.radio row:selected:focus:inconsistent {
    -gtk-icon-source: url("assets/radio-mixed-alt.png");
}

.radio row:inconsistent:hover,
.radio row:selected:inconsistent:hover,
.radio row:selected:focus:inconsistent:hover {
    -gtk-icon-source: url("assets/radio-mixed-hover-alt.png");
}

.radio:inconsistent:insensitive {
    -gtk-icon-source: url("assets/radio-mixed-disabled.png");
}

.radio row:inconsistent:insensitive,
.radio row:selected:inconsistent:insensitive,
.radio row:selected:focus:inconsistent:insensitive {
    -gtk-icon-source: url("assets/radio-mixed-disabled-alt.png");
}

.radio:inconsistent:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-mixed.png");
}

.radio:inconsistent:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-mixed-hover.png");
}

.radio row:inconsistent:backdrop,
.radio row:selected:inconsistent:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-mixed-alt.png");
}

.radio row:inconsistent:hover:backdrop,
.radio row:selected:inconsistent:hover:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-mixed-hover-alt.png");
}

.radio:inconsistent:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-mixed-disabled.png");
}

.radio row:selected:inconsistent:insensitive:backdrop {
    -gtk-icon-source: url("assets/backdrop-radio-mixed-disabled-alt.png");
}

.primary-toolbar .menu .check,
.menubar.toolbar .menu .check,
.header-bar .menu .check,
.menu .check {
    -gtk-icon-source: url("assets/check-menuitem-unselected.png");
}

.primary-toolbar .menu .radio,
.menubar.toolbar .menu .radio,
.header-bar .menu .radio,
.menu .radio {
    -gtk-icon-source: url("assets/check-menuitem-unselected.png");
}

.primary-toolbar .menu .check:checked,
.menubar.toolbar .menu .check:checked,
.header-bar .menu .check:checked,
.menu .check:checked {
    -gtk-icon-source: url("assets/check-menuitem-dark.png");
}

.toolbar .menu .check:checked:hover,
.menu .check:checked:hover {
    -gtk-icon-source: url("assets/check-menuitem.png");
}

.primary-toolbar .menu .check:checked:insensitive,
.menubar.toolbar .menu .check:checked:insensitive,
.header-bar .menu .check:checked:insensitive,
.toolbar .menu .check:checked:hover:insensitive,
.menu .check:checked:insensitive,
.menu .check:checked:hover:insensitive {
    -gtk-icon-source: url("assets/check-menuitem-insensitive.png");
}

.toolbar .menu .radio:checked:hover,
.menu .radio:checked {
    -gtk-icon-source: url("assets/radio-menuitem.png");
}

.primary-toolbar .menu .radio:checked:insensitive,
.menubar.toolbar .menu .radio:checked:insensitive,
.header-bar .menu .radio:checked:insensitive,
.toolbar .menu .radio:checked:hover:insensitive,
.menu .radio:checked:insensitive,
.menu .radio:checked:hover:insensitive {
    -gtk-icon-source: url("assets/radio-menuitem-insensitive.png");
}

.toolbar .menu .check {
    -gtk-icon-source: url("assets/check-menuitem-unselected.png");
}

.toolbar .menu .radio {
    -gtk-icon-source: url("assets/check-menuitem-unselected.png");
}

.toolbar .menu .check:checked {
    -gtk-icon-source: url("assets/check-menuitem-dark.png");
}

.toolbar .menu .check:checked:insensitive {
    -gtk-icon-source: url("assets/check-menuitem-insensitive-dark.png");
}

.toolbar .menu .radio:checked {
    -gtk-icon-source: url("assets/radio-menuitem-dark.png");
}

.toolbar .menu .radio:checked:insensitive {
    -gtk-icon-source: url("assets/radio-menuitem-insensitive-dark.png");
}

/*********************
 * GtkScale's slider *
 *********************/
.scale.slider,
.scale.slider.horizontal {
    background-image: url("assets/slider-horizontal.png");
}

.scale.slider:backdrop,
.scale.slider.horizontal:backdrop {
    /*background-image: url("assets/slider-horizontal-disabled.png");*/
}

.scale.slider:hover,
.scale.slider.horizontal:hover {
    background-image: url("assets/slider-horizontal-hover.png");
}

.scale.slider:focused,
.scale.slider.horizontal:focused {
    background-image: url("assets/slider-horizontal-focused.png");
}

.scale.slider:hover:focused,
.scale.slider.horizontal:hover:focused {
    background-image: url("assets/slider-horizontal-focused-hover.png");
}

.scale.slider:insensitive,
.scale.slider.horizontal:insensitive {
    background-image: url("assets/slider-horizontal-disabled.png");
}

.scale.slider:insensitive:backdrop,
.scale.slider.horizontal:insensitive:backdrop {
    /*background-image: url("assets/slider-horizontal-backdrop-disabled.png");*/
}

.scale.slider.vertical {
    background-image: url("assets/slider-vertical.png");
}

.scale.slider.vertical:backdrop {
    /*background-image: url("assets/slider-vertical-backdrop.png");*/
}

.scale.slider.vertical:hover {
    background-image: url("assets/slider-vertical-hover.png");
}

.scale.slider.vertical:focused {
    background-image: url("assets/slider-vertical-focused.png");
}

.scale.slider.vertical:hover:focused {
    background-image: url("assets/slider-vertical-focused-hover.png");
}

.scale.slider.vertical:insensitive {
    background-image: url("assets/slider-vertical-disabled.png");
}

.scale.slider.vertical:insensitive:backdrop {
    /*background-image: url("assets/slider-vertical-backdrop-disabled.png");*/
}

/*.scale.scale-has-marks-above.slider.horizontal {
    background-image: url("assets/slider-up.png");
}

.scale.scale-has-marks-above.slider.horizontal:insensitive {
    background-image: url("assets/slider-up-disabled.png");
}

.scale.scale-has-marks-above.slider.horizontal:backdrop {
    background-image: url("assets/slider-up-backdrop.png");
}

.scale.scale-has-marks-above.slider.horizontal:backdrop:insensitive {
    background-image: url("assets/slider-up-backdrop-disabled.png");
}

.scale.scale-has-marks-above.slider.vertical {
    background-image: url("assets/slider-left.png");
}

.scale.scale-has-marks-above.slider.vertical:insensitive {
    background-image: url("assets/slider-left-disabled.png");
}

.scale.scale-has-marks-above.slider.vertical:backdrop {
    background-image: url("assets/slider-left-backdrop.png");
}

.scale.scale-has-marks-above.slider.vertical:backdrop:insensitive {
    background-image: url("assets/slider-left-backdrop-disabled.png");
}

.scale.scale-has-marks-below.slider.horizontal {
    background-image: url("assets/slider-down.png");
}

.scale.scale-has-marks-below.slider.horizontal:insensitive {
    background-image: url("assets/slider-down-disabled.png");
}

.scale.scale-has-marks-below.slider.horizontal:backdrop {
    background-image: url("assets/slider-down-backdrop.png");
}

.scale.scale-has-marks-below.slider.horizontal:backdrop:insensitive {
    background-image: url("assets/slider-down-backdrop-disabled.png");
}

.scale.scale-has-marks-below.slider.vertical {
    background-image: url("assets/slider-right.png");
}

.scale.scale-has-marks-below.slider.vertical:insensitive {
    background-image: url("assets/slider-right-disabled.png");
}

.scale.scale-has-marks-below.slider.vertical:backdrop {
    background-image: url("assets/slider-right-backdrop.png");
}

.scale.scale-has-marks-below.slider.vertical:backdrop:insensitive {
    background-image: url("assets/slider-right-backdrop-disabled.png");
}*/

