/* Set up shadows and hilights for button visual separation */
.primary-toolbar .linked button,
headerbar .linked button {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 1.1),
                inset -1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked button:first-child,
headerbar .linked button:first-child {
    box-shadow: inset -1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked button:active,
headerbar .linked button:active,
.primary-toolbar .linked button:disabled,
headerbar .linked button:disabled {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked button:active,
headerbar .linked button:active,
.primary-toolbar .linked button:disabled,
headerbar .linked button:disabled {
    box-shadow: inset -1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked button:last-child,
headerbar .linked button:last-child {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 1.1);
}

menubar {
    color: @dark_fg_color;
    text-shadow: 0 1px shade (@dark_bg_color, 1.1);
}

menubar menuitem:hover,
.menubar.menuitem:hover,
.menubar .menuitem:hover {
    color: @dark_fg_color;
    text-shadow: 0 1px shade (@dark_bg_color, 1.1);
}

popover modelbutton:hover,
popover menuitem:checked:hover,
menuitem:hover,
menu menuitem:hover {
    color: @selected_fg_color;
    text-shadow: 0 -1px shade (@selected_bg_color, 0.7);
}

toolbar headerbar menu menuitem:disabled,
toolbar headerbar menu menuitem *:disabled,
toolbutton menu menuitem:disabled,
toolbutton menu menuitem *:disabled,
.primary-toolbar button menu menuitem:disabled,
.primary-toolbar button menu menuitem *:disabled,
headerbar button menu menuitem:disabled,
headerbar button menu menuitem *:disabled,
menuitem:disabled,
menuitem *:disabled {
    color: mix (@fg_color, @bg_color, 0.5);
    text-shadow: 0 1px shade (@bg_color, 1.14);
}

/* for the playback menu item in the sound menu */
menu spinner,
menu spinner:hover {
    color: @selected_bg_color;
}

/* primary-toolbar */
.primary-toolbar,
headerbar,
.maximized headerbar.titlebar:not(:backdrop) {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.96)),
                                     to (shade (@dark_bg_color, 1.1)));
    border-bottom-color: shade (@dark_bg_color, 1.02);
    border-top-color: shade (@dark_bg_color, 1.02);

    text-shadow: 0 1px shade (@dark_bg_color, 1.1);
}

.primary-toolbar:disabled,
headerbar:disabled {
    text-shadow: 0 1px shade (@dark_bg_color, 1.1);
}

.primary-toolbar button,
headerbar button *,
headerbar button:disabled * {
    text-shadow: 0 1px alpha (shade (@dark_bg_color, 1.25), 0.32);
}

.primary-toolbar button:hover,
.primary-toolbar button:active,
.primary-toolbar button:disabled,
headerbar button:hover,
headerbar button:backdrop:hover,
headerbar button:active,
headerbar button:disabled {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.03)),
                                     to (shade (@dark_bg_color, 0.96)));
}

.titlebar {
    border-top-width: 0px;
}
