/* default color scheme */
@define-color bg_color #e0e0e0;
@define-color fg_color #333;
@define-color base_color #fff;
@define-color text_color #333;
@define-color selected_bg_color #8FB2CF;
@define-color selected_fg_color #fff;
@define-color tooltip_bg_color #333;
@define-color tooltip_fg_color #fff;

/* misc colors used by gtk+ */
@define-color info_fg_color rgb (181, 171, 156);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (173, 120, 41);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (97, 122, 214);
@define-color question_bg_color rgb (138, 173, 212);
@define-color error_fg_color rgb (166, 38, 38);
@define-color error_bg_color rgb (237, 54, 54);
@define-color link_color #5590CC;
@define-color error_color #cc0000;
@define-color combobox_color #888;

/* theme common colors */
@define-color notebook_button_bg_color shade (@bg_color, 1.02);
@define-color button_bg_color shade (@bg_color,1.02);
@define-color button_insensitive_bg_color mix (@button_bg_color, @bg_color, 0.6);
/* @define-color dark_bg_color @bg_color;	*/
@define-color dark_bg_color #bcbcbc;
@define-color dark_fg_color @fg_color;
@define-color borders @dark_bg_color;
@define-color transparent rgba (0, 0, 0, 0);

@define-color backdrop_fg_color mix (@bg_color, @fg_color, 0.8);
@define-color backdrop_text_color mix (@base_color, @text_color, 0.8);
@define-color backdrop_dark_fg_color mix (@dark_bg_color, @dark_fg_color, 0.75);
@define-color backdrop_selected_bg_color shade (@bg_color, 0.92);
@define-color backdrop_selected_fg_color @fg_color;

@define-color toolbar_base #e0e0e0;
@define-color toolbar_final #bcbcbc;
@define-color toolbar_border #fff;
@define-color toolbar_bg_color			@bg_color;
@define-color toolbar_fg_color			@fg_color;
@define-color toolbar_textshadow_color		@bg_color;
@define-color toolbar_bg_top_color		@toolbar_base;
@define-color toolbar_bg_bottom_color		@toolbar_final;
@define-color toolbar_border_top_color		@toolbar_base;
@define-color toolbar_border_bottom_color	@toolbar_border;

@import url("gtk-widgets-borders.css");
@import url("gtk-widgets-borders-radiance.css");
@import url("gtk-widgets-assets.css");
@import url("gtk-widgets-assets-radiance.css");
@import url("gtk-widgets.css");
@import url("gtk-widgets-radiance.css");
@import url("gtk-widgets-toolbar.css");
