########################################################################
# Notebook
########################################################################

style "notebook_bg" {
	bg[NORMAL]        = "#e0e0e0"
}

style "notebook" {
	xthickness = 3
	ythickness = 3
	bg[NORMAL]        = "#e0e0e0"

	engine "pixmap" {

### Notebook ###
		image {	function = BOX
			file = "images/notebook.png"
			border = {4, 4, 4, 4}
			stretch	= TRUE	}
		
### Tab TOP ###

## Normal
		image {	function = EXTENSION
			state = ACTIVE
			file = "images/notebook-tab-top.png"
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_side = BOTTOM	}

## Active
		image {	function = EXTENSION
			file = "images/notebook-tab-top-active.png"
			border = {4, 4, 4, 4}
			stretch = TRUE
			gap_side = BOTTOM	}

### Tab BOTTOM ###

## Normal
		image {	function = EXTENSION
			state = ACTIVE
			file = "images/notebook-tab-bottom.png"
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_side = TOP	}

## Active		
		image {	function = EXTENSION
			file = "images/notebook-tab-bottom-active.png"
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_side = TOP	}

### Tab LEFT ###
		
## Normal
		image {	function = EXTENSION
			state = ACTIVE
			file = "images/notebook-tab-left.png"
			border = {4,4,4,4}
			stretch	= TRUE
			gap_side = RIGHT	}
		
## Active
		image {	function = EXTENSION
			file = "images/notebook-tab-left-active.png"
			border = {4, 4, 4, 4}
			stretch = TRUE
			gap_side = RIGHT	}

### Tab RIGHT ###
    	
## Normal
		image {	function = EXTENSION
			state = ACTIVE
			file = "images/notebook-tab-right.png"
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_side = LEFT	}
		
## Active
		image {	function = EXTENSION
			file = "images/notebook-tab-right-active.png"
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_side = LEFT	}

### Gap TOP ###
		image {	function = BOX_GAP
			file = "images/notebook.png" 
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_file = "images/notebook-top-gap.png"
			gap_border = {4, 4, 0, 0}
			gap_start_file = "images/null.png"
			gap_start_border = {0, 0, 0, 0}
			gap_end_file = "images/null.png"
			gap_end_border = {0, 0, 0, 0}
			gap_side = TOP	}

### Gap BOTTOM ###
		image {	function = BOX_GAP
			file = "images/notebook.png"
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_file = "images/notebook-bottom-gap.png"
			gap_border = {4, 4, 0, 0}
			gap_start_file = "images/null.png"
			gap_start_border = {0, 0, 0, 0}
			gap_end_file = "images/null.png"
			gap_end_border = {0, 0, 0, 0}
			gap_side = BOTTOM	}

### Gap LEFT ###    
		image {	function = BOX_GAP
			file = "images/notebook.png"
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_file = "images/notebook-left-gap.png"
			gap_border = {0, 0, 4, 4}
			gap_start_file = "images/null.png"
			gap_start_border = {0, 0, 0, 0}
			gap_end_file = "images/null.png"
			gap_end_border = {0, 0, 0, 0}
			gap_side = LEFT	}
    
### Gap RIGHT ###
		image {	function = BOX_GAP
			file = "images/notebook.png" 
			border = {4, 4, 4, 4}
			stretch	= TRUE
			gap_file = "images/notebook-right-gap.png"
			gap_border = {0, 0, 4, 4}
			gap_start_file = "images/null.png"
			gap_start_border = {0, 0, 0, 0}
			gap_end_file = "images/null.png"
			gap_end_border = {0, 0, 0, 0}
			gap_side = RIGHT	}

### Focus ###
		image {	function = FOCUS
			file = "images/null.png"
			border = {1, 1, 1, 1}
			stretch = TRUE	}
	}
}

class "GtkNotebook*" style "notebook"

