##########################################################################
# Toolbar
##########################################################################

style "toolbar" {
	engine "pixmap"
	{
		image 
		{
	  		function = BOX
			recolorable = TRUE
	  		file = "images/toolbar.png"
	  		border 	= {1,1,1,1}
        	stretch = TRUE
		}
		
		image 
		{
			function = HANDLE
		    overlay_file = "images/handle-horiz.png"
		    overlay_stretch = FALSE
		    orientation	= HORIZONTAL
		}
        	
        image 
        {
			function = HANDLE
		    overlay_file = "images/handle-vert.png"
		    overlay_stretch = FALSE
		    orientation	= VERTICAL
		}
	}
}

class "*Toolbar*" style "toolbar"
class "*Handle*" style "toolbar"
class "*Paned*" style "toolbar"

