/* Decorations */

UnityDecoration {
    -UnityDecoration-extents: 28px 0 0 0;
    -UnityDecoration-input-extents: 10px;

    -UnityDecoration-shadow-offset-x: 1px;
    -UnityDecoration-shadow-offset-y: 5px;
    -UnityDecoration-active-shadow-color: rgba (0, 0, 0, 0.78);
    -UnityDecoration-active-shadow-radius: 30px;
    -UnityDecoration-inactive-shadow-color: rgba (0, 0, 0, 0.3);
    -UnityDecoration-inactive-shadow-radius: 25px;

    -UnityDecoration-glow-size: 10px;
    -UnityDecoration-glow-color: rgb (221, 72, 20);

    -UnityDecoration-title-indent: 10px;
    -UnityDecoration-title-fade: 35px;
    -UnityDecoration-title-alignment: 0.0;
}

UnityDecoration.top {
    border: 1px solid rgba (85, 40, 0, 0.04); /* shade (@dark_bg_color) (shade (#edebe6, 1.06) */
    border-bottom-width: 0;
    border-radius: 6px 6px 0 0;
    padding: 1px 6px 0 6px;

    box-shadow: inset 0 0 transparent, inset 0 0 transparent,
                inset 0 1px shade (#edebe6, 1.065), inset 0 0 transparent;

    background-color: transparent;
    background-clip: border-box;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (#edebe6, 1.06)),
                                     to (@dark_bg_color));

    color: shade (@dark_bg_color, 0.4);
    text-shadow: 1px 0 shade (@dark_bg_color, 1.06), -1px 0 shade (@dark_bg_color, 1.06),
                 0 1px shade (@dark_bg_color, 1.06), 0 -1px shade (@dark_bg_color, 1.06);
}

UnityDecoration.top:backdrop {
    border: 1px solid rgba (110, 27, 0, 0.04); /* shade @dark_bg_color - shade (#edebe6, 0.96) */
    border-bottom-width: 0;
    background-color: transparent;
    background-clip: border-box;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (#edebe6, 0.96)),
                                     to (@dark_bg_color));
    box-shadow: inset 0 0 transparent, inset 0 0 transparent,
                inset 0 1px shade (#edebe6, 0.97), inset 0 0 transparent;

    color: #a39e9a;
    text-shadow: 1px 0 1px shade (@dark_bg_color, 1.08), -1px 0 1px shade (@dark_bg_color, 1.08),
                 0 1px 1px shade (@dark_bg_color, 1.08), 0 -1px 1px shade (@dark_bg_color, 1.08);
}

UnityDecoration.left,
UnityDecoration.right {
    background-color: shade (@bg_color, 0.7);
    background-size: 1px 70px;
    background-repeat: repeat-x;

    /* start color: mix of the top border color and bg-image gradient end */
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     color-stop (0, #a89686),
                                     color-stop (0.5, #a89686),
                                     color-stop (1, shade (@bg_color, 0.7)));
}

UnityDecoration.left:backdrop,
UnityDecoration.right:backdrop {
    /* start color: mix of the top border color and bg-image gradient end */
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     color-stop (0, #b5a395),
                                     color-stop (0.5, #b5a395),
                                     color-stop (1, shade (@bg_color, 0.7)));
}

UnityDecoration.bottom {
    background-image: none;
    background-color: shade (@bg_color, 0.7);
}

/* Panel Style */

UnityPanelWidget,
.unity-panel {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (#edebe6, 1.06)),
                                     to (@dark_bg_color));
    border-top-color: shade (#edebe6, 1.08);
    border-style: solid;
    border-width: 1px 0 0 0;

    color: shade (@dark_bg_color, 0.4);
    text-shadow: 1px 0 shade (@dark_bg_color, 1.06), -1px 0 shade (@dark_bg_color, 1.06),
                 0 1px shade (@dark_bg_color, 1.06), 0 -1px shade (@dark_bg_color, 1.06);
}

UnityPanelWidget:backdrop,
.unity-panel:backdrop {
    color: #a39e9a;
}

.unity-panel.menubar,
.unity-panel .menubar {
}

.unity-panel.menuitem,
.unity-panel .menuitem {
    border-width: 1px 1px 0 1px;
    icon-shadow: 0 -1px shade (@dark_bg_color, 1.06);
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.5)),
                                     to (shade (@dark_bg_color, 1.02)));
    color: shade (@dark_bg_color, 0.4);
}

@keyframes playbackmenuitem_spinner {
    to { -gtk-icon-transform: rotate(1turn); }
}

.menu IdoPlaybackMenuItem.menuitem:active {
    -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
    animation: playbackmenuitem_spinner 1s infinite linear;
    color: @selected_bg_color;
}
