style "menubar" {
	engine "clearlooks" {
		hint = "menubar"
	}
}

style "menu" {
	xthickness = 2
	ythickness = 3
	bg[NORMAL] = @bg_color
	engine "clearlooks" {
		radius = 0.0
	}
}

style "menu_item" {
	xthickness = 2
	ythickness = 3
	fg[PRELIGHT]      = @selected_fg_color
	engine "clearlooks" {
		hint = "menubar"
	}
}

style "separator_menu_item" {
	xthickness = 1
	ythickness = 0
	GtkSeparatorMenuItem::horizontal-padding = 0
	GtkWidget::wide-separators = 0
	GtkWidget::separator-width = 1
	GtkWidget::separator-height = 7
}

# Wrokaroudn style for places where the text color is used instead of the fg color.
style "text_is_fg_color_workaround" {

	text[NORMAL]      = @fg_color
	text[PRELIGHT]    = @fg_color
	text[SELECTED]    = @selected_fg_color
	text[ACTIVE]      = @fg_color
	text[INSENSITIVE] = darker (@bg_color)
}

# Workaround style for menus where the text color is used instead of the fg color.
style "menuitem_text_is_fg_color_workaround" {

	text[NORMAL]      = @fg_color
	text[PRELIGHT]    = @selected_fg_color
	text[SELECTED]    = @selected_fg_color
	text[ACTIVE]      = @fg_color
	text[INSENSITIVE] = darker (@bg_color)
}

# Workaround style for places where the fg color is used instead of the text color.
style "fg_is_text_color_workaround" {

	fg[NORMAL]        = @text_color
	fg[PRELIGHT]      = @text_color
	fg[INSENSITIVE]   = darker (@bg_color)
}

widget_class "*<GtkMenuBar>*" style "menubar"
widget_class "*<GtkMenu>*" style "menu"
widget_class "*<GtkMenuItem>*" style "menu_item"
widget_class "*<GtkSeparatorMenuItem>*" style "separator_menu_item"
