########################################################################
# Button
########################################################################

style "button"
{
	engine "pixmap" 
    {
### Button ### 

## Normal
		image {	function = BOX
			state = NORMAL
			file = "images/button.png"
			border = {4, 4, 4, 4}
			stretch = TRUE	}
## Prelight
		image {	function = BOX
			state = PRELIGHT
			file = "images/button-sel.png"
			border = {4, 4, 4, 4}
			stretch = TRUE	}

## Insensitive
		image {	function = BOX
			state = INSENSITIVE
			file = "images/button-ins.png"
			border = {4, 4, 4, 4}
			stretch = TRUE	}

## Active
		image {	function = BOX
			state = ACTIVE
			file = "images/button-pressed.png"
			border = {4, 4, 4, 4}
			stretch = TRUE	}

### Focus ###
		image {	function = FOCUS
			file = "images/null.png"	}
    }
}

style "spinbutton" {
	engine "clearlooks" {
		hint = "spinbutton"
	}
}

class "GtkSpinButton" style "spinbutton"
class "GtkButton*" style "button"
