/***************
 * Resize grip *
 ***************/

.grip {
    background-color: transparent;
    /*background-image: url("assets/resize-grip.svg");*/
}

/*************************
 * Check and Radio items *
 *************************/

/* draw regular check and radio items using our SVG assets */
check {
    -gtk-icon-source: -gtk-scaled(url("assets/check-unselected.png"),
                                  url("assets/check-unselected@2.png"));
}

check:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/check-unselected-hover.png"),
                                  url("assets/check-unselected-hover@2.png"));
}

check row,
check row:selected,
check row:selected:focus {
    -gtk-icon-source: -gtk-scaled(url("assets/check-unselected-alt.png"),
                                  url("assets/check-unselected-alt@2.png"));
}

check row:hover,
check row:selected:hover,
check row:selected:focus:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/check-unselected-hover-alt.png"),
                                  url("assets/check-unselected-hover-alt@2.png"));
}

check:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/check-unselected-disabled.png"),
                                  url("assets/check-unselected-disabled@2.png"));
}

check row:disabled {
    background-color: transparent;
}

check row:disabled,
check row:selected:disabled,
check row:selected:focus:disabled {
    background-color: transparent;
    -gtk-icon-source: -gtk-scaled(url("assets/check-unselected-disabled-alt.png"),
                                  url("assets/check-unselected-disabled-alt@2.png"));
}

check:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-unselected.png"),
                                  url("assets/backdrop-check-unselected@2.png"));
}

check:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-unselected-hover.png"),
                                  url("assets/backdrop-check-unselected-hover@2.png"));
}

check row:backdrop,
check row:selected:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-unselected-alt.png"),
                                  url("assets/backdrop-check-unselected-alt@2.png"));
}

check row:hover:backdrop,
check row:selected:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-unselected-hover-alt.png"),
                                  url("assets/backdrop-check-unselected-hover-alt@2.png"));
}

check:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-unselected-disabled.png"),
                                  url("assets/backdrop-check-unselected-disabled@2.png"));
}

check row:selected:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-unselected-disabled-alt.png"),
                                  url("assets/backdrop-check-unselected-disabled-alt@2.png"));
}

check:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/check-selected.png"),
                                  url("assets/check-selected@2.png"));
}

check:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/check-selected-hover.png"),
                                  url("assets/check-selected-hover@2.png"));
}

check row:checked,
check row:selected:checked,
check row:selected:focus:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/check-selected-alt.png"),
                                  url("assets/check-selected-alt@2.png"));
}

check row:checked:hover,
check row:selected:checked:hover,
check row:selected:checked:focus:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/check-selected-hover-alt.png"),
                                  url("assets/check-selected-hover-alt@2.png"));
}

check:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/check-selected-disabled.png"),
                                  url("assets/check-selected-disabled@2.png"));
}

check row:checked:disabled,
check row:selected:checked:disabled,
check row:selected:focus:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/check-selected-disabled-alt.png"),
                                  url("assets/check-selected-disabled-alt@2.png"));
}

check:checked:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-selected.png"),
                                  url("assets/backdrop-check-selected@2.png"));
}

check:checked:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-selected-hover.png"),
                                  url("assets/backdrop-check-selected-hover@2.png"));
}

check row:checked:backdrop,
check row:selected:checked:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-selected-alt.png"),
                                  url("assets/backdrop-check-selected-alt@2.png"));
}

check row:checked:hover:backdrop,
check row:selected:checked:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-selected-hover-alt.png"),
                                  url("assets/backdrop-check-selected-hover-alt@2.png"));
}

check:checked:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-selected-disabled.png"),
                                  url("assets/backdrop-check-selected-disabled@2.png"));
}

check row:selected:checked:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-selected-disabled-alt.png"),
                                  url("assets/backdrop-check-selected-disabled-alt@2.png"));
}

check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/check-mixed.png"),
                                  url("assets/check-mixed@2.png"));
}

check:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/check-mixed-hover.png"),
                                  url("assets/check-mixed-hover@2.png"));
}

check row:indeterminate,
check row:selected:indeterminate,
check row:selected:focus:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/check-mixed-alt.png"),
                                  url("assets/check-mixed-alt@2.png"));
}

check row:indeterminate:hover,
check row:selected:indeterminate:hover,
check row:selected:focus:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/check-mixed-hover-alt.png"),
                                  url("assets/check-mixed-hover-alt@2.png"));
}

check:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/check-mixed-disabled.png"),
                                  url("assets/check-mixed-disabled@2.png"));
}

check row:indeterminate:disabled,
check row:selected:indeterminate:disabled,
check row:selected:focus:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/check-mixed-disabled-alt.png"),
                                  url("assets/check-mixed-disabled-alt@2.png"));
}

check:indeterminate:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-mixed.png"),
                                  url("assets/backdrop-check-mixed@2.png"));
}

check:indeterminate:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-mixed-hover.png"),
                                  url("assets/backdrop-check-mixed-hover@2.png"));
}

check row:indeterminate:backdrop,
check row:selected:indeterminate:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-mixed-alt.png"),
                                  url("assets/backdrop-check-mixed-alt@2.png"));
}

check row:indeterminate:hover:backdrop,
check row:selected:indeterminate:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-mixed-hover-alt.png"),
                                  url("assets/backdrop-check-mixed-hover-alt@2.png"));
}

check:indeterminate:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-mixed-disabled.png"),
                                  url("assets/backdrop-check-mixed-disabled@2.png"));
}

check row:selected:indeterminate:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-check-mixed-disabled-alt.png"),
                                  url("assets/backdrop-check-mixed-disabled-alt@2.png"));
}

radio {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected.png"),
                                  url("assets/radio-unselected@2.png"));
}

radio:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-hover.png"),
                                  url("assets/radio-unselected-hover@2.png"));
}

radio row,
radio row:selected,
radio row:selected:focus {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-alt.png"),
                                  url("assets/radio-unselected-alt@2.png"));
}

radio row:hover,
radio row:selected:hover,
radio row:selected:focus:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-hover-alt.png"),
                                  url("assets/radio-unselected-hover-alt@2.png"));
}

radio:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-disabled.png"),
                                  url("assets/radio-unselected-disabled@2.png"));
}

radio row:disabled {
    background-color: transparent;
}

radio row:disabled,
radio row:selected:disabled,
radio row:selected:focus:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-unselected-disabled-alt.png"),
                                  url("assets/radio-unselected-disabled-alt@2.png"));
}

radio:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-unselected.png"),
                                  url("assets/backdrop-radio-unselected@2.png"));
}

radio:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-unselected-hover.png"),
                                  url("assets/backdrop-radio-unselected-hover@2.png"));
}

radio row:backdrop,
radio row:selected:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-unselected-alt.png"),
                                  url("assets/backdrop-radio-unselected-alt@2.png"));
}

radio row:hover:backdrop,
radio row:selected:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-unselected-hover-alt.png"),
                                  url("assets/backdrop-radio-unselected-hover-alt@2.png"));
}

radio:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-unselected-disabled.png"),
                                  url("assets/backdrop-radio-unselected-disabled@2.png"));
}

radio row:selected:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-unselected-disabled-alt.png"),
                                  url("assets/backdrop-radio-unselected-disabled-alt@2.png"));
}

radio:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected.png"),
                                  url("assets/radio-selected@2.png"));
}

radio:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected-hover.png"),
                                  url("assets/radio-selected-hover@2.png"));
}

radio row:checked,
radio row:selected:checked,
radio row:selected:focus:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected-alt.png"),
                                  url("assets/radio-selected-alt@2.png"));
}

radio row:checked:hover,
radio row:selected:checked:hover,
radio row:selected:focus:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected-hover-alt.png"),
                                  url("assets/radio-selected-hover-alt@2.png"));
}

radio:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected-disabled.png"),
                                  url("assets/radio-selected-disabled@2.png"));
}

radio row:disabled,
radio row:selected:checked:disabled,
radio row:selected:focus:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-selected-disabled-alt.png"),
                                  url("assets/radio-selected-disabled-alt@2.png"));
}

radio:checked:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-selected.png"),
                                  url("assets/backdrop-radio-selected@2.png"));
}

radio:checked:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-selected-hover.png"),
                                  url("assets/backdrop-radio-selected-hover@2.png"));
}

radio row:checked:backdrop,
radio row:selected:checked:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-selected-alt.png"),
                                  url("assets/backdrop-radio-selected-alt@2.png"));
}

radio row:checked:hover:backdrop,
radio row:selected:checked:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-selected-hover-alt.png"),
                                  url("assets/backdrop-radio-selected-hover-alt@2.png"));
}

radio:checked:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-selected-disabled.png"),
                                  url("assets/backdrop-radio-selected-disabled@2.png"));
}

radio row:selected:checked:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-selected-disabled-alt.png"),
                                  url("assets/backdrop-radio-selected-disabled-alt@2.png"));
}

radio:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed.png"),
                                  url("assets/radio-mixed@2.png"));
}

radio:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-hover.png"),
                                  url("assets/radio-mixed-hover@2.png"));
}

radio row:indeterminate,
radio row:selected:indeterminate,
radio row:selected:focus:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-alt.png"),
                                  url("assets/radio-mixed-alt@2.png"));
}

radio row:indeterminate:hover,
radio row:selected:indeterminate:hover,
radio row:selected:focus:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-hover-alt.png"),
                                  url("assets/radio-mixed-hover-alt@2.png"));
}

radio:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-disabled.png"),
                                  url("assets/radio-mixed-disabled@2.png"));
}

radio row:indeterminate:disabled,
radio row:selected:indeterminate:disabled,
radio row:selected:focus:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-disabled-alt.png"),
                                  url("assets/radio-mixed-disabled-alt@2.png"));
}

radio:indeterminate:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-mixed.png"),
                                  url("assets/backdrop-radio-mixed@2.png"));
}

radio:indeterminate:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-mixed-hover.png"),
                                  url("assets/backdrop-radio-mixed-hover@2.png"));
}

radio row:indeterminate:backdrop,
radio row:selected:indeterminate:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-mixed-alt.png"),
                                  url("assets/backdrop-radio-mixed-alt.png"));
}

radio row:indeterminate:hover:backdrop,
radio row:selected:indeterminate:hover:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-mixed-hover-alt.png"),
                                  url("assets/backdrop-radio-mixed-hover-alt@2.png"));
}

radio:indeterminate:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-mixed-disabled.png"),
                                  url("assets/backdrop-radio-mixed-disabled@2.png"));
}

radio row:selected:indeterminate:disabled:backdrop {
    -gtk-icon-source: -gtk-scaled(url("assets/backdrop-radio-mixed-disabled-alt.png"),
                                  url("assets/backdrop-radio-mixed-disabled-alt@2.png"));
}

.primary-toolbar menu check,
menubar toolbar menu check,
headerbar menu check,
menu check,
menu check:hover,
menu check:disabled:not(:checked),
menu check:indeterminate:not(:checked) {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-unselected.png"),
                                  url("assets/check-menuitem-unselected@2.png"));
}

.primary-toolbar menu radio,
menubar toolbar menu radio,
headerbar menu radio,
menu radio,
menu radio:hover,
menu radio:disabled:not(:checked),
menu radio:indeterminate:not(:checked) {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-unselected.png"),
                                  url("assets/check-menuitem-unselected@2.png"));
}

.primary-toolbar menu check:checked,
menubar toolbar menu check:checked,
headerbar menu check:checked,
menu check:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-dark.png"),
                                  url("assets/check-menuitem-dark@2.png"));
}

toolbar menu check:checked:hover,
menu check:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem.png"),
                                  url("assets/check-menuitem@2.png"));
}

.primary-toolbar menu check:checked:disabled,
menubar toolbar menu check:checked:disabled,
headerbar menu check:checked:disabled,
toolbar menu check:checked:hover:disabled,
menu check:checked:disabled,
menu check:checked:hover:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-insensitive.png"),
                                  url("assets/check-menuitem-insensitive@2.png"));
}

.primary-toolbar menu radio:checked,
menubar toolbar menu radio:checked,
headerbar menu radio:checked,
toolbar menu radio:checked:hover,
menu radio:checked,
menu radio:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem.png"),
                                  url("assets/radio-menuitem@2.png"));
}

.primary-toolbar menu radio:checked:disabled,
menubar toolbar menu radio:checked:disabled,
headerbar menu radio:checked:disabled,
toolbar menu radio:checked:hover:disabled,
menu radio:checked:disabled,
menu radio:checked:hover:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-insensitive.png"),
                                  url("assets/radio-menuitem-insensitive@2.png"));
}

toolbar menu check {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-unselected.png"),
                                  url("assets/check-menuitem-unselected@2.png"));
}

toolbar menu radio {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-unselected.png"),
                                  url("assets/check-menuitem-unselected@2.png"));
}

toolbar menu check:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-dark.png"),
                                  url("assets/check-menuitem-dark@2.png"));
}

toolbar menu check:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/check-menuitem-insensitive-dark.png"),
                                  url("assets/check-menuitem-insensitive-dark@2.png"));
}

toolbar menu radio:checked {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-dark.png"),
                                  url("assets/radio-menuitem-dark@2.png"));
}

toolbar menu radio:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("assets/radio-menuitem-insensitive-dark.png"),
                                  url("assets/radio-menuitem-insensitive-dark@2.png"));
}

/*********************
 * GtkScale's slider *
 *********************/
scale slider,
scale.horizontal contents:only-child trough slider {
    background-image: -gtk-scaled(url("assets/slider-horizontal.png"),
                                  url("assets/slider-horizontal@2.png"));
    background-repeat: no-repeat;
}

scale:backdrop slider,
scale.horizontal:backdrop slider {
     /*background-image: url("assets/slider-horizontal-disabled.png");*/
}

scale slider:hover,
scale.horizontal slider:hover {
    background-image: -gtk-scaled(url("assets/slider-horizontal-hover.png"),
                                  url("assets/slider-horizontal-hover@2.png"));
    background-repeat: no-repeat;
}

scale slider:focus,
scale.horizontal slider:focus {
    background-image: -gtk-scaled(url("assets/slider-horizontal-focused.png"),
                                  url("assets/slider-horizontal-focused@2.png"));
}

scale slider:hover:focus,
scale.horizontal slider:hover:focus {
    background-image: -gtk-scaled(url("assets/slider-horizontal-focused-hover.png"),
                                  url("assets/slider-horizontal-focused-hover@2.png"));
}

scale:disabled slider,
scale.horizontal:disabled slider {
    background-image: -gtk-scaled(url("assets/slider-horizontal-disabled.png"),
                                  url("assets/slider-horizontal-disabled@2.png"));
}

scale slider:disabled:backdrop,
scale.horizontal slider:disabled:backdrop {
    /*background-image: url("assets/slider-horizontal-backdrop-disabled.png");*/
}

scale.vertical slider {
    background-image: -gtk-scaled(url("assets/slider-vertical.png"),
                                  url("assets/slider-vertical@2.png"));
}

scale:backdrop.vertical slider {
    /*background-image: url("assets/slider-vertical-backdrop.png");*/
}

scale.vertical slider:hover {
    background-image: -gtk-scaled(url("assets/slider-vertical-hover.png"),
                                  url("assets/slider-vertical-hover@2.png"));
}

scale.vertical slider:focus {
    background-image: -gtk-scaled(url("assets/slider-vertical-focused.png"),
                                  url("assets/slider-vertical-focused@2.png"));
}

scale.vertical slider:hover:focus {
    background-image: -gtk-scaled(url("assets/slider-vertical-focused-hover.png"),
                                  url("assets/slider-vertical-focused-hover@2.png"));
}

scale:disabled.vertical slider {
    background-image: -gtk-scaled(url("assets/slider-vertical-disabled.png"),
                                  url("assets/slider-vertical-disabled@2.png"));
}

scale:disabled:backdrop.vertical slider {
    /*background-image: url("assets/slider-vertical-backdrop-disabled.png");*/
}

/*scale scale-has-marks-above.slider.horizontal {
    background-image: url("assets/slider-up.png");
}

scale scale-has-marks-above.slider.horizontal:disabled {
    background-image: url("assets/slider-up-disabled.png");
}

scale scale-has-marks-above.slider.horizontal:backdrop {
    background-image: url("assets/slider-up-backdrop.png");
}

scale scale-has-marks-above.slider.horizontal:backdrop:disabled {
    background-image: url("assets/slider-up-backdrop-disabled.png");
}

scale scale-has-marks-above.slider.vertical {
    background-image: url("assets/slider-left.png");
}

scale scale-has-marks-above.slider.vertical:disabled {
    background-image: url("assets/slider-left-disabled.png");
}

scale scale-has-marks-above.slider.vertical:backdrop {
    background-image: url("assets/slider-left-backdrop.png");
}

scale scale-has-marks-above.slider.vertical:backdrop:disabled {
    background-image: url("assets/slider-left-backdrop-disabled.png");
}

scale scale-has-marks-below.slider.horizontal {
    background-image: url("assets/slider-down.png");
}

scale scale-has-marks-below.slider.horizontal:disabled {
    background-image: url("assets/slider-down-disabled.png");
}

scale scale-has-marks-below.slider.horizontal:backdrop {
    background-image: url("assets/slider-down-backdrop.png");
}

scale scale-has-marks-below.slider.horizontal:backdrop:disabled {
    background-image: url("assets/slider-down-backdrop-disabled.png");
}

scale scale-has-marks-below.slider.vertical {
    background-image: url("assets/slider-right.png");
}

scale scale-has-marks-below.slider.vertical:disabled {
    background-image: url("assets/slider-right-disabled.png");
}

scale scale-has-marks-below.slider.vertical:backdrop {
    background-image: url("assets/slider-right-backdrop.png");
}

scale scale-has-marks-below.slider.vertical:backdrop:disabled {
    background-image: url("assets/slider-right-backdrop-disabled.png");
}*/

