panel-toplevel,
panel-plug {
    color: @dark_fg_color;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.15)),
                                     to (shade (@dark_bg_color, 0.95)));
}

panel-toplevel .gnome-panel-menu-bar:backdrop,
panel-toplevel .gnome-panel-menu-bar,
gp-applet > menubar,
gp-applet,
panel-applet > menubar,
panel-applet,
clock-box {
    background: transparent;
    color: @dark_fg_color;
}

gp-applet button:backdrop,
gp-applet button,
panel-applet button:backdrop,
panel-applet button {
    border-image: none;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.15)),
                                     to (shade (@dark_bg_color, 0.95)));    
    border-color: alpha (shade (@dark_bg_color, 0.9), 0.6);
    border-left-color: alpha (shade (@dark_bg_color, 1.2), 0.6);
    border-radius: 0;
    border-width: 0 1px 0 1px;

    color: @dark_fg_color;
    text-shadow: none;
}

#clock-applet-button {
  background: transparent;
  border: 0;
}

panel-applet button:active:hover:backdrop,
panel-applet button:active:hover,
panel-applet button:active:backdrop,
gp-applet button:active:hover:backdrop,
gp-applet button:active:hover,
gp-applet button:active:backdrop,
#clock-applet-button:active:hover,
#clock-applet-button:active {
    border-image: none;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.7)),
                                     to (shade (@dark_bg_color, 0.8))); 
    border-color: shade (@dark_bg_color, 0.7);
}

gp-applet button:hover:backdrop,
gp-applet button:hover,
panel-applet button:hover:backdrop,
panel-applet button:hover,
#clock-applet-button:hover {
    border-image: none;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.3)),
                                     to (shade (@dark_bg_color, 1.1))); 
    border-color: alpha (shade (@dark_bg_color, 0.9), 0.6);
    border-left-color: alpha (shade (@dark_bg_color, 1.2), 0.8);
}

gp-applet button:checked,
panel-applet button:checked,
#clock-applet-button:checked {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.8)),
                                     to (shade (@dark_bg_color, 1)));
}

gp-applet button:checked:hover,
panel-applet button:checked:hover,
#clock-applet-button:checked:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1)),
                                     to (shade (@dark_bg_color, 1.1)));
}

gp-applet button:checked:hover:active,
panel-applet button:checked:hover:active,
#clock-applet-button:checked:hover:active {
    border-image: none;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.6)),
                                     to (shade (@dark_bg_color, 0.7))); 
    border-color: shade (@dark_bg_color, 0.8);
}

clock-box {
    text-shadow: 0 1px shade (@dark_bg_color, 1.08);
}

wnck-pager,
wnck-tasklist {
    background-color: @dark_bg_color;
}

gp-arrow-button {
  min-width: 20px;
  min-height: 0px;

  border: 1px solid #9d9d99;
  border-radius: 3px;
  background-image: linear-gradient(to bottom, #e8e8e7, #dededd 60%, #cfcfcd);
  margin: 2px;
}

.vertical gp-arrow-button {
  min-width: 0px;
  min-height: 20px;
}

gp-arrow-button:hover {
  background-image: linear-gradient(to bottom, #f7f7f7, #e8e8e7 60%, #dededd);
}

gp-arrow-button:active {
  background-image: linear-gradient(to bottom, #c8c8c5, #dcdcda);
}

panel-toplevel.background:backdrop {
  box-shadow: none;
}
