# ==============================================================================
# BANSHEE SPECIFIC SETTINGS
# ==============================================================================

style "banshee_scrollbar" {
	engine "murrine" {
		roundness = 20
	}
}

widget    "__gtksharp_1*SeekSlider*"    style "scale"
widget    "__gtksharp_1*Player*croll*"      style "banshee_scrollbar"

widget_class    "__gtksharp_1*<GtkToolbar>*"    style "default"
widget_class    "__gtksharp_1*<GtkButton>*"     style "button"
#widget_class    "__gtksharp_1*<GtkScale>*"      style "scale"







