/* gnome-terminal */
@define-color terminal_bg #300a24;

vte-terminal.terminal-screen {
    -TerminalScreen-background-darkness: 0.95;
    background-color: @terminal_bg;
    color: #fff;
}

terminal-screen-container scrollbar:hover,
terminal-screen-container scrollbar:active {
    background-color: alpha(@scrollbar_track_color, 0.4);
    border-radius: 1px;
}

terminal-screen-container {
    background-color: transparent;
}

notebook.terminal-notebook header {
    background-color: @dark_bg_color;
    border: none;
}


notebook.terminal-notebook header.top tab,
notebook.terminal-notebook header.top tab:hover {
    background-color: shade(@bg_color, 0.75);
    border-width: 1px 1px 0px 1px;
    border-radius:  8px 8px 0px 0px;
    border-image: none;
    border-style: solid;
    border-color: @dark_bg_color;
}

notebook.terminal-notebook header.top tab:checked {
    background-color: shade(@bg_color, 1.2);
}

notebook.terminal-notebook tab button,
notebook.terminal-notebook tab button:hover {
    background-color: transparent;
    padding: 1px;
}

notebook.terminal-notebook > header > box,
notebook.terminal-notebook > header > box:hover {
    padding-left: 5px;
}

notebook.terminal-notebook > header > box button,
notebook.terminal-notebook > header > box button:hover,
notebook.terminal-notebook > header > box button:hover:backdrop {
    background: inherit;
    border: inherit;
    padding: inherit;
}

notebook.terminal-notebook > header > box > box > button:not(:last-child):hover,
notebook.terminal-notebook > header > box > box > button:not(:last-child):hover:backdrop,
notebook.terminal-notebook > header > box > box > button:not(:last-child) {
    padding-right: 5px;
}

notebook.terminal-notebook > header > box button:hover,
notebook.terminal-notebook > header > box button:hover:backdrop {
    color: shade (@bg_color, 0.9);
}

notebook.terminal-notebook > header > box button {
    color: shade (@bg_color, 0.7);
}

notebook.terminal-notebook > header > box button:backdrop {
    color: shade (@bg_color, 0.4);
}
