* {
    -GtkHTML-link-color: #f07746; /* @link_color */
    -GtkIMHtml-hyperlink-color: #f07746; /* @link_color */
    -GtkTextView-error-underline-color: #df382c; /* @error_color doesn't work due to a gtk bug */
    -WnckTasklist-fade-overlay-rect: 0;

    background-origin: border-box;
    background-clip: padding-box;
}

.background {
    color: @fg_color;
    background-color: @bg_color;
}

.background:backdrop {
    color: @backdrop_fg_color;
    box-shadow: inset -1px 0 shade (@bg_color, 0.94);
}

assistant .sidebar .highlight {
        color: @fg_color;
        font: bold;
}

assistant .sidebar {
        background-color: shade (@bg_color, 0.97);
        border-right-color: shade (@bg_color, 0.8);
        border-radius: 0;
        border-style: solid;
        border-width: 0 1px 0 0;
        padding: 12px;

        color: mix (@fg_color, @bg_color, 0.40);
        text-shadow: 0 1px shade (@bg_color, 1.04);
        box-shadow: inset -1px 0 shade (@bg_color, 0.94);
}

/**********
 * button *
 **********/
button {
    padding: 5px 6px;

    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@button_bg_color, 1.08)),
                                     color-stop (0.5, @button_bg_color),
                                     to (shade (@button_bg_color, 0.94)));

    color: @fg_color;
    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.4);

    border: 1px solid transparent;
    border-radius: 8px;
    border-image-source: url("assets/button.png");

    /* all button border images have the same size and are sliced in the same way */
    border-image-width: 10px 12px 10px 12px;
    border-image-slice: 10 12 10 12;
    border-image-repeat: stretch;
}

button.flat {
    background-image: none;
    border-image-source: none;
    border-color: transparent;
}

button:backdrop {
    background-image: none;
    background-color: @bg_color;
    border-image-source: url("assets/backdrop-button.png");

    color: @backdrop_fg_color;
    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.2);
}

button.flat:backdrop {
    border-image-source: none;
}

button:focus {
    border-image-source: url("assets/button-focused.png");
}

button:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@button_bg_color, 1.12)),
                                     color-stop (0.5, @button_bg_color),
                                     to (shade (@button_bg_color, 0.96)));
    border-image-source: url("assets/button-hover.png");
}

button:hover:backdrop {
    background-color: shade (@bg_color, 1.04);
    border-image-source: url("assets/backdrop-button-hover.png");
}

button:hover:focus {
    border-image-source: url("assets/button-focused-hover.png");
}


button:disabled {
    background-image: none;
    background-color: mix (#ebebeb, @bg_color, 0.5);

    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.4);
    border-image-source: url("assets/button-disabled.png");
}

button:disabled:backdrop {
    background-color: #ebebeb;

    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.2);
    border-image-source: url("assets/backdrop-button-disabled.png");
}

button.flat:disabled,
button.flat:disabled:backdrop {
    background-color: transparent;
    border-image-source: none;
}

button:checked {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#cecece),
                                     to (#e8e8e8));
    border-image-source: url("assets/button-active.png");
}

button:checked:focus {
    border-image-source: url("assets/button-active-focused.png");
}

button:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#dcdcdc),
                                     to (#f3f3f3));
    border-image-source: url("assets/button-active-hover.png");
}

button:active:focus {
    border-image-source: url("assets/button-active-focused-hover.png");
}

button:checked:disabled,
button:active:disabled {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#e3e3e3),
                                     to (#f3f3f3));
    border-image-source: url("assets/button-active-disabled.png");
}

button:checked:backdrop {
    border-image-source: url("assets/backdrop-button-active.png");
}

button:active:backdrop {
    border-image-source: url("assets/backdrop-button-active-hover.png");
}

button:checked:disabled:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (mix (#e3e3e3, @bg_color, 0.5)),
                                     to (mix (#f3f3f3, @bg_color, 0.5)));
    border-image-source: url("assets/backdrop-button-active-disabled.png");
}

/*
button.default {
    border-image-source: url("assets/button-default.png");
}

button.default:hover {
    border-image-source: url("assets/button-default-hover.png");
}

button.default:focus {
    border-image-source: url("assets/button-default-focused.png");
}

button.default:focus:hover {
    border-image-source: url("assets/button-default-focused-hover.png");
}
*/

button.destructive-action {
    background-image: linear-gradient(to bottom, #e03d3d, #ef2929);
    border-color: #8e0b0b;
    border-image: none;
    color: white;
    -gtk-icon-shadow: 0 1px shade(#9d4242, 1.15);
    outline-color: rgba(255, 255, 255, 0.3);
    text-shadow: 0 1px shade(#9d4242, 1.15);
}

/******************
 * Linked Widgets *
 *****************/
.linked entry,
.linked button,
.linked combobox box.linked button,
combobox entry + box.linked button {
    border-radius: 0;
    border-image-width: 10px 0 10px 0;
    border-width: 1px 0 1px 0;
    box-shadow: inset -1px 0 shade (@bg_color, 0.84);
}

.linked entry:first-child,
.linked button:first-child,
.linked combobox:first-child box.linked button,
combobox:first-child entry + box.linked button {
    border-image-width: 10px 0 10px 12px;
    border-radius: 8px 0 0 8px;
}

.linked entry:last-child,
.linked button:last-child,
.linked combobox:last-child box.linked button,
combobox:last-child entry + box.linked button {
    border-image-width: 10px 12px 10px 0;
    border-radius: 0 8px 8px 0;
    box-shadow: none;
}

.linked entry:only-child,
.linked button:only-child,
.linked combobox:only-child box.linked button,
combobox:only-child entry + box.linked button {
    border-image-width: 10px 12px 10px 12px;
    border-radius: 8px;
}

.primary-toolbar .linked button,
headerbar .linked button {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 1.4),
                inset -1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked button:first-child,
headerbar .linked button:first-child {
    box-shadow: inset -1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked button:last-child,
headerbar .linked button:last-child {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 1.4)
}

.primary-toolbar .linked button:active,
headerbar .linked button:active,
.primary-toolbar .linked button:disabled,
headerbar .linked button:disabled {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked button:only-child,
headerbar .linked button:only-child {
    box-shadow: none;
}

*:link,
*:visited {
  color: @link_color;
}

button separator { 
	color: shade(@bg_color, 1.30);
}

/* actionbar */
actionbar > revealer > box {
    padding: 6px;
    border-top: 1px solid @borders;
}

actionbar > revealer > box:backdrop {
    border-color: shade(@borders, 0.8);
}

/**************
 * ComboBoxes *
 **************/

combobox {
	padding: 0;
	text-shadow: 0 1px @button_text_shadow;
}

combobox:disabled {
	text-shadow: none;
	color: @insensitive_fg_color;
}

arrow {
    min-height: 16px;
    min-width: 16px;
    color: black;
}

combobox arrow {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

combobox arrow:disabled,
combobox arrow:backdrop {
    color: @insensitive_fg_color;
}

/* calendar */
calendar {
    background-color: white;
    border: 1px solid @borders;
}

/****************
 * cell and row *
 ****************/
.cell checkbutton check {
	margin: 3px;
}

.cell {
    background-color: @base_color;
    border-radius: 0;
    border-width: 0;
}

row:selected {
    background-image: -gtk-gradient (linear, left bottom, left top,
                                     from (shade (@selected_bg_color, 1.06)),
                                     to (shade (@selected_bg_color, 0.94)));
    border-top-color: shade (@selected_bg_color, 0.88);
    border-style: solid;
    border-width: 1px 0 0 0;
}

row:selected:backdrop {
    background-image: -gtk-gradient (linear, left bottom, left top,
                                     from (shade (@backdrop_selected_bg_color, 1.06)),
                                     to (shade (@backdrop_selected_bg_color, 0.94)));
    border-top-color: shade (@backdrop_selected_bg_color, 0.9);
    color: @backdrop_selected_fg_color;
}

/*******************
 * check and radio *
 *******************/

check, radio {
    min-height: 14px;
    min-width: 14px;
    margin: 0 4px;
}

/* Draw a focus ring around the contained label ... */
checkbutton.text-button label {
    border: 1px solid transparent;
    border-radius: 5px;
}

checkbutton.text-button:focus label {
    border-color: @focus_color;
    background-color: @focus_bg_color;
}

checkbutton check, radiobutton radio {
	margin-left: 4px;
	margin-right: 4px;
}

/* ... unless it's a proper button, which already has a focus-colored border */
button.text-button:focus label {
    border: none;
    background: none;
}

menu radio * {
    box-shadow: none;
}

/*******************
 * treeview header *
 *******************/

treeview.view header button,
treeview.view header button:active {
    border-radius: 0;
    border-width: 0 1px 1px 0;
    border-image: none;
}

treeview.view header button {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.06)),
                                     to (shade (@bg_color, 1.04)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@bg_color, 0.99)),
                                 to (shade (@bg_color, 0.9))) 1;
    box-shadow: inset -1px 0 shade (@bg_color, 1.1),
                inset 0 -1px shade (@bg_color, 1.1);

    text-shadow: 0 1px alpha (shade (@bg_color, 1.25), 0.4);
}

treeview.view header button:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.04)),
                                     to (shade (@bg_color, 1.02)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@bg_color, 0.94)),
                                 to (shade (@bg_color, 0.88))) 1;
    box-shadow: inset -1px 0 shade (@bg_color, 1.03),
                inset 0 -1px shade (@bg_color, 1.03);
}

treeview.view header button:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.13)),
                                     to (shade (@bg_color, 1.08)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@bg_color, 0.99)),
                                 to (shade (@bg_color, 0.9))) 1;
}

treeview.view header button:hover:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.1)),
                                     to (shade (@bg_color, 1.06)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@bg_color, 0.99)),
                                 to (shade (@bg_color, 0.9))) 1;
}

treeview.view header button:last-child {
    border-width: 0 0 1px 0;
}

/****************
 * Content view *
 ****************/
.content-view.view {
    background-color: shade (@bg_color, 1.01);
}

.content-view.view:hover {
    background-color: shade (@bg_color, 1.03);
}

.view.cell:selected,
.view.cell:active,
.view:selected,
.view:active,
.content-view.view:selected,
.content-view.view:active {
    background-color: @selected_bg_color;
}

.content-view.view:disabled {
    background-color: @bg_color;
}

.content-view.view:backdrop {
    background-color: @bg_color;
}

.content-view.view:selected:backdrop {
    background-color: @backdrop_selected_bg_color;
}

:not(iconview).view.cell:disabled,
.content-view.view:disabled {
    background-color: @bg_color;
}

:not(iconview).view.cell:backdrop,
.content-view.view:backdrop {
    background-color: @bg_color;
}

:not(iconview).view.cell:selected:backdrop,
.content-view.view:selected:backdrop {
    background-color: @backdrop_selected_bg_color;
}

/*********
 * entry *
 *********/
entry {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@base_color, 0.96)),
                                     to (@base_color));
    padding: 5px 7px;

    color: @text_color;
}

entry.flat, entry.flat:focus {
    padding: 2px;
}

entry:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (mix (shade (@base_color, 0.96), @bg_color, 0.5)),
                                     to (mix (@base_color, @bg_color, 0.5)));
    color: @backdrop_text_color;
}

entry:selected,
entry:selected:focus {
    background-color: @selected_bg_color;
    color: @selected_fg_color;
}

entry:disabled {
    background-color: #f5f5f5;
    background-image: none;

    color: mix (@text_color, @base_color, 0.4);
}

entry.read-only {
    background-color: #f5f5f5;
    background-image: none;
}

entry:disabled:backdrop {
    background-color: mix (#f5f5f5, @bg_color, 0.5);

    color: mix (@text_color, @base_color, 0.4);
}

.primary-toolbar entry progress,
headerbar entry progress {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 0.8)),
                                     color-stop (0.1, shade (@selected_bg_color, 0.9)),
                                     to (shade (@selected_bg_color, 1.1)));
    border-width: 0;

    color: @selected_fg_color;
}

/* Application notification */
.app-notification,
.app-notification.frame {
    padding: 3px;
    border-width: 0 1px 1px;
    border-style: solid;
    background-color: @bg_color;
}

/************
 * expander *
 ************/

expander {
    color: @fg_color;
}

expander arrow {
    min-width: 16px;
    min-height: 16px;
    margin-right: 5px;
    -gtk-icon-style: regular;
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

expander arrow:dir(rtl) {
    margin-left: 5px;
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

expander arrow:hover {
    color: shade(@fg_color, 0.5);
}

expander arrow:checked {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

/*********
 * frame *
 *********/
.frame {
    border-radius: 3px;
    border-width: 1px;
    border-style: solid;
    border-color: shade (@bg_color, 0.82);
    border-image: none;
    background: none;
}

notebook.frame {
    border: none;
}

/* XXX: this is a copy of the above; adding notebook.frame stack there didn't
 * work */
frame border, notebook.frame > stack {
    border-radius: 3px;
    border-width: 1px;
    border-style: solid;
    border-color: shade (@bg_color, 0.82);
    border-image: none;
    background: none;
}

.frame.flat, frame border.flat {
    border: none;
}

scrolledwindow > viewport.frame,
frame > box > stack > scrolledwindow {
    border-style: none;
}

frame > box.vertical > scrolledwindow.frame {
    border-width: 1px 0px 1px 0px;
}


/****************
 * window-frame *
 ****************/

.csd.popup {
    border-style: none;
    border-radius: 0;
    box-shadow: 0 3px 8px @shadow_color;
}

/************
 * iconview *
 ************/

.view {
    background-color: @base_color;
    color: @text_color;
}

iconview.view.cell:selected,
iconview.view.cell:selected:focus {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 1.0)),
                                     to (shade (@selected_bg_color, 0.9)));
    border-radius: 5px;
    border-style: solid;
    border-width: 1px;
    border-color: shade (@selected_bg_color, 0.8);
    border-bottom-color: shade (@selected_bg_color, 0.7);

    box-shadow: inset 1px 0 shade (@selected_bg_color, 1),
                inset -1px 0 shade (@selected_bg_color, 1),
                inset 0 1px shade (@selected_bg_color, 1.08),
                inset 0 -1px shade (@selected_bg_color, 1.0);
}

.rubberband,
rubberband {
    background-color: alpha (@selected_bg_color, 0.35);
    border-color: @selected_bg_color;
    border-radius: 0;
    border-style: solid;
    border-width: 1px;
}

iconview.cell {
    background-color: transparent;
}

/***********
 * infobar *
 ***********/
.info {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@info_bg_color, 1.04)),
                                     to (shade (@info_bg_color, 0.96)));
    border-style: solid;
    border-width: 1px;

    color: @info_fg_color;

    border-color: shade (@info_bg_color, 0.8);
    border-bottom-color: shade (@info_bg_color, 0.75);

    box-shadow: inset 1px 0 shade (@info_bg_color, 1.08),
                inset -1px 0 shade (@info_bg_color, 1.08),
                inset 0 1px shade (@info_bg_color, 1.1),
                inset 0 -1px shade (@info_bg_color, 1.04);
}

.warning {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@warning_bg_color, 1.04)),
                                     to (shade (@warning_bg_color, 0.96)));
    border-style: solid;
    border-width: 1px;

    color: @warning_fg_color;

    border-color: shade (@warning_bg_color, 0.8);
    border-bottom-color: shade (@warning_bg_color, 0.75);

    box-shadow: inset 1px 0 shade (@warning_bg_color, 1.08),
                inset -1px 0 shade (@warning_bg_color, 1.08),
                inset 0 1px shade (@warning_bg_color, 1.1),
                inset 0 -1px shade (@warning_bg_color, 1.04);
}

.question {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@question_bg_color, 1.04)),
                                     to (shade (@question_bg_color, 0.96)));
    border-style: solid;
    border-width: 1px;

    color: @question_fg_color;

    border-color: shade (@question_bg_color, 0.8);
    border-bottom-color: shade (@question_bg_color, 0.75);

    box-shadow: inset 1px 0 shade (@question_bg_color, 1.08),
                inset -1px 0 shade (@question_bg_color, 1.08),
                inset 0 1px shade (@question_bg_color, 1.1),
                inset 0 -1px shade (@question_bg_color, 1.04);
}

.error {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@error_bg_color, 1.04)),
                                     to (shade (@error_bg_color, 0.96)));
    border-style: solid;
    border-width: 1px;

    color: @error_fg_color;

    border-color: shade (@error_bg_color, 0.8);
    border-bottom-color: shade (@error_bg_color, 0.75);

    box-shadow: inset 1px 0 shade (@error_bg_color, 1.08),
                inset -1px 0 shade (@error_bg_color, 1.08),
                inset 0 1px shade (@error_bg_color, 1.1),
                inset 0 -1px shade (@error_bg_color, 1.04);
}

/********
 * menu *
 ********/
toolbar headerbar menu,
.primary-toolbar button menu,
headerbar button menu,
menu {
    background-image: none;
    background-color: shade (@dark_bg_color, 1.08);
    border-bottom-color: shade (@dark_bg_color, 0.96);
    border-left-color: shade (@dark_bg_color, 0.8);
    border-right-color: shade (@dark_bg_color, 0.8);
    border-top-color: shade (@dark_bg_color, 0.96);
    padding: 0;
    border-width: 1px;
    border-style: solid;

    color: @dark_fg_color;

    box-shadow: inset 0 1px shade (@dark_bg_color, 1.18),
                inset 0 -1px shade (@dark_bg_color, 1.18),
                inset -1px 0 shade (@dark_bg_color, 1.16),
                inset 1px 0 shade (@dark_bg_color, 1.18);

    margin: 1px;
}

menu arrow {
    color: @dark_fg_color;
}

toolbar menu,
combobox menu {
    background-image: none;
    background-color: @bg_color;
    border-bottom-color: shade (@bg_color, 0.66);
    border-right-color: shade (@bg_color, 0.7);
    border-top-color: shade (@bg_color, 0.8);
    border-style: solid;
    padding: 0;

    color: @fg_color;

    box-shadow: inset -1px 0 shade (@bg_color, 1.18),
                inset 1px 0 shade (@bg_color, 1.18),
                inset 0 1px shade (@bg_color, 1.18);
}

menu:selected {
    background-color: @selected_bg_color;
}

menu button:hover,
menu button:checked,
menu button:checked:disabled,
menu button:disabled,
menu button
{
    background-color: shade (@dark_bg_color, 1.08);
    background-image: none;
    border-radius: 0;
    border-style: none;
    border-width: 1px;
}

.context-menu {
    font: regular medium;
}

/***********
 * menubar *
 ***********/
menubar,
.menubar {
    -GtkWidget-window-dragging: true;

    background-color: @dark_bg_color;
    background-image: none;
    border-width: 0;

    color: @dark_fg_color;
    text-shadow: 0 -1px shade (@dark_bg_color, 0.6);
    min-height: 24px;
}

menubar:backdrop,
.menubar:backdrop {
    color: @backdrop_dark_fg_color;
    text-shadow: 0 -1px shade (@dark_bg_color, 0.8);
}

menubar menuitem:hover,
.menubar.menuitem:hover,
.menubar .menuitem:hover {
    background-color: transparent;
    background-clip: border-box;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.38)),
                                     to (shade (@dark_bg_color, 1.11)));

    box-shadow: inset 0 1px 1px 0 shade (@dark_bg_color, 1.8);

    color: shade (@dark_fg_color, 1.1);
    text-shadow: 0 -1px shade (@dark_bg_color, 0.7);
}

/************
 * menuitem *
 ************/
menuitem {
    padding: 0px;
    background: transparent;
    border-radius: 0;
    padding: 3px 5px 3px 5px;

    text-shadow: none;
}

/* Workaround for lp:949368 */
combobox menuitem * {
    color: @fg_color;
}

combobox menuitem *:hover {
    color: @selected_fg_color;
}


popover modelbutton:hover,
popover menuitem:checked:hover,
menuitem:hover,
menu menuitem:hover {
    border-radius: 0;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 1.1)),
                                     to (shade (@selected_bg_color, 0.9)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@selected_bg_color, 0.7)),
                                 to (shade (@selected_bg_color, 0.7))) 1;
    border-image-width: 1px;
    box-shadow: inset 1px 0 shade (@selected_bg_color, 1.02),
                inset -1px 0 shade (@selected_bg_color, 1.02),
                inset 0 1px shade (@selected_bg_color, 1.16),
                inset 0 -1px shade (@selected_bg_color, 0.96);

    color: @selected_fg_color;
    text-shadow: 0 -1px shade (@selected_bg_color, 0.7);
}

menuitem check:checked,
menuitem radio:checked {
    color: @fg_color;
}

menu menuitem check:hover,
menu menuitem radio:hover {
    box-shadow: none;
}

toolbar headerbar menu menuitem:disabled,
toolbar headerbar menu menuitem *:disabled,
toolbutton menu menuitem:disabled,
toolbutton menu menuitem *:disabled,
.primary-toolbar button menu menuitem:disabled,
.primary-toolbar button menu menuitem *:disabled,
headerbar button menu menuitem:disabled,
headerbar button menu menuitem *:disabled,
menuitem:disabled,
menuitem *:disabled {
    color: mix (@dark_fg_color, @dark_bg_color, 0.5);
    text-shadow: 0 -1px shade (@dark_bg_color, 0.6);
}

toolbar menu menuitem:disabled,
toolbar menu menuitem *:disabled,
combobox  menu menuitem:disabled,
combobox  menu menuitem *:disabled {
    color: mix (@fg_color, @bg_color, 0.5);
    text-shadow: 0 1px shade (@bg_color, 1.14);
}

menuitem calendar,
menuitem calendar .button,
menuitem calendar .header,
menuitem calendar .view {
    background-color: @dark_bg_color;
    background-image: none;
    border-radius: 0;
    border-style: solid;
    border-width: 0;
    padding: 1px;

    color: @dark_fg_color;
}

menuitem calendar {
    background-color: shade (@dark_bg_color, 1.3);
    background-image: none;
}

menuitem calendar:indeterminate {
    color: shade (@bg_color, 0.6);
}

menuitem entry {
    background-color: shade (@dark_bg_color, 1.3);
    background-image: none;

    color: @dark_fg_color;

    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@dark_bg_color, 0.75)),
                                 to (shade (@dark_bg_color, 0.9))) 1;
    border-image-width: 1px;
}

.primary-toolbar scale trough,
.primary-toolbar scale trough:backdrop,
headerbar scale trough,
headerbar scale trough:backdrop,
menuitem scale trough {
    background-color: @dark_bg_color;
    background-image: none;
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@dark_bg_color, 0.75)),
                                 to (shade (@dark_bg_color, 1.15))) 1;
    border-image-width: 1px;
}

menuitem accelerator {
    color: alpha (@dark_fg_color, 0.5);
}

menuitem accelerator:hover {
    color: alpha (@selected_fg_color, 0.8);
}

menuitem accelerator:disabled {
    color: alpha (mix (@dark_fg_color, @dark_bg_color, 0.5), 0.5);
    text-shadow: 0 -1px shade (@dark_bg_color, 0.7);
}

menuitem > box > image + label {
    padding-left: 6px;
}

/************
 * notebook *
 ************/
notebook header.top tab { padding: 4px 6px 2px 6px; }
notebook header.top tab:checked { padding-bottom: 3px; }
notebook header.bottom tab { padding: 2px 6px 4px 6px; }
notebook header.bottom tab:checked { padding-top: 3px; }
notebook header.left tab { padding: 2px 4px 2px 6px; }
notebook header.left tab:checked { padding-right: 5px; }
notebook header.right tab { padding: 2px 6px 2px 4px; }
notebook header.right tab:checked { padding-left: 5px; }

notebook header {
    border-width: 0; /* set below depending on position of tab bar */
    border-color: shade (@bg_color, 0.82);
    border-style: solid;
}

/* Draw a border between tabs and content ... */
notebook:not(.frame) header.top { border-bottom-width: 1px; }
notebook:not(.frame) header.right { border-left-width: 1px; }
notebook:not(.frame) header.left { border-right-width: 1px; }
notebook:not(.frame) header.bottom { border-top-width: 1px; }

notebook.frame header.top { border-bottom: 1px solid @bg_color; }

notebook header.top tab {
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (alpha (shade (@bg_color, 0.9), 0.0)),
                                 to (shade (@bg_color, 0.9))) 1;
    border-image-width: 0 1px;
}

notebook header.top tab:checked,
notebook header.top tab:checked:hover {
    background-image: linear-gradient(to bottom,
                                      shade(@bg_color, 1.075),
                                      shade(@bg_color, 1));
    border-radius: 4px 4px 0px 0px;
    border-width: 0px 1px 0px 1px;
    border-style: solid;
    border-color: @borders;
}

notebook header.right tab {
    border-image: -gtk-gradient (linear, right top, left top,
                                 from (alpha (shade (@bg_color, 0.9), 0.0)),
                                 to (shade (@bg_color, 0.9))) 1;
    border-image-width: 1px 0;
}

notebook header.right tab:checked,
notebook header.right tab:checked:hover {
    background-image: linear-gradient(to left,
                                      shade(@bg_color, 1.075),
                                      shade(@bg_color, 1));
    border-radius:  0px 4px 4px 0px;
    border-width: 1px 0px 1px 0px;
    border-color: shade(@bg_color, 0.95);
}

notebook header.left tab {
    border-image: -gtk-gradient (linear, left top, right top,
                                 from (alpha (shade (@bg_color, 0.9), 0.0)),
                                 to (shade (@bg_color, 0.9))) 1;
    border-image-width: 1px 0;
}

notebook header.left tab:checked,
notebook header.left tab:checked:hover {
    background-image: linear-gradient(to right,
                                      shade(@bg_color, 1.075),
                                      shade(@bg_color, 1));
    border-radius: 4px 0px 0px 4px;
    border-width: 1px 0px 1px 0px;
    border-color: shade(@bg_color, 0.95);
}

notebook header.bottom tab {
    border-image: -gtk-gradient (linear, left bottom, left top,
                                 from (alpha (shade (@bg_color, 0.9), 0.0)),
                                 to (shade (@bg_color, 0.9))) 1;
    border-image-width: 0 1px;
}

notebook header.bottom tab:checked,
notebook header.bottom tab:checked:hover {
    background-image: linear-gradient(to top,
                                      shade(@bg_color, 1.075),
                                      shade(@bg_color, 1));
    border-radius: 0 0 4px 4px;
    border-width: 0px 1px 0px 1px;
    border-style: solid;
    border-color: shade(@bg_color, 0.95);
}

/* Draw a focus ring around labels in tabs */
notebook tab label {
    border: 1px solid transparent;
    border-radius: 5px;
}

notebook:focus tab:checked label {
    border-color: @focus_color;
    background-color: @focus_bg_color;
}

notebook GtkDrawingArea {
        background-color: shade (@bg_color, 1.02);
}

/******************
 * pane separator *
 ******************/

paned separator {
    background-color: transparent;
    border-color: shade (@bg_color, 0.84);
}

/************
 * Pathbars *
 ************/
.path-bar button.text-button,
.path-bar button.image-button,
.path-bar button {
  padding-left: 4px;
  padding-right: 4px;
}

.path-bar button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0;
}

.path-bar button.text-button.image-button label:last-child,
.path-bar button label:last-child {
  padding-right: 8px;
}

.path-bar button.text-button.image-button label:first-child,
.path-bar button label:first-child {
  padding-left: 8px;
}

.path-bar button image {
  padding-left: 4px;
  padding-right: 4px;
}

.path-bar button.slider-button {
  padding-left: 0;
  padding-right: 0;
}


/*************************
 * progressbar and scale *
 *************************/
.progressbar,
scale,
progressbar {
    border-radius: 8px;
    border-width: 0px;
    padding: 3px;
}

menubar menuitem scale highlight.left,
scale highlight.left,
progressbar trough progress,
row progressbar,
row:hover progressbar,
row:selected progressbar,
row:selected:focus progressbar,
row:nth-child(odd) progressbar,
.progressbar,
.progressbar row,
.progressbar row:hover,
.progressbar row:selected,
.progressbar row:selected:focus,
.progressbar row:nth-child(odd),
entry progress {
    border-radius: 5px;
    border-style: solid;
    border-width: 1px;
    background-image: linear-gradient(to bottom,
                                      @progressbar_fill_a,
                                      @progressbar_fill_b);
    border-top-color: shade(@button_border_active, 0.80);
    border-left-color: shade(@button_border_active, 0.85);
    border-right-color: shade(@button_border_active, 0.85);
    border-bottom-color: shade(@button_border_active, 0.80);
    color: @theme_fg_color;
    text-shadow: none;
}

row:backdrop progressbar,
row:hover:backdrop progressbar,
row:selected:backdrop progressbar,
row:selected:focus:backdrop progressbar,
.progressbar:backdrop,
.progressbar row:backdrop,
.progressbar row:hover:backdrop,
.progressbar row:selected:backdrop,
.progressbar row:selected:focus:backdrop,
.progresbar.vertical:backdrop,
progressbar:backdrop trough progress,
scale highlight.bottom:backdrop,
progressbar.vertical:backdrop trough progress {
    background-image: linear-gradient(to bottom,
                                      @progressbar_fill_a,
                                      @progressbar_fill_b);
    color: @backdrop_fg_color;
    text-shadow: none;
}

scale highlight.left:disabled {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 0.95)),
                                     to (shade (@bg_color, 0.85)));
}

scale highlight.bottom:disabled {
    background-image: -gtk-gradient (linear, left top, right top,
                                     from (shade (@bg_color, 0.95)),
                                     to (shade (@bg_color, 0.85)));
}

.trough,
trough,
trough row,
trough row:hover,
trough row:selected,
trough row:selected:focus {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#d1d1d1),
                                     to (#e8e8e8));
    border-style: solid;
    border-width: 1px;

    color: @text_color;
}

.trough.vertical,
trough.vertical {
    background-image: -gtk-gradient (linear, left top, right top,
                                     from (#d1d1d1),
                                     to (#e8e8e8));
}

/* level bars as used for password quality or remaining power */

levelbar {
    min-width: 34px;
    min-height: 5px;
}

levelbar.vertical {
    min-width: 5px;
    min-height: 34px;
}

levelbar trough {
    padding: 2px;
    border-radius: 2px;
    box-shadow: none;
}

levelbar.horizontal block {
    min-height: 3px;
}

levelbar.vertical block {
    min-width: 3px;
}

levelbar block.filled {
    border-width: 1px;
    border-style: solid;

    border-color: @selected_bg_color;
    background-color: #db6a3c;
}

levelbar.continuous block.filled {
    padding: 2px;
    border-radius: 2px;
}

levelbar block.filled:backdrop,
levelbar block.filled.high:backdrop,
levelbar block.filled.low:backdrop {
    background-color: @backdrop_filling_bg;
    border-color: @backdrop_filling_bg;
    background-image: none;
}


levelbar.horizontal.discrete block.filled {
    margin: 0 1px;
}

levelbar.vertical.discrete block.filled {
    margin: 1px 0;
}

levelbar block.filled.high {
    border-color: shade(@success_color, 0.85);
    background-image: linear-gradient(to bottom,
                                      shade(@success_color, 1.2),
                                      @success_color 75%,
                                      shade(@success_color, 0.95)
                                      );
}

levelbar block.filled.low {
    border-color: shade(@warning_bg_color, 0.80);
    background-image: linear-gradient(to bottom,
                                      shade(@warning_bg_color, 1.3),
                                      @warning_bg_color 75%,
                                      shade(@warning_bg_color, 0.90)
                                      );
}

levelbar block.filled.empty {
    background-color: transparent;
    background-image: none;
    border-color: alpha(@bg_color, 0.1);
}

levelbar block.filled.empty:backdrop {
    border-color: transparent;
    background-color: transparent;
}

/************
 * GtkScale *
 ************/

scale.vertical {
    min-width: 13px;
}

scale.horizontal {
    min-height: 13px;
}

scale.horizontal trough {
    min-height: 3px;
    border-radius: 6px;
 }


scale trough,
scale.vertical trough {
    min-width: 3px;
    border-radius: 6px;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#d1d1d1),
                                     to (#e8e8e8));
    border-style: solid;
    border-width: 1px;
    color: @text_color;
}

scale.vertical trough {
    margin: 0 6px;
}

scale trough highlight,
scale.horizontal trough highlight,
scale.vertical trough highlight {
    border-color: @scale_highlight_bg;
    border-style: solid;
    border-width: 0px;
    background-image: none;
    box-shadow: none;
    background-color: @scale_highlight_bg;
}

scale trough:disabled,
scale.horizontal trough:disabled,
scale.vertical trough:disabled {
    box-shadow: none;
}


scale trough:disabled {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 0.95)),
                                     to (shade (@bg_color, 0.85)));
}

scale.vertical trough:disabled {
    background-image: -gtk-gradient (linear, left top, right top,
                                     from (shade (@bg_color, 0.95)),
                                     to (shade (@bg_color, 0.85)));
}

scale.horizontal trough highlight:disabled,
scale.vertical trough highlight:disabled,
scale.horizontal trough highlight:backdrop,
scale.vertical trough highlight:backdrop {
    background-color: @backdrop_filling_bg;
    box-shadow: none;
    background-image: none;
}

/* defines the color of the actuall marks on the scale */
scale marks indicator {
	color: alpha(@fg_color, 0.3);
}

/* this makes marks visible */
scale.horizontal indicator,
scale.horizontal.fine-tune indicator {
    min-height: 8px;
    min-width: 1px;
}

scale.vertical indicator,
scale.vertical.fine-tune indicator {
    min-height: 1px;
    min-width: 8px;
}

scale slider,
scale slider:hover,
scale slider:disabled {
	border-radius: 8px;
	border-style: none;
	background-color: transparent;
	/* background-image in -assets variant */
}

scale.vertical slider,
scale.horizontal slider {
    background-size: 100%;
    background-repeat: no-repeat;
    background-position: center;
}

scale.horizontal slider {
    min-width: 14px;
    margin: -9px 0px -9px 0px;
}

scale.vertical slider {
    min-height: 14px;
    margin: 0px -9px 0px -9px;
}

scale.horizontal.scale-has-marks-above.color,
scale.vertical.scale-has-marks-below.color {
    margin: 0px 0px 0px 0px;
    padding: 0px;
}

scale.scale-has-marks-above.color trough,
scale.scale-has-marks-below.color trough {
      border-color: @scale_highlight_border;
      border-radius: 3px;
      background-repeat: no-repeat;
}

scale.vertical.scale-has-marks-below.color slider {
    min-height: 20px;
    min-width: 22px;
    padding: 0px;
    background-size: 100%;
    background-repeat: no-repeat;
    background-position: center;
    margin: 0px 0px 0px 0px;
}

scale.horizontal contents:first-child:not(:only-child) slider {
    min-height: 22px;
}

scale.horizontal.scale-has-marks-above.color slider {
    min-height: 14px;
    min-width: 20px;
    margin: 0px 0px 0px 0px;
    padding: 5px 0px;
    background-size: 100%;
    background-repeat: no-repeat;
    background-position: center;
}

scale.horizontal.scale-has-marks-above.color slider:hover,
scale.vertical.scale-has-marks-below.color slider:hover {
    background-size: 105%;
}

scale.horizontal.scale-has-marks-above.color.fine-tune slider,
scale.vertical.scale-has-marks-below.color.fine-tune slider,
scale.vertical.fine-tune slider:active,
scale.vertical.fine-tune slider:active:hover,
scale.horizontal.fine-tune slider:active,
scale.horizontal.fine-tune slider:hover:active {
	background-size: 80%;
}

/*************
 * scrollbar *
 *************/

.scrollbar,
scrollbar {
    -GtkScrollbar-has-backward-stepper: 0;
    -GtkScrollbar-has-forward-stepper: 0;
}

scrollbar slider {
    background-color: @scrollbar_track_color;
}

.scrollbar.vertical slider,
scrollbar.vertical slider {
    min-height: 15px;
    min-width: 5px;
}

.scrollbar.horizontal.slider,
scrollbar.horizontal slider {
    min-width: 15px;
    min-height: 5px;
}

.scrollbar.vertical.slider:hover,
scrollbar.vertical:hover slider {
    min-width: 10px;
}

.scrollbar.horizontal.slider:hover,
scrollbar.horizontal:hover slider {
    min-height: 10px;
}

.scrollbar.contents,
scrollbar contents {
    background-color: transparent;
    background-image: none;
    background-size: 0;
    border: none;
    border-radius: 0;
}

.scrollbar.trough,
scrollbar trough {
    background-image: none;
    border: none;
}

.scrollbar:hover:backdrop,
.scrollbar.dragging:backdrop,
scrollbar:hover:backdrop,
scrollbar.dragging:backdrop {
    background-color: @backdrop_selected_bg_color;
}

/* Adding margins, so actual visible size is: width - margin this allows to
 * keep the slider smaller, but keeping few threshold pixels
 */
.scrollbar.vertical:hover:dir(ltr),
.scrollbar.vertical:active:dir(ltr),
scrollbar.vertical:hover:dir(ltr),
scrollbar.vertical:active:dir(ltr) {
    margin-left: 2px;
}

.scrollbar.vertical:hover:dir(rtl),
.scrollbar.vertical:active:dir(rtl),
scrollbar.vertical:hover:dir(rtl),
scrollbar.vertical:active:dir(rtl) {
    margin-right: 2px;
}

.scrollbar.horizontal:hover,
.scrollbar.horizontal:active,
scrollbar.horizontal:hover,
scrollbar.horizontal:active {
    margin-top: 2px;
}

.scrollbar.slider,
scrollbar slider {
    background-color: alpha(@selected_bg_color, 0.8);
    border-radius: 1px;
}

.scrollbar.slider:hover,
.scrollbar.slider:active,
scrollbar slider:hover,
scrollbar slider:active {
    border-radius: 2px;
    margin: 0;
}

/* Adding margins, so actual visible size is: -GtkRange-slider-width - margin
 * this allows to define some kind of proximity effect also on mouse-enter
 */
.scrollbar.vertical:dir(ltr):not(:hover):not(.dragging),
scrollbar.vertical:dir(ltr):not(:hover):not(.dragging) {
    margin-left: 7px;
}

.scrollbar.vertical:dir(rtl):not(:hover):not(.dragging),
scrollbar.vertical:dir(rtl):not(:hover):not(.dragging) {
    margin-right: 7px;
}

.scrollbar.horizontal:not(:hover):not(.dragging),
scrollbar.horizontal:not(:hover):not(.dragging) {
    margin-top: 7px;
}

.scrollbar.slider:hover,
scrollbar slider:hover {
    background-color: alpha(@selected_bg_color, 0.85);
}

.scrollbar.slider:active,
scrollbar slider:active {
    background-color: @selected_bg_color;
}

.scrollbar.slider:backdrop,
scrollbar slider:backdrop {
    background-color: alpha(@backdrop_filling_bg, 0.8);
}

.scrollbar.slider:hover:backdrop,
scrollbar slider:hover:backdrop {
    background-color: alpha(@backdrop_filling_bg, 0.85);
}

.scrollbar.slider:active:backdrop,
scrollbar slider:active:backdrop {
    background-color: @backdrop_filling_bg;
}

/*******************
 * scrolled window *
 *******************/
.ubuntu-online-accounts.frame,
scrolledwindow.frame {
    border-top-color: shade (@bg_color, 0.84);
    border-right-color: shade (@bg_color, 0.76);
    border-bottom-color: shade (@bg_color, 0.86);
    border-left-color: shade (@bg_color, 0.76);
    border-width: 1px;
    border-radius: 0;
    border-style: solid;
}

.ubuntu-online-accounts.frame {
    border-top-width: 0;
}

/*************
 * separator *
 *************/
separator {
    min-width: 1px;
    min-height: 1px;
    border-top-width: 1px;
    border-left-width: 1px;
    border-style: solid;
    border-image: none;
    border-color: shade (@bg_color, 0.92);
    border-bottom-color: alpha (shade (@bg_color, 1.26), 0.6);
    border-right-color: alpha (shade (@bg_color, 1.26), 0.6);
}

treeview.view separator,
treeview separator,
separator,
separator:hover {
    color: shade (@bg_color, 0.92);
}

separator.horizontal {
    border-width: 1px 0 1px 0;
}

separator.vertical {
    border-width: 0 1px 0 1px;
}

button separator {
    border-color: shade (@button_bg_color, 0.9);
    border-bottom-color: alpha (shade (@bg_color, 1.26), 0.6);
    border-right-color: alpha (shade (@bg_color, 1.26), 0.6);
}

button separator:disabled {
    border-color: shade (@button_insensitive_bg_color, 0.96);
    border-bottom-color: alpha (shade (@bg_color, 1.26), 0.3);
    border-right-color: alpha (shade (@bg_color, 1.26), 0.3);
}

menu separator {
    margin-left: 5px;
    margin-right: 5px;
    border: none;
    color: @dark_bg_color;
}

menuitem.separator,
menu separator {
    border-color: shade (@dark_bg_color, 0.99);
    border-bottom-color: alpha (shade (@dark_bg_color, 1.26), 0.5);
    border-right-color: alpha (shade (@dark_bg_color, 1.26), 0.5);
}

toolbar menu separator,
combobox menu separator {
    border-color: shade (@bg_color, 0.92);
    border-bottom-color: alpha (shade (@bg_color, 1.26), 0.6);
    border-right-color: alpha (shade (@bg_color, 1.26), 0.6);
}

/***********
 * sidebar *
 ***********/

filechooser box.search-bar,
#pathbarbox,
placessidebar.sidebar {
    background-color: shade (@bg_color, 0.95);

    color: @fg_color;
    text-shadow: 0 1px shade (shade (@bg_color, 0.95), 1.04);
}

filechooser:backdrop box.search-bar,
#pathbarbox:backdrop,
placessidebar.sidebar:backdrop {
    color: mix (@fg_color, shade (@bg_color, 0.95), 0.2);
    text-shadow: 0 1px shade (shade (@bg_color, 0.95), 1.02);
}

placessidebar.sidebar row {
    min-height: 30px;
}

placessidebar.sidebar row:selected {
    color: @selected_fg_color;
    text-shadow: 0 1px shade (@selected_bg_color, 0.7);
}

placessidebar.sidebar row:selected:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (shade (@bg_color, 0.95), 0.94)),
                                     to (shade (shade (@bg_color, 0.95), 0.86)));
    border-top-color: shade (shade (@bg_color, 0.95), 0.88);

    color: @fg_color;
    text-shadow: 0 1px shade (shade (@bg_color, 0.95), 0.96);
}

placessidebar.sidebar .sidebar-icon {
    padding-left: 10px;
    padding-right: 10px;
}


/**************
 * spinbutton *
 **************/

spinbutton button:active,
spinbutton button:disabled,
spinbutton button {
    border-radius: 0;
}

spinbutton button:active:nth-child(last),
spinbutton button:disabled:nth-child(last)
spinbutton button:nth-child(last),
spinbutton button:active:backdrop:nth-child(last),
spinbutton button:disabled:backdrop:nth-child(last),
spinbutton button:backdrop:nth-child(last) {
    border-radius: 0 7px 7px 0;
}

spinbutton button,
spinbutton button:active,
spinbutton button:backdrop,
spinbutton button:active:backdrop,
spinbutton button:hover,
spinbutton button:hover:backdrop {
    background-image: none;
    background-color: transparent;
    border-image: none;
    border-width: 0 0 0 1px;
    border-left-color: alpha (shade (@bg_color, 0.6), 0.22);
}

spinbutton.horizontal button:disabled {
    margin-top: 1px;
    margin-bottom: 1px;
    border-image: none;
}

spinbutton.horizontal button:last-child:disabled {
    margin-right: 3px;
}

spinbutton button:active {
    background-image: -gtk-gradient (radial, center center, 0.0, center center, 0.5,
                                     from (alpha (@selected_bg_color, 0.2)),
                                     to (alpha (@selected_bg_color, 0.0)));
}

spinbutton button:disabled,
spinbutton button:disabled:backdrop {
    border-left-color: alpha (shade (@bg_color, 0.6), 0.18);

    color: shade (@bg_color, 0.66);
}

spinbutton,
spinbutton:hover {
    color: @fg_color;
}

/***********
 * spinner *
 ***********/
@keyframes spinner {
    to { -gtk-icon-transform: rotate(1turn); }
}

spinner {
    -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
    color: @selected_bg_color;
    opacity: 0;
}

spinner:checked {
    animation: spinner 1s infinite linear;
    opacity: 1;
}

spinner:checked:backdrop {
    color: @backdrop_fg_color;
}

spinner:checked:disabled {
    opacity: 0.5;
}

/*************
 * statusbar *
 *************/
statusbar {
}

/**********
 * switch *
 **********/
switch {
    padding: 0;
    border-radius: 8px;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#cecece),
                                     to (#e8e8e8));

    color: @fg_color;
    text-shadow: 0 1px alpha (shade (@bg_color, 1.25), 0.5);
}

switch:checked {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 0.93)),
                                     to (shade (@selected_bg_color, 0.99)));

    color: @selected_fg_color;
    text-shadow: 0 1px shade (@selected_bg_color, 0.7);
}

switch:focus {
    outline: 2px solid @focus_color;
    outline-offset: -2px;
    -gtk-outline-radius: 6px;
}

/* XXX temporary */
switch:backdrop,
switch:disabled {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 0.93)),
                                     to (shade (@bg_color, 0.99)));

    color: shade (@bg_color, 0.6);
    text-shadow: 0 1px alpha (shade (@bg_color, 1.25), 0.5);
}

switch slider {
    padding: 1px;
    border-radius: 6px;
    border-left-width: 1px;
    border-right-width: 1px;
    border-style: solid;

    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@button_bg_color, 1.08)),
                                     color-stop (0.5, @button_bg_color),
                                     to (shade (@button_bg_color, 0.94)));

    color: @fg_color;
    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.4);
}

switch slider:backdrop {
    background-image: none;
    background-color: @bg_color;

    color: @backdrop_fg_color;
    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.2);
}

/************
 * textview *
 ************/
textview {
    background-color: @base_color;
}

headerbar {
    padding: 2px 6px;
}

/*
 * Header Bars
 *
 * The following rules only style header bars when they are used as a window's
 * titlebar widget (i.e., they have .titlebar set as well).
 *
 * Some applications reuse their header bar as a primary toolbar on desktops
 * that prefer showing traditional title bars. The rules for those are further
 * down grouped with normal toolbars.
 */
.titlebar {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.5)),
                                     to (@dark_bg_color));
    border-color: shade (@dark_bg_color, 1.5);
    border-style: solid;
    border-width: 1px 0 0 0;
    border-radius: 7px 7px 0 0;

    color: @dark_fg_color;
}

.titlebar .title {
    font: bold;
}

.titlebar .subtitle {
    font-size: smaller;
    opacity: 0.5;
}

.titlebar:backdrop {
    color: @backdrop_fg_color;
    background-image: none;
    background-color: @dark_bg_color;
    border-top-color: @dark_bg_color;
    box-shadow: inset 0 1px shade (@dark_bg_color, 1.2);
}

.maximized .titlebar {
    border-radius: 0;
    border: none;
}

.maximized .titlebar.toolbar-mode {
    box-shadow: none;
}

.titlebar button.titlebutton {
    background-clip: padding-box;
    border: 1px solid #d0c7bf;
    color: #8b8379;
    -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.5);
    border-radius: 9px;
    padding: 0;
    box-shadow: none;
    background-image: linear-gradient(to top, #d5d2ce, #ece8e4 50%, #f7f4f3);
}

.titlebar button.titlebutton.close {
    color: #7f4025;
    -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.25);
    background-image: linear-gradient(to top, #e77041, #f17d43 50%, #f9b39c);
}

.titlebar button.titlebutton.close:hover {
    background-image: linear-gradient(to top, #e67144, #ed8b67 50%, #f9cbbd);
}

.titlebar button.titlebutton:hover,
.titlebar button.titlebutton:backdrop:hover {
    background-image: linear-gradient(to top, #e2e1df, #f8f6f3 50%, #fcfbf9);
}

.titlebar button.titlebutton:active {
    -gtk-icon-shadow: none;
    background-image: linear-gradient(to top, #fcfbf8, #fbf9f6);
}

.titlebar button.titlebutton.close:active {
    background-image: linear-gradient(to top, #ec6e44, #e76b41);
}

.titlebar button.titlebutton:backdrop {
    color: #8b8379;
    -gtk-icon-shadow: none;
    background-image: linear-gradient(to top, #ece9e6, #e8e4e1);
}


/***********
 * toolbar *
 ***********/
.toolbar {
    border-style: none;
    padding: 1px;

    background-color: @bg_color;
    color: @fg_color;
    text-shadow: none;
}

.toolbar:backdrop {
    color: @backdrop_fg_color;
}

/*******************
 * primary-toolbar *
 *******************/
.primary-toolbar,
headerbar,
.maximized headerbar.titlebar:not(:backdrop) {
    -GtkWidget-window-dragging: true;

    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.96)),
                                     to (shade (@dark_bg_color, 1.4)));
    border-bottom-color: shade (@dark_bg_color, 1.1);
    border-top-color: shade (@dark_bg_color, 1.09);
    border-style: solid;
    border-width: 1px 0 1px 0;
    border-radius: 0;

    color: @dark_fg_color;
    text-shadow: 0 -1px shade (@dark_bg_color, 0.7);

    box-shadow: inset 0 1px shade (@dark_bg_color, 0.94);
}

.maximized headerbar.titlebar.toolbar-mode:not(:backdrop) {
    border-width: 0;
}

.primary-toolbar:backdrop,
headerbar:backdrop {
    background-image: none;
    background-color: @dark_bg_color;
    box-shadow: none;
    border-top-color: @dark_bg_color;
    border-bottom-color: shade (@dark_bg_color, 0.9);

    color: @backdrop_dark_fg_color;
}

.primary-toolbar:disabled,
headerbar:disabled {
    text-shadow: 0 -1px shade (@dark_bg_color, 0.7);
}

.primary-toolbar button,
headerbar button,
headerbar button:disabled,
.primary-toolbar button.flat:hover {
    background: transparent;
    border-image-source: url("assets/radiance-button-toolbar.png");
    padding: 9px;
    color: @dark_fg_color;
}

.primary-toolbar button,
headerbar button *,
headerbar button:disabled * {
    text-shadow: 0 -1px shade (@dark_bg_color, 0.7);
}

.primary-toolbar button.flat {
    border-image-source: none;
    background: transparent;
}

.primary-toolbar button:focus,
headerbar button:focus {
    border-image-source: url("assets/radiance-button-toolbar-focused.png");
}

.primary-toolbar button:active,
.primary-toolbar button:checked,
headerbar button:active,
headerbar button:checked {
    border-image-source: url("assets/radiance-button-toolbar-active.png");
}

.primary-toolbar button:active:focus,
.primary-toolbar button:checked:focus,
headerbar button:active:focus,
headerbar button:checked:focus,
headerbar button:hover:focus {
    border-image-source: url("assets/radiance-button-toolbar-active-focused.png");
}

.primary-toolbar button:backdrop,
headerbar button:backdrop,
headerbar button:disabled:backdrop,
headerbar button:checked:backdrop {
    color: @backdrop_dark_fg_color;
    background-color: transparent;
    border-image-source: url("assets/radiance-backdrop-button-toolbar.png");
}

.primary-toolbar button:backdrop,
headerbar button:backdrop *,
headerbar button:disabled:backdrop *,
headerbar button:checked:backdrop * {
    text-shadow: 0 -1px shade (@dark_bg_color, 0.9);
}

.primary-toolbar button.flat:backdrop {
    border-image-source: none;
}

.primary-toolbar button:active:backdrop,
.primary-toolbar button:checked:backdrop,
headerbar button:active:backdrop {
    border-image-source: url("assets/radiance-backdrop-button-toolbar-active.png");
}

.primary-toolbar button:hover,
.primary-toolbar button:checked,
headerbar button:hover,
headerbar button:checked,
headerbar button:backdrop:hover,
headerbar button:backdrop:checked {
    background-color: transparent;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.2)),
                                     to (shade (@dark_bg_color, 1.1)));
    border-image-source: url("assets/radiance-backdrop-button-toolbar.png");
}

.primary-toolbar button:active,
headerbar button:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.95)),
                                     to (shade (@dark_bg_color, 1.0)));
    text-shadow: 0 -1px shade (@dark_bg_color, 0.6);
}

.primary-toolbar button:checked:disabled,
.primary-toolbar button:disabled,
headerbar button:checked:disabled,
headerbar button:disabled {
    text-shadow: none;
}

.primary-toolbar button:disabled,
headerbar button:disabled {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.01)),
                                     to (shade (@dark_bg_color, 0.99)));
    border-image-source: url("assets/button-toolbar.png");
}

.primary-toolbar button.flat:disabled {
    background-image: none;
    border-image-source: inherit;
}

.primary-toolbar button:checked:disabled,
headerbar button:checked:disabled {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.94)),
                                     to (shade (@dark_bg_color, 1.02)));
    border-image-source: url("assets/button-toolbar.png");
}

.primary-toolbar separator,
.primary-toolbar separator,
.primary-toolbar separator:disabled,
headerbar separator,
headerbar separator:disabled {
    border-color: alpha (shade (@dark_bg_color, 0.94), 0.35);
    border-bottom-color: alpha (shade (@dark_bg_color, 1.26), 0.5);
    border-right-color: alpha (shade (@dark_bg_color, 1.26), 0.5);
}

/* inline-toolbar */
.inline-toolbar.toolbar {
    -GtkToolbar-button-relief: normal;

    border-right-color: shade (@bg_color, 0.86);
    border-bottom-color: shade (@bg_color, 0.88);
    border-left-color: shade (@bg_color, 0.86);

    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (#f2f1ef, 0.93)),
                                     color-stop (0.08, #f2f1ef),
                                     to (#ffffff));
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-radius: 3px;
    border-top-right-radius: 0;
    border-top-left-radius: 0;
    padding: 3px 4px 4px 4px;
}

.inline-toolbar.toolbar button {
    padding: 4px;

    -gtk-icon-shadow: 0 1px shade (@bg_color, 1.16);
}

/* Middle button */
.inline-toolbar.toolbar button,
.inline-toolbar.toolbar button:active,
.inline-toolbar.toolbar button:focus,
.inline-toolbar.toolbar button:focus:active,
.inline-toolbar.toolbar button:disabled,
.inline-toolbar.toolbar button:backdrop,
.inline-toolbar.toolbar button:backdrop:disabled,
.inline-toolbar.toolbar GtkToolButton button,
.inline-toolbar.toolbar GtkToolButton button:active,
.inline-toolbar.toolbar GtkToolButton button:focus,
.inline-toolbar.toolbar GtkToolButton button:focus:active,
.inline-toolbar.toolbar GtkToolButton button:disabled,
.inline-toolbar.toolbar GtkToolButton button:backdrop,
.inline-toolbar.toolbar GtkToolButton button:backdrop:disabled {
    border-right-width: 0;
    border-left-width: 0;
    border-image-width: 10px 0 10px 0;
    border-radius: 0;
}

/* Leftmost button */
.inline-toolbar.toolbar button:first-child,
.inline-toolbar.toolbar button:active:first-child,
.inline-toolbar.toolbar button:focus:first-child,
.inline-toolbar.toolbar button:focus:active:first-child,
.inline-toolbar.toolbar button:disabled:first-child,
.inline-toolbar.toolbar button:backdrop:first-child,
.inline-toolbar.toolbar button:backdrop:disabled:first-child,
.inline-toolbar.toolbar GtkToolButton:first-child button,
.inline-toolbar.toolbar GtkToolButton:first-child button:active,
.inline-toolbar.toolbar GtkToolButton:first-child button:focus,
.inline-toolbar.toolbar GtkToolButton:first-child button:focus:active,
.inline-toolbar.toolbar GtkToolButton:first-child button:disabled,
.inline-toolbar.toolbar GtkToolButton:first-child button:backdrop,
.inline-toolbar.toolbar GtkToolButton:first-child button:backdrop:disabled {
    border-left-width: 1px;
    border-right-width: 0;
    border-image-width: 10px 0 10px 12px;
    border-radius: 8px;
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
}

/* Rightmost button */
.inline-toolbar.toolbar button:last-child,
.inline-toolbar.toolbar button:active:last-child,
.inline-toolbar.toolbar button:focus:last-child,
.inline-toolbar.toolbar button:focus:active:last-child,
.inline-toolbar.toolbar button:disabled:last-child,
.inline-toolbar.toolbar button:backdrop:last-child,
.inline-toolbar.toolbar button:backdrop:disabled:last-child,
.inline-toolbar.toolbar GtkToolButton:last-child button,
.inline-toolbar.toolbar GtkToolButton:last-child button:active,
.inline-toolbar.toolbar GtkToolButton:last-child button:focus,
.inline-toolbar.toolbar GtkToolButton:last-child button:focus:active,
.inline-toolbar.toolbar GtkToolButton:last-child button:disabled,
.inline-toolbar.toolbar GtkToolButton:last-child button:backdrop,
.inline-toolbar.toolbar GtkToolButton:last-child button:backdrop:disabled {
    border-left-width: 0;
    border-right-width: 1px;
    border-image-width: 10px 12px 10px 0;
    border-radius: 8px;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}

/* Single button */
.inline-toolbar.toolbar button:only-child,
.inline-toolbar.toolbar button:active:only-child,
.inline-toolbar.toolbar button:focus:only-child,
.inline-toolbar.toolbar button:focus:active:only-child,
.inline-toolbar.toolbar button:disabled:only-child,
.inline-toolbar.toolbar button:backdrop:only-child,
.inline-toolbar.toolbar button:backdrop:disabled:only-child,
.inline-toolbar.toolbar GtkToolButton:only-child button,
.inline-toolbar.toolbar GtkToolButton:only-child button:active,
.inline-toolbar.toolbar GtkToolButton:only-child button:focus,
.inline-toolbar.toolbar GtkToolButton:only-child button:focus:active,
.inline-toolbar.toolbar GtkToolButton:only-child button:disabled,
.inline-toolbar.toolbar GtkToolButton:only-child button:backdrop,
.inline-toolbar.toolbar GtkToolButton:only-child button:backdrop:disabled {
    border-right-width: 1px;
    border-left-width: 1px;
    border-image-width: 10px 12px 10px 12px;
    border-radius: 8px;
}

/***********
 * tooltip *
 ***********/
tooltip {
    background-image: -gtk-gradient (radial, center 0, 0, center 0, 0.8,
                                     from (alpha (mix (@tooltip_bg_color, #ffffff, 0.2), 0.86)),
                                     to (alpha (@tooltip_bg_color, 0.86)));
    border-color: alpha (#ffffff, 0.2);
    border-radius: 5px;
    border-style: solid;
    border-width: 1px;
}

tooltip label {
    color: @tooltip_fg_color;
}

/************
 * treeview *
 ************/
treeview.view.dnd {
    border-color: shade (@selected_bg_color, 1.12);
    border-radius: 2px;
    border-width: 1px;
    border-style: solid;
}

treeview.view .entry {
    background-image: none;
}

treeview.view {
	border-width: 1px;
	border-color: @selected_bg_color;
}

treeview.view.separator {
    min-height: 2px;
    color: @borders;
}

/************
 * viewport *
 ************/
viewport.frame {
    border-width: 0;
}

/************
 * listbox  *
 ************/
.list-rowbutton {
    border-image: none;
    border-style: none;
    border-radius: 0;
    background-image: none;
}

.list-rowbutton:selected {
    text-shadow: none;
}

/************
 * popover  *
 ************/
popover {
    background-clip: border-box;

    border-radius: 5px;
    border: 1px solid darker(@bg_color);

    box-shadow: 0 2px 3px @shadow_color;
    margin: 10px;
    padding: 2px;
}

popover:backdrop {
    box-shadow: none;
}

/* Popover menuitems are actually buttons. The following rules reset most of
 * the button styles for them.
 */
popover modelbutton,
popover modelbutton:checked,
popover modelbutton:hover,
popover modelbutton:active,
popover modelbutton:disabled,
popover modelbutton:backdrop,
popover menuitem,
popover menuitem:checked,
popover menuitem:hover,
popover menuitem:active,
popover menuitem:disabled,
popover menuitem:backdrop {
    border-image: none;
    border: none;
    text-shadow: none;
    border-radius: 3px;
}

popover modelbutton:backdrop:hover,
popover menuitem:backdrop:hover {
    border: none;
    border-image: none;
    background: transparent;
    color: @fg_color;
}

popover modelbutton:checked,
popover modelbutton check,
popover modelbutton check:checked,
popover modelbutton radio,
popover modelbutton radio:checked,
popover menuitem:checked,
popover menuitem.check,
popover menuitem.check:checked,
popover menuitem.radio,
popover menuitem.radio:checked {
    background-image: none;
    border: none;
}

popover modelbutton:disabled,
popover modelbutton *:disabled,
popover menuitem:disabled,
popover menuitem *:disabled {
    text-shadow: none;
    background: none;
}


/* menu buttons inside popovers */
modelbutton.flat,
popover.background checkbutton,
popover.background radiobutton,
menu button.flat {
    min-height: 26px;
    padding-left: 5px;
    padding-right: 5px;
    border-radius: 3px;
    outline-offset: -2px;
}

modelbutton.flat:hover,
popover.background checkbutton:hover,
popover.background radiobutton:hover,
menu button.flat:hover {
    background-color: #f4f4f4;
}

modelbutton.flat check:last-child,
popover.background checkbutton check:last-child,
popover.background radiobutton check:last-child,
modelbutton.flat radio:last-child,
popover.background checkbutton radio:last-child,
popover.background radiobutton radio:last-child,
menu button.flat check:last-child,
menu button.flat radio:last-child {
    margin-left: 8px;
}

modelbutton.flat check:first-child,
popover.background checkbutton check:first-child,
popover.background radiobutton check:first-child,
modelbutton.flat radio:first-child,
popover.background checkbutton radio:first-child,
popover.background radiobutton radio:first-child,
menu button.flat check:first-child,
menu button.flat radio:first-child
{
    margin-right: 8px;
}

menu arrow.left,
modelbutton.flat arrow.left,
popover.background checkbutton arrow.left,
popover.background radiobutton arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

menu arrow.right,
modelbutton.flat arrow.right,
popover.background checkbutton arrow.right,
popover.background radiobutton arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

/* Floating bars */
.floating-bar {
    background-color: @info_bg_color;
    border-radius: 3px 3px 0 0;
    border-style: solid;
    border-width: 1px;
    border-color: darker (@info_bg_color);
}


/* OSD overlays */
.osd,
.osd:backdrop {
    color: @osd_fg_color;
    background-color: @osd_bg_color;
    border-color: @osd_border_color;
}

.osd.toolbar {
    padding: 12px;
    border-radius: 8px;
}

.osd button,
.osd button:backdrop {
    color: @osd_fg_color;
    background: none;
    border: none;
    padding: 12px;
    border-radius: 8px;
    transition: all 100ms ease-in-out;
    box-shadow: none;
}

/* buttons that are not part of an osd toolbar need a background */
button.osd,
button.osd:hover,
button.osd:active {
    background: @osd_bg_color;
    padding: 12px;
    box-shadow: none;
    border-image: none;
}

button.osd:hover,
.osd button:hover {
    color: lighter(@osd_fg_color);
    -gtk-icon-shadow: 0 0 3px @osd_fg_color;
}

button.osd:active,
.osd button:active {
    color: darker(@osd_fg_color);
    -gtk-icon-shadow: none;
}

/*************
 * overshoot *
 *************/
overshoot.top {
    background: -gtk-gradient(radial, center top, 0, center top, 0.7, from(shade(@bg_color, 0.92)), to(alpha(@bg_color, 0.0)));
}

overshoot.right {
    background: -gtk-gradient(radial, right center, 0, right center, 0.7, from(shade(@bg_color, 0.92)), to(alpha(@bg_color, 0.0)));
}

overshoot.bottom {
    background: -gtk-gradient(radial, center bottom, 0, center bottom, 0.7, from(shade(@bg_color, 0.92)), to(alpha(@bg_color, 0.0)));
}

overshoot.left {
    background: -gtk-gradient(radial, left center, 0, left center, 0.7, from(shade(@bg_color, 0.92)), to(alpha(@bg_color, 0.0)));
}

/**************
 * undershoot *
 **************/
undershoot {
    background: none;
}

/*****************************************************************************
 * states [please keep this section at the end of the file (CSS precedence)] *
 *****************************************************************************/
*:disabled {
    color: shade (@bg_color, 0.6);
    text-shadow: 0 1px alpha (shade (@bg_color, 1.25), 0.5);
}

label selection,
label selection:focus,
label selection:hover,
entry selection,
.view text selection,
*:selected,
*:selected:focus {
    background-color: alpha (@selected_bg_color, 0.9);

    color: @selected_fg_color;
}

entry selection:backdrop,
.view text selection:backdrop,
*:selected:backdrop,
*:selected:focus:backdrop {
    background-color: alpha (@backdrop_selected_bg_color, 0.9);

    color: @backdrop_selected_fg_color;
}

*:link,
*:visited {
    color: #f07746; /* @link_color */
}
