
BaobabWindow GtkGrid {
    background-color: @bg_color;
}

BaobabLocationList GtkGrid {
    background-color: transparent;
}

.baobab-toolbar.toolbar {
    border-color: shade (@bg_color, 0.9);
    border-style: solid;
    border-width: 0 0 1px 0;
    border-radius: 0;
}

.cell.baobab-level-cell,
.cell.baobab-level-cell:hover,
.cell.baobab-level-cell:selected,
.cell.baobab-level-cell:selected:hover {
    border-color: alpha (black, 0.06);
    border-width: 1px;
    border-style: solid;
    background-color: @base_color;
}
