
/**********
 * states *
 **********/
*:insensitive {
    color: shade (@bg_color, 0.6);
    text-shadow: none;
}

/************
 * toolbars *
 ************/

.menubar.toolbar,
.primary-toolbar,
.primary-toolbar .toolbar,
.primary-toolbar.toolbar {
	-GtkWidget-window-dragging: true;
	background-image: -gtk-gradient (linear, left top, left bottom,
					from (@toolbar_bg_top_color),
					to (@toolbar_bg_bottom_color));
	border-top-color: @toolbar_border_top_color;
	border-bottom-color: @toolbar_border_bottom_color;
	border-style: solid;
	border-width: 1px 0 1px 0;
	padding: 2px;
	color: @toolbar_fg_color;
	-unico-border-gradient: none;
	-unico-inner-stroke-gradient: none;
	-unico-inner-stroke-top-color: @transparent;
	-unico-inner-stroke-width: 0;
}



.menubar.toolbar :insensitive,
.primary-toolbar :insensitive {
	color: mix (@toolbar_bg_color, @toolbar_fg_color, 0.35);
}

.menubar.toolbar GtkSeparatorToolItem,
.menubar.toolbar .separator,
.menubar.toolbar .separator:insensitive,
.primary-toolbar GtkSeparatorToolItem,
.primary-toolbar .separator,
.primary-toolbar .separator:insensitive {
	border-color: alpha (shade (@toolbar_bg_color, 0.9), 0.5);
	border-style: solid;

	-unico-border-gradient: none;
	-unico-inner-stroke-color: alpha (shade (@toolbar_bg_color, 1.26), 0.4);
	-unico-inner-stroke-gradient: none;
}

/* primary-toolbar */
.primary-toolbar,
.primary-toolbar .toolbar,
.primary-toolbar.toolbar,
.menubar.toolbar,
.header-bar {
    box-shadow: inset 0 0px shade (@dark_bg_color, 0.94);
}


/*************************
 *  header bars		 *
 *************************/

.header-bar {
    padding: 5px;
    border-width: 0 0 1px;
    border-style: solid;
    border-color: shade(@toolbar_bg_color, 0.7);
    background-image: linear-gradient(to bottom,
                                      shade(@toolbar_bg_color, 1.00),
                                      shade(@toolbar_bg_color, 0.90)
                                      );
}


/*************************
 * progressbar and scale *
 *************************/

.scale.trough.highlight {
    background-color: @progress_color;
    background-image: none;
    background-clip: content-box;
}

.menubar .menuitem .scale.highlight.left,
.scale.highlight.left,
.progressbar,
.progressbar row,
.progressbar row:hover,
.progressbar row:selected,
.progressbar row:selected:focused {
    border-radius: 8px;
    border-width: 0px;
    background-image: none;
    background-color: @progress_color;
    border-style: solid;
}

/********
 * menu *
 ********/

.menubar {
	padding: 2px;
}

GtkTreeMenu.menu .menuitem:insensitive,
GtkTreeMenu.menu .menuitem *:insensitive,
.toolbar .primary-toolbar .menu .menuitem:insensitive,
.toolbar .primary-toolbar .menu .menuitem *:insensitive,
.toolbar .menubar.toolbar .menu .menuitem:insensitive,
.toolbar .menubar.toolbar .menu .menuitem *:insensitive,
.toolbar .header-bar .menu .menuitem:insensitive,
.toolbar .header-bar .menu .menuitem *:insensitive,
GtkMenuToolButton.menu .menuitem:insensitive,
GtkMenuToolButton.menu .menuitem *:insensitive,
.primary-toolbar .button .menu .menuitem:insensitive,
.primary-toolbar .button .menu .menuitem *:insensitive,
.menubar.toolbar .button .menu .menuitem:insensitive,
.menubar.toolbar .button .menu .menuitem *:insensitive,
.header-bar .button .menu .menuitem:insensitive,
.header-bar .button .menu .menuitem *:insensitive,
.menuitem:insensitive,
.menuitem *:insensitive {
    color: mix (@dark_fg_color, @dark_bg_color, 0.5);
    text-shadow: none;
}

.menuitem .accelerator:insensitive {
    color: alpha (mix (@dark_fg_color, @dark_bg_color, 0.5), 0.5);
    text-shadow: none;
}

/***************
 * menubaritem *
 ***************/

.menubar.menuitem:hover,
.menubar .menuitem:hover {
    border-radius: 4px 4px 0 0;
    border-width: 1px 1px 0 1px;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 1.20)),
                                     to (shade (@selected_bg_color, 0.80)));

    box-shadow: none;

    color: @selected_fg_color;
    text-shadow: none;
}

.menubar.menuitem:hover,
.menubar .menuitem:hover {
    border-color: #9CB8B8;
}

/*************
 * Scrollbar *
 *************/
.scrollbar {
	background-image: none;
	border-style: solid;
	-GtkRange-trough-border: 0;
	-GtkRange-arrow-scaling: 0.444;
	-GtkRange-slider-width: 10;
	-GtkRange-stepper-size: 0;
	-GtkScrollbar-min-slider-length: 30;
	-GtkRange-stepper-spacing: 0;
	-GtkRange-trough-under-steppers: 1;
	-unico-inner-stroke-style: none;
}

.scrollbar,
.scrollbar.vertical,
.scrollbar.horizontal {
    -GtkScrollbar-has-backward-stepper: 0;
    -GtkScrollbar-has-forward-stepper: 0;
    -GtkRange-slider-width: 12px;
    border-radius: 10px;
    border-image: none;
}

/* Through */
.scrollbar.trough.vertical,
.scrollbar.trough.horizontal {
	background-image: -gtk-gradient (linear,
		left top, right top,
		from (shade (@trough_bg_color_b, 0.99)),
		to (@trough_bg_color_a));
	background-color: shade (@theme_bg_color, 0.882);
	border-radius: 0;
	-adwaita-border-gradient: -gtk-gradient (linear,
		left top, right top,
		from (alpha (@scrollslider_gradient_a, 1.00)),
		to (alpha (@scrollslider_gradient_a, 0.00)));
	border-width: 0;
	border-style: none;
}


/* Sliders and buttons */
.scrollbar.slider.vertical,
.scrollbar.button.vertical,
.scrollbar.slider.horizontal,
.scrollbar.button.horizontal {
	background-image: -gtk-gradient (linear,
		left top, right top,
		from (@scrollslider_gradient_a),
		to (@scrollslider_gradient_b));
	background-color: @theme_base_color;
	border-color: transparent;
	border-radius: 10px;
	border-width: 1px;
}

.scrollbar.slider.vertical:prelight,
.scrollbar.slider.horizontal:prelight {
	background-image: -gtk-gradient (linear,
		left top, right top,
		from (shade (@scrollslider_gradient_a, 0.90)),
		to (shade (@scrollslider_gradient_b, 0.90)));
	background-color: @theme_base_color;
	border-color: transparent;
	border-radius: 10px;
	border-width: 1px;
}

.scrollbar.slider.vertical:prelight:active,
.scrollbar.slider.horizontal:prelight:active {
	background-image: -gtk-gradient (linear,
		left top, right top,
		from (shade (@scrollslider_gradient_a, 0.80)),
		to (shade (@scrollslider_gradient_b, 0.80)));
	background-color: @theme_base_color;
	border-color: transparent;
	border-radius: 10px;
	border-width: 1px;
}

.scrollbar.slider:insensitive {
	background-color: @theme_base_color;
}

.scrollbar.trough:insensitive {
	background-color: shade (@theme_bg_color, 0.882);
}


/* Nautilus mods */

/* sidebar */
NautilusWindow .sidebar,
NautilusWindow .sidebar .view {
    background-color: @sidepane_color;
}
