gf-popup-window {
  border: 1px solid shade(@dark_bg_color, 0.8);
  border-radius: 10px;
}

gf-popup-window.solid {
  border-radius: 0px;
}

#gf-candidate-popup {
  border-radius: 3px;
}

#gf-candidate-popup.solid {
  border-radius: 0px;
}

#gf-candidate-popup gf-candidate-box label {
  padding: 4px 6px;
}

#gf-candidate-popup gf-candidate-box label:last-child {
  padding-left: 0px;
}

#gf-candidate-popup gf-candidate-box:selected,
#gf-candidate-popup gf-candidate-box:hover {
  background-color: @selected_bg_color;
  color: @selected_fg_color;
  border-radius: 3px;
}

#gf-input-source-popup {
  background-color: @dark_bg_color;
  color: @dark_fg_color;
}

#gf-input-source-popup #gf-input-source {
  background-color: shade(@dark_bg_color, 1.1);
  border-radius: 6px;
  min-width: 120px;
  min-height: 120px;
  font-size: 22px;
}

#gf-input-source-popup #gf-input-source:selected {
  background-color: @selected_bg_color;
  color: @selected_fg_color;
}

#gf-label-window {
  font-size: 40px;
}

#gf-osd-window {
  background-color: @dark_bg_color;
  color: @dark_fg_color;
}
