########################################################################
# Progressbar
########################################################################

style "progressbar" {
	GtkProgressBar ::shadow-type = GTK_SHADOW_NONE
	bg[NORMAL] = "#C8C8C8"
	bg[SELECTED] = @selected_bg_color
	engine "pixmap" {
		image {	function = BOX
			detail = "trough"
			file = "images/progressbar-trough-horiz.png"
			border = {9, 9, 9, 9}
			stretch	= TRUE
			orientation = HORIZONTAL }
		image {	function = BOX
			detail = "trough"
			file = "images/progressbar-trough-vert.png"
			border = {9, 9, 9, 9}
			stretch = TRUE
			orientation = VERTICAL }
		image { function = SHADOW
			shadow = IN
			file = "images/progressbar-trough-tree.png"
			border = {9, 9, 9, 9}
			stretch	= TRUE }		
		image { function = BOX
			detail = "bar"
			file = "images/progressbar-horiz.png"
			border = {8, 8, 8, 8}
			stretch	= TRUE
			orientation = HORIZONTAL }
		image { function = BOX
			detail = "bar"
			file = "images/progressbar-vert.png"
			border = {8, 8, 8, 8}
			stretch = TRUE
			orientation = VERTICAL }
		image { function = BOX
			state = SELECTED
			border = {2, 2, 2, 2}
			file = "images/progressbar-horiz.png"
			stretch	= TRUE }
	}
}

style "progressbar_tree" {
	GtkProgressBar ::shadow-type = GTK_SHADOW_NONE
	bg[NORMAL] = "#C8C8C8"
	bg[SELECTED] = @selected_bg_color
	engine "pixmap" {
		image {	function = SHADOW
			shadow = IN
			file = "images/progressbar-trough-tree.png"
			border = {9, 9, 9, 9}
			stretch	= TRUE	}
		image {	function = BOX
			state = SELECTED
			border = {2, 2, 2, 2}
			file = "images/progressbar-tree.png"
			stretch	= TRUE	}
	}
}

class "GtkTreeView*" style "progressbar_tree"
class "GtkProgressBar*" style "progressbar"
