style "chrome-gtk-frame"
{
    ChromeGtkFrame::frame-color = "#dbdcdb"
    ChromeGtkFrame::inactive-frame-color = "#dbdcdb"

    ChromeGtkFrame::incognito-frame-color = darker("#dbdcdb")
    ChromeGtkFrame::incognito-inactive-frame-color = darker("#dbdcdb")
    
    ChromeGtkFrame::scrollbar-trough-color = "#bdbdbd"
    ChromeGtkFrame::scrollbar-slider-prelight-color = "#d8e5e0"
    ChromeGtkFrame::scrollbar-slider-normal-color = "#e0e0e0"
}

class "ChromeGtkFrame" style "chrome-gtk-frame"
