# ==============================================================================
# CHROMIUM SPECIFIC SETTINGS
# ==============================================================================

style "chromium_toolbar_button" {
	engine "murrine" {
		roundness = 3
		textstyle = 0
	}
}

style "chrome-gtk-frame"
{
  ChromeGtkFrame::frame-color = "#dfd7cf"
  ChromeGtkFrame::inactive-frame-color = "#dfd7cf"

  ChromeGtkFrame::frame-gradient-size = 16
  ChromeGtkFrame::frame-gradient-color = shade (0.97, @bg_color)

  ChromeGtkFrame::incognito-frame-color = "#dfd7cf"
  ChromeGtkFrame::incognito-inactive-frame-color = "#dfd7cf"

  ChromeGtkFrame::incognito-frame-gradient-size = 16
  ChromeGtkFrame::incognito-frame-gradient-color = shade (0.97, @bg_color)

  ChromeGtkFrame::scrollbar-trough-color = shade (0.912, @bg_color)
  ChromeGtkFrame::scrollbar-slider-prelight-color = shade (1.04, @bg_color)
  ChromeGtkFrame::scrollbar-slider-normal-color = @bg_color
}

class "ChromeGtkFrame" style "chrome-gtk-frame"

widget_class "*Chrom*Button*" style "chromium_toolbar_button"






