/* Borders */
menubar menuitem,
.menubar.menuitem {
    border: 1px solid transparent;
    border-bottom-width: 0px;
}

menubar menuitem:hover,
.menubar.menuitem:hover {
    border: 1px solid #2e2e2c;
    border-bottom-width: 0px;
    border-radius: 4px 4px 0 0;
}

/*********
 * entry *
 *********/
spinbutton,
entry {
    border-radius: 8px;
    border-width: 1px;
    border-style: solid;
    border-color: transparent;
}

spinbutton,
entry {
    border-image: -gtk-scaled(url("assets/entry.png"),url("assets/entry@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

spinbutton:backdrop,
entry:backdrop {
    border-image: -gtk-scaled(url("assets/backdrop-entry.png"),url("assets/backdrop-entry@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

spinbutton:focus,
entry:focus {
    border-image: -gtk-scaled(url("assets/entry-focused.png"),url("assets/entry-focused@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

spinbutton:disabled,
entry:disabled {
    border-image: -gtk-scaled(url("assets/entry-disabled.png"),url("assets/entry-disabled@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

spinbutton:disabled:backdrop,
entry:disabled:backdrop {
    border-image: -gtk-scaled(url("assets/backdrop-entry-disabled.png"),url("assets/backdrop-entry-disabled@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

spinbutton entry,
spinbutton entry:focus,
spinbutton entry:disabled,
spinbutton entry:disabled:backdrop,
spinbutton entry:backdrop {
    margin: 1px;
    border-image: none;
}

.primary-toolbar entry,
menubar toolbar entry,
headerbar entry {
    border-image: -gtk-scaled(url("assets/entry-toolbar.png"),url("assets/entry-toolbar@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

.primary-toolbar entry:focus,
menubar toolbar entry:focus,
headerbar entry:focus {
    border-image: -gtk-scaled(url("assets/entry-toolbar-focused.png"),url("assets/entry-toolbar-focused@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

.primary-toolbar entry progress,
menubar toolbar entry progress,
headerbar entry progress {
    border-radius: 8px;
    border-width: 0;
}

/******************
 * comboboxentry *
 ******************/
combobox entry:first-child,
combobox entry button:first-child {
    border-image-width: 10px 1px 10px 12px;
    border-radius: 8px 0 0 8px;
    border-right-width: 0;
}

combobox entry:last-child,
combobox entry button:last-child {
    border-image-width: 10px 12px 10px 1px;
    border-radius: 0 8px 8px 0;
    border-left-width: 0;
}

combobox entry button {
    border-image: -gtk-scaled(url("assets/combobox-button.png"),url("assets/combobox-button@2.png")) 10 12 10 1 / 10px 12px 10px 1px stretch;
}

combobox entry button:backdrop {
    border-image: -gtk-scaled(url("assets/backdrop-combobox-button.png"),url("assets/backdrop-combobox-button@2.png")) 10 12 10 1 / 10px 12px 10px 1px stretch;
}

combobox entry button:focus {
    border-image: -gtk-scaled(url("assets/combobox-button-focused.png"),url("assets/combobox-button-focused@2.png")) 10 12 10 1 / 10px 12px 10px 1px stretch;
}

combobox entry button:disabled {
    border-image: -gtk-scaled(url("assets/combobox-button-disabled.png"),url("assets/combobox-button-disabled@2.png")) 10 12 10 1 / 10px 12px 10px 1px stretch;
}

combobox entry button:disabled:backdrop {
    border-image: -gtk-scaled(url("assets/backdrop-combobox-button-disabled.png"),url("assets/backdrop-combobox-button-disabled@2.png")) 10 12 10 1 / 10px 12px 10px 1px stretch;
}

combobox entry button:active:focus {
    border-image: -gtk-scaled(url("assets/combobox-button-pressed-focused.png"),url("assets/combobox-button-pressed-focused@2.png")) 10 12 10 1 / 10px 12px 10px 1px stretch;
}

.primary-toolbar combobox entry button,
.primary-toolbar combobox entry button:focus:disabled,
menubar toolbar combobox entry button,
menubar toolbar combobox entry button:focus:disabled,
headerbar combobox entry button,
headerbar combobox entry button:focus:disabled {
    border-image: url("assets/combobox-entry button-toolbar.png") 10 12 10 1 / 10px 12px 10px 1px stretch;
}

.primary-toolbar combobox entry button:focus,
menubar toolbar combobox entry button:focus,
headerbar combobox entry button:focus {
    border-image: url("assets/combobox-entry button-toolbar-focused.png") 10 12 10 1 / 10px 12px 10px 1px stretch;
}

.primary-toolbar combobox entry button:focus:active:focus,
menubar toolbar combobox entry button:focus:active:focus,
headerbar combobox entry button:focus:active:focus {
    border-image: url("assets/combobox-entry button-toolbar-pressed-focused.png") 10 12 10 1 / 10px 12px 10px 1px stretch;
}

.primary-toolbar combobox entry:first-child,
.primary-toolbar combobox entry button:first-child,
menubar toolbar combobox entry:first-child,
menubar toolbar combobox entry button:first-child,
headerbar combobox entry:first-child,
headerbar combobox entry button:first-child {
    border-image-width: 10px 0 10px 12px;
    border-radius: 8px 0 0 8px;
    border-right-width: 0;
}

.primary-toolbar combobox entry:last-child,
.primary-toolbar combobox entry button:last-child,
menubar toolbar combobox entry:last-child,
menubar toolbar combobox entry button:last-child,
headerbar combobox entry:last-child,
headerbar combobox entry button:last-child {
    border-image-width: 10px 12px 10px 1px;
    border-radius: 0 8px 8px 0;
    border-left-width: 0;
}

notebook header.top tab:checked {
    border-image: -gtk-scaled(url("assets/notebook-tab-top.png"),url("assets/notebook-tab-top@2.png")) 8 10 1 10 / 8px 10px 1px 10px stretch;
}

notebook header.right tab:checked {
    border-image: -gtk-scaled(url("assets/notebook-tab-right.png"),url("assets/notebook-tab-right@2.png")) 10 8 10 1 / 10px 8px 10px 1px stretch;
}

notebook header.bottom tab:checked {
    border-image: -gtk-scaled(url("assets/notebook-tab-bottom.png"),url("assets/notebook-tab-bottom@2.png")) 1 10 8 10 / 1px 10px 8px 10px stretch;
}

notebook header.left tab:checked {
    border-image: -gtk-scaled(url("assets/notebook-tab-left.png"),url("assets/notebook-tab-left@2.png")) 10 1 10 8 / 10px 1px 10px 8px stretch;
}

.trough,
trough,
trough.highlight {
    border-radius: 4px;
    border-width: 1px;
    border-style: solid;
    border-color: transparent;
}

.trough,
trough {
    border-image: -gtk-scaled(url("assets/progressbar-horizontal-trough.png"),url("assets/progressbar-horizontal-trough@2.png")) 6 7 6 7 / 6px 7px 6px 7px stretch;
}

switch {
    border-image: -gtk-scaled(url("assets/switch-trough-off.png"),url("assets/switch-trough-off@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

switch:checked {
    border-image: -gtk-scaled(url("assets/switch-trough-on.png"),url("assets/switch-trough-on@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

.primary-toolbar switch,
menubar toolbar switch,
headerbar switch {
    border-image: -gtk-scaled(url("assets/switch-trough-toolbar-off.png"),url("assets/switch-trough-toolbar-off@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

.primary-toolbar switch:checked,
menubar toolbar switch:checked,
headerbar switch:checked {
    border-image: -gtk-scaled(url("assets/switch-trough-toolbar-on.png"),url("assets/switch-trough-toolbar-on@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

/* XXX temporary */
switch:backdrop,
switch:checked:backdrop,
switch:disabled,
switch:checked:disabled {
    border-image: -gtk-scaled(url("assets/switch-trough-disabled.png"),url("assets/switch-trough-disabled@2.png")) 10 12 10 12 / 10px 12px 10px 12px stretch;
}

switch slider {
    border-image: -gtk-scaled(url("assets/switch-button-off.png"),url("assets/switch-button-off@2.png")) 9 11 9 11 / 9px 11px 9px 11px stretch;
}

switch:checked slider {
    border-image: -gtk-scaled(url("assets/switch-button-on.png"),url("assets/switch-button-on@2.png")) 9 11 9 11 / 9px 11px 9px 11px stretch;
}

/* XXX temporary */
switch:backdrop slider,
switch:disabled slider {
    border-image: -gtk-scaled(url("assets/switch-button-off-disabled.png"),url("assets/switch-button-off-disabled@2.png")) 9 11 9 11 / 9px 11px 9px 11px stretch;
}

/* XXX temporary */
switch:active:backdrop slider,
switch:active:disabled slider {
    border-image: -gtk-scaled(url("assets/switch-button-on-disabled.png"),url("assets/switch-button-on-disabled@2.png")) 9 11 9 11 / 9px 11px 9px 11px stretch;
}

/*
progressbar trough progress,
.progressbar,
progressbar row,
progressbar row:hover,
progressbar row:selected,
progressbar row:selected:focus {
    border-image: url("assets/progressbar-horizontal-fill.png") 5 6 5 6 / 5px 6px 5px 6px stretch;
}

.progressbar.vertical.trough,
progressbar.vertical trough progress {
    border-image: url("assets/progressbar-vertical-fill.png") 6 5 6 5 / 6px 5px 6px 5px stretch;
}

.progressbar.trough:backdrop,
progressbar:backdrop trough progress,
progressbar row:backdrop,
progressbar row:hover:backdrop,
progressbar row:selected:backdrop,
progressbar row:selected:focus:backdrop {
    border-image: url("assets/progressbar-horizontal-fill-backdrop.png") 5 6 5 6 / 5px 6px 5px 6px stretch;
}

.progressbar.vertical:backdrop,
progressbar.vertical:backdrop trough progress {
    border-image: url("assets/progressbar-vertical-fill-backdrop.png") 6 5 6 5 / 6px 5px 6px 5px stretch;
}
*/

scale trough {
    border-image: -gtk-scaled(url("assets/scale-horizontal-trough.png"),url("assets/scale-horizontal-trough@2.png")) 2 6 2 6 / 2px 6px 2px 6px stretch;
}

scale:disabled trough {
    border-image: -gtk-scaled(url("assets/scale-horizontal-trough-disabled.png"),url("assets/scale-horizontal-trough-disabled@2.png")) 2 6 2 6 / 2px 6px 2px 6px stretch;
}

scale:backdrop trough {
    border-image: -gtk-scaled(url("assets/scale-horizontal-trough-backdrop.png"),url("assets/scale-horizontal-trough-backdrop@2.png")) 2 6 2 6 / 2px 6px 2px 6px stretch;
}

scale.vertical trough {
    border-image: -gtk-scaled(url("assets/scale-vertical-trough.png"),url("assets/scale-vertical-trough@2.png")) 6 2 6 2 / 6px 2px 6px 2px stretch;
}

scale.vertical:disabled trough {
    border-image: -gtk-scaled(url("assets/scale-vertical-trough-disabled.png"),url("assets/scale-vertical-trough-disabled@2.png")) 6 2 6 2 / 6px 2px 6px 2px stretch;
}

scale trough.highlight.left {
    border-image: -gtk-scaled(url("assets/scale-horizontal-fill.png"),url("assets/scale-horizontal-fill@2.png")) 2 6 2 6 / 2px 6px 2px 6px stretch;
}

scale.vertical:backdrop trough {
    border-image: -gtk-scaled(url("assets/scale-vertical-trough-backdrop.png"),url("assets/scale-vertical-trough-backdrop@2.png")) 6 2 6 2 / 6px 2px 6px 2px stretch;
}

scale:backdrop trough.highlight.left {
    border-image: -gtk-scaled(url("assets/scale-horizontal-fill-disabled.png"),url("assets/scale-horizontal-fill-disabled@2.png")) 2 6 2 6 / 2px 6px 2px 6px stretch;
}

scale:backdrop trough.highlight.left {
    border-image: -gtk-scaled(url("assets/scale-horizontal-fill-backdrop.png"),url("assets/scale-horizontal-fill-backdrop@2.png")) 2 6 2 6 / 2px 6px 2px 6px stretch;
}

scale.vertical trough.highlight.bottom {
    border-image: -gtk-scaled(url("assets/scale-vertical-fill.png"),url("assets/scale-vertical-fill@2.png")) 6 2 6 2 / 6px 2px 6px 2px stretch;
}

scale.vertical:disabled trough.highlight.bottom {
    border-image: -gtk-scaled(url("assets/scale-vertical-fill-disabled.png"),url("assets/scale-vertical-fill-disabled@2.png")) 6 2 6 2 / 6px 2px 6px 2px stretch;
}

scale.vertical:backdrop trough.highlight.bottom {
    border-image: -gtk-scaled(url("assets/scale-vertical-fill-backdrop.png"),url("assets/scale-vertical-fill-backdrop@2.png")) 6 2 6 2 / 6px 2px 6px 2px stretch;
}

