@define-color notebook_tab_gradient_b shade (@bg_color, 0.98);

GeditWindow .pane-separator,
GeditWindow .pane-separator:hover {
}

GeditPanel.title GtkLabel {
}

GeditDocumentsPanel .view {
}

GeditDocumentsPanel .view:backdrop {
}

GeditWindow .notebook {
    padding: 1px;
    border-radius: 1px;
}

GeditPanel .notebook {
    border-radius: 1px;
}

GeditPanel .notebook tab,
GeditWindow .notebook tab {
    border-radius: 3px;
}

GeditViewFrame .gedit-search-slider {
    background-color: @theme_base_color;
    padding: 6px;
    border-color: shade (@notebook_tab_gradient_b, 0.80);
    border-radius: 0 0 3px 3px;
    border-width: 0 1px 1px 1px;
    border-style: solid;
}

GeditViewFrame .gedit-search-slider .not-found {
    color: @error_fg_color;
    background-image: none;
    background-color: @error_bg_color;
}

GeditViewFrame .gedit-search-slider .not-found:selected {
    background-color: @theme_selected_bg_color;
    color: @theme_selected_fg_color;
}

GeditFileBrowserWidget .toolbar  {
    background-color: @theme_bg_color;
    border: none;
    padding-bottom: 3px;
}

.gedit-search-entry-occurrences-tag {
    background-color: transparent;
    color: @backdrop_text_color;
    margin: 2px;
    padding: 2px;
}
