########################################################################
# Radio buttons 
########################################################################

style "radio_button"
{
### Radio ###
	engine "pixmap" 
	{
		## Normal
		image 	{
			function = CHECK
			state = NORMAL
			shadow = OUT
			overlay_file = "images/radio.png"
			overlay_stretch = FALSE	}

		image 	{
			function = CHECK
			state = NORMAL
			shadow = IN
			overlay_file = "images/radio-pressed.png"
			overlay_stretch = FALSE	}
		
		image 	{
			function = OPTION
			state = NORMAL
			shadow = OUT
			overlay_file = "images/radio.png"
			overlay_stretch = FALSE	}

		image 	{
			function = OPTION
			state = NORMAL
			shadow = IN
			overlay_file = "images/radio-pressed.png"
			overlay_stretch = FALSE	}
		
		## Prelight
		image 	{
			function = CHECK
			state = PRELIGHT
			shadow = OUT
			overlay_file = "images/radio-sel.png"
			overlay_stretch = FALSE	}

		image 	{
			function = CHECK
			state = PRELIGHT
			shadow = IN
			overlay_file = "images/radio-pressed-sel.png"
			overlay_stretch = FALSE	}
		
		image 	{
			function = OPTION
			state = PRELIGHT
			shadow = OUT
			overlay_file = "images/radio-sel.png"
			overlay_stretch = FALSE	}

		image 	{
			function = OPTION
			state = PRELIGHT
			shadow = IN
			overlay_file = "images/radio-pressed-sel.png"
			overlay_stretch = FALSE	}
		
		## Insensitive
		image 	{
			function = CHECK
			state = INSENSITIVE
			shadow = OUT
			overlay_file = "images/radio-ins.png"
			overlay_stretch = FALSE	}

		image 	{
			function = CHECK
			state = INSENSITIVE
			shadow = IN
			overlay_file = "images/radio-pressed-ins.png"
			overlay_stretch = FALSE	}
		
		image 	{
			function = OPTION
			state = INSENSITIVE
			shadow = OUT
			overlay_file = "images/radio-ins.png"
			overlay_stretch = FALSE	}

		image 	{
			function = OPTION
			state = INSENSITIVE
			shadow = IN
			overlay_file = "images/radio-pressed-ins.png"
			overlay_stretch = FALSE	}
		
		## Active
		image 	{
			function = CHECK
			state = ACTIVE
			shadow = OUT
			overlay_file = "images/radio-active.png"
			overlay_stretch = FALSE	}

		image 	{
			function = CHECK
			state = ACTIVE
			shadow = IN
			overlay_file = "images/radio-pressed-active.png"
			overlay_stretch = FALSE	}
		
		image 	{
			function = OPTION
			state = ACTIVE
			shadow = OUT
			overlay_file = "images/radio-active.png"
			overlay_stretch = FALSE	}

		image 	{
			function = OPTION
			state = ACTIVE
			shadow = IN
			overlay_file = "images/radio-pressed-active.png"
			overlay_stretch = FALSE	}
	}
}

class "GtkRadio*" style "radio_button"
class "GtkRadioMenuItem*" style "radio_button"

style "radio_button_tree"
{
### Radio button ###	
	engine "pixmap" 
	{
		image 	{
			function = CHECK
			shadow = OUT
			overlay_file = "images/radio.png"
			overlay_stretch = FALSE	}

		image 	{
			function = CHECK
			shadow = IN
			overlay_file = "images/radio-pressed.png"
			overlay_stretch = FALSE	}
		
		image 	{
			function = OPTION
			shadow = OUT
			overlay_file = "images/radio.png"
			overlay_stretch = FALSE	}

		image 	{
			function = OPTION
			shadow = IN
			overlay_file = "images/radio-pressed.png"
			overlay_stretch = FALSE	}
	}
}

class "GtkTreeView*" style "radio_button_tree"

