style "dark"
{
	bg[NORMAL]   = "#e0e0e0"
	bg[PRELIGHT] = shade (1.05, "#e0e0e0")
	bg[SELECTED] = @selected_bg_color
	bg[ACTIVE]   = shade (0.95, "#e0e0e0")
	bg[INSENSITIVE]   = "#e0e0e0"
}

style "menubar" = "dark" {
	# those two lines were added to fix firefox's menubar item text
	bg[SELECTED] = "#8FB2CF"
	fg[SELECTED] = @selected_fg_color

	engine "murrine" {
		textstyle = 1
		text_shade = 1.23
		gradient_shades = {1.0, 1.0, 1.0, 1.0}
		lightborder_shade = 1.0
	}
}

style "menubar_item" = "menu_item" {
	bg[PRELIGHT] = "#8FB2CF"
	fg[PRELIGHT] = @selected_fg_color

	engine "murrine" {
		gradient_shades = {1.00, 1.0, 1.0, 1.0}
#		glowstyle = 5
		border_shades = { 1.0, 1.0 }
		glow_shade = 1.00
		lightborderstyle = 3
		lightborder_shade = 1.2
		roundness = 4
	}
}
