/* NOTES to contributors:
 * use 4 spaces intends, and keep code ALIGNED and ORDERED */

/* default */
* {
    -GtkArrow-arrow-scaling: 0.6;
    -GtkButton-child-displacement-x: 1;
    -GtkButton-child-displacement-y: 1;
    -GtkButton-default-border: 0;
    -GtkButton-image-spacing: 0;
    -GtkButton-interior-focus: true;
    -GtkButton-inner-border: 3;
    -GtkCheckButton-indicator-size: 18;
    -GtkCheckMenuItem-indicator-size: 16;
    -GtkEntry-inner-border: 2;
    -GtkEntry-progress-border: 0;
    -GtkExpander-expander-size: 8;
    -GtkHTML-link-color: @link_color;
    -GtkIMHtml-hyperlink-color: @link_color;
    -GtkMenu-horizontal-padding: 0;
    -GtkMenu-vertical-padding: 5px;
    -GtkMenuBar-internal-padding: 0;
    -GtkMenuItem-arrow-scaling: 0.6;
    -GtkNotebook-tab-overlap: 1;
    -GtkPaned-handle-size: 6;
    -GtkProgressBar-min-horizontal-bar-height: 14;
    -GtkProgressBar-min-vertical-bar-width: 14;
    -GtkRange-trough-border: 0;
    -GtkRange-slider-width: 14;
    -GtkRange-stepper-size: 13;
    -GtkRange-trough-under-steppers: 1;
    -GtkRange-stepper-spacing: 0;
    -GtkScale-trough-border: 0;
    -GtkScrollbar-activate-slider: 1;
    -GtkScrollbar-trough-border: 0;
    -GtkScrollbar-min-slider-length: 31;
    -GtkScrolledWindow-scrollbar-spacing: 0;
    -GtkScrolledWindow-scrollbars-within-bevel: 1;
    -GtkSeparatorMenuItem-horizontal-padding: 0;
    -GtkStatusbar-shadow-type: none;
    -GtkTextView-error-underline-color: @error_color;
    -GtkToolButton-icon-spacing: 6;
    -GtkToolItemGroup-expander-size: 11;
    -GtkToolbar-internal-padding: 0;
    -GtkTreeView-expander-size: 8;
    -GtkTreeView-vertical-separator: 0;
    -GtkWidget-wide-separators: true;
    -GtkWidget-separator-width: 2;
    -GtkWidget-separator-height: 2;
    -GtkWidget-focus-padding: 0;
    -GtkWidget-focus-line-width: 1px;
    -GtkWidget-link-color: @link_color;
    -GtkWidget-visited-link-color: @link_color;
    -GtkWindow-resize-grip-width: 0;
    -GtkWindow-resize-grip-height: 0;
    -WnckTasklist-fade-overlay-rect: 0;

    background-origin: border-box;
    background-clip: padding-box;
    border-width: 1px;

    engine: unico;

    /*-unico-arrow-texture: url("assets/combobox-arrow.png");*/

    -unico-focus-border-color: alpha (@selected_bg_color, 0.5);
    -unico-focus-border-radius: 5;
    -unico-focus-fill-color: alpha (@selected_bg_color, 0.1);
}

GtkWindow {
    color: @fg_color;
}

* {
    /* inherit the color from parent by default */
    color: inherit;
    background-color: @bg_color;
}

GtkWindow:backdrop {
    color: @backdrop_fg_color;
}

/**********
 * states *
 **********/
*:insensitive {
    color: shade (@bg_color, 0.6);
    text-shadow: 0 1px alpha (shade (@bg_color, 1.25), 0.5);
}

*:active {
}

*:active:hover:insensitive {
}

*:active:insensitive {
}

*:hover {
}

*:hover:insensitive {
}

*:selected,
*:selected:focused {
    background-color: alpha (@selected_bg_color, 0.9);

    color: @selected_fg_color;
}

*:selected:backdrop,
*:selected:focused:backdrop {
    background-color: alpha (@backdrop_selected_bg_color, 0.9);

    color: @backdrop_selected_fg_color;
}


/*********
 * arrow *
 *********/
/*.arrow * {
    background-image: url("assets/combobox-arrow.png");
}*/

/*************
 * assistant *
 *************/
GtkAssistant .sidebar .highlight {
    color: @fg_color;
    font: bold;
}

GtkAssistant .sidebar {
    background-color: shade (@bg_color, 0.97);
    border-right-color: shade (@bg_color, 0.8);
    border-radius: 0;
    border-style: solid;
    border-width: 0 1px 0 0;
    padding: 12px;

    color: mix (@fg_color, @bg_color, 0.40);
    text-shadow: 0 1px shade (@bg_color, 1.04);

    box-shadow: inset -1px 0 shade (@bg_color, 0.94);
}

/**************
 * background *
 **************/
.background {
    background-color: @bg_color;
    border-width: 0;
}

/**********
 * button *
 **********/
.button {
    -GtkWidget-focus-line-width: 0;

    padding: 5px 6px;
}

GtkSwitch.slider,
.button {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@button_bg_color, 1.08)),
                                     color-stop (0.5, @button_bg_color),
                                     to (shade (@button_bg_color, 0.94)));

    color: @fg_color;
    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.4);
}

GtkSwitch.slider:backdrop,
.button:backdrop {
    background-image: none;
    background-color: @bg_color;

    color: @backdrop_fg_color;
    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.2);
}

.button:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@button_bg_color, 1.12)),
                                     color-stop (0.5, @button_bg_color),
                                     to (shade (@button_bg_color, 0.96)));
}

.button:hover:backdrop {
    background-image: none;
    background-color: shade (@bg_color, 1.04);
}

.button:insensitive {
    background-image: none;
    background-color: mix (#ebebeb, @bg_color, 0.5);

    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.4);
}

.button:insensitive:backdrop {
    background-image: none;
    background-color: #ebebeb;

    text-shadow: 0 1px alpha (shade (@button_bg_color, 1.25), 0.2);
}

.button:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#cecece),
                                     to (#e8e8e8));
}

.button:active:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#dcdcdc),
                                     to (#f3f3f3));
}

.button:active:insensitive {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#e3e3e3),
                                     to (#f3f3f3));
}

.button:active:insensitive:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (mix (#e3e3e3, @bg_color, 0.5)),
                                     to (mix (#f3f3f3, @bg_color, 0.5)));
}

/* default button */

/*
.button.default {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (mix (shade (@selected_bg_color, 1.16), @bg_color, 0.3)),
                                     to (mix (shade (@selected_bg_color, 0.84), @bg_color, 0.3)));

    text-shadow: 0 1px alpha (shade (@selected_bg_color, 1.26), 0.4);
}

.button.default:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (mix (shade (@selected_bg_color, 1.21), @bg_color, 0.3)),
                                     to (mix (shade (@selected_bg_color, 0.89), @bg_color, 0.3)));
}

.button.default:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (mix (shade (@selected_bg_color, 0.95), @bg_color, 0.3)),
                                     to (mix (shade (@selected_bg_color, 1.05), @bg_color, 0.3)));
}

.button.default:active:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (mix (shade (@selected_bg_color, 1.0), @bg_color, 0.3)),
                                     to (mix (shade (@selected_bg_color, 1.1), @bg_color, 0.3)));
}

.button.default:insensitive {
}
*/
/* Middle button */
.primary-toolbar .linked .entry,
.primary-toolbar .linked .button,
.primary-toolbar .linked .button:active,
.primary-toolbar .linked .button:active:hover,
.primary-toolbar .linked .button:insensitive {
    border-width: 1px;
    border-right-width: 0;

    border-radius: 0;
}

/* Set up shadows and hilights for button visual separation */
.linked .button,
.toolbar .button.raised.linked,
.toolbar .raised.linked .button,
.inline-toolbar.toolbar .button,
.inline-toolbar.toolbar GtkToolButton .button {
    box-shadow: inset -1px 0 shade (@bg_color, 0.84);
}

.linked .button:first-child,
.toolbar .button.raised.linked:first-child,
.toolbar .raised.linked .button:first-child,
.inline-toolbar.toolbar .button:first-child,
.inline-toolbar.toolbar GtkToolButton:first-child .button {
    box-shadow: inset -1px 0 shade (@bg_color, 0.84);
}

.linked .button:last-child,
.toolbar .button.raised.linked:last-child,
.toolbar .raised.linked .button:last-child,
.inline-toolbar.toolbar .button:last-child,
.inline-toolbar.toolbar GtkToolButton:last-child .button {
    /*box-shadow: inset 1px 0 shade (@bg_color, 1.06);*/
}

.linked .button:active,
.toolbar .button.raised.linked:active,
.toolbar .raised.linked .button:active,
.inline-toolbar.toolbar .button:active,
.inline-toolbar.toolbar GtkToolButton .button:active {
    /*box-shadow: inset 1px 0 shade (@bg_color, 0.76);*/
}

.linked .button:insensitive,
.toolbar .button.raised.linked:insensitive,
.toolbar .raised.linked .button:insensitive,
.inline-toolbar.toolbar .button:insensitive,
.inline-toolbar.toolbar GtkToolButton .button:insensitive {
    box-shadow: inset -1px 0 shade (@bg_color, 0.84);
}

.linked .button:backdrop,
.toolbar .button.raised.linked:backdrop,
.toolbar .raised.linked .button:backdrop,
.inline-toolbar.toolbar .button:backdrop,
.inline-toolbar.toolbar GtkToolButton .button:backdrop {
    /*box-shadow: inset -1px 0 @unfocused_borders;*/
}

.linked .button:insensitive:backdrop,
.toolbar .button.raised.linked:insensitive:backdrop,
.toolbar .raised.linked .button:insensitive:backdrop,
.inline-toolbar.toolbar .button:insensitive:backdrop,
.inline-toolbar.toolbar GtkToolButton .button:insensitive:backdrop {
    /*box-shadow: inset -1px 0 @unfocused_insensitive_borders;*/
}


/* Middle button */
.linked .entry,
.linked .button,
.linked .button:active,
.linked .button:active:hover,
.linked .button:focus,
.linked .button:focus:active,
.linked .button:insensitive {
    border-right-width: 0;
    border-left-width: 0;
    border-image-width: 10px 0 10px 0;
    border-radius: 0;
}

/* Leftmost button */
.linked .entry:first-child,
.linked .button:first-child,
.linked .button:active:first-child,
.linked .button:active:hover:first-child,
.linked .button:focus:first-child,
.linked .button:focus:active:first-child,
.linked .button:insensitive:first-child {
    border-width: 1px;
    border-right-width: 0;
    border-image-width: 10px 0 10px 12px;
    border-radius: 8px;
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
}

/* Rightmost button */
.linked .entry:last-child,
.linked .button:last-child,
.linked .button:active:last-child,
.linked .button:active:hover:last-child,
.linked .button:focus:last-child,
.linked .button:focus:active:last-child,
.linked .button:insensitive:last-child {
    border-width: 1px;
    border-left-width: 0;
    border-image-width: 10px 12px 10px 0;
    border-radius: 8px;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}

/* Linked single button */
.linked .entry:only-child,
.linked .button:only-child,
.linked .button:active:only-child,
.linked .button:active:hover:only-child,
.linked .button:focus:only-child,
.linked .button:focus:active:only-child,
.linked .button:insensitive:only-child {
    border-right-width: 1px;
    border-left-width: 1px;
    border-image-width: 10px 12px 10px 12px;
    border-radius: 8px;
}f

/* Set up shadows and hilights for button visual separation */
.primary-toolbar .linked .button,
.primary-toolbar .button.raised.linked,
.primary-toolbar .raised.linked .button {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 1.4),
                inset -1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked .button:first-child,
.primary-toolbar .button.raised.linked:first-child,
.primary-toolbar .raised.linked .button:first-child {
    box-shadow: inset -1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked .button:last-child,
.primary-toolbar .button.raised.linked:last-child,
.primary-toolbar .raised.linked .button:last-child {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 1.4)
}

.primary-toolbar .linked .button:active,
.primary-toolbar .button.raised.linked:active,
.primary-toolbar .raised.linked .button:active {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked .button:insensitive,
.primary-toolbar .button.raised.linked:insensitive,
.primary-toolbar .raised.linked .button:insensitive {
    box-shadow: inset -1px 0 shade (@dark_bg_color, 0.9);
}

.primary-toolbar .linked .button:backdrop:last-child,
.primary-toolbar .button.raised.linked:backdrop:last-child,
.primary-toolbar .raised.linked .button:backdrop:last-child {
    box-shadow: inset 1px 0 shade (@dark_bg_color, 1.2);
}

/*.primary-toolbar .linked .button:insensitive:backdrop,
.primary-toolbar .button.raised.linked:insensitive:backdrop,
.primary-toolbar .raised.linked .button:insensitive:backdrop {
    box-shadow: inset -1px 0 @unfocused_insensitive_borders;
}*/


/* Linked single button */
.primary-toolbar .linked .entry:only-child,
.primary-toolbar .linked .button:only-child,
.primary-toolbar .linked .button:active:only-child,
.primary-toolbar .linked .button:active:hover:only-child,
.primary-toolbar .linked .button:insensitive:only-child {
    border-radius: 8px;
    box-shadow: none;
}

/****************
 * cell and row *
 ****************/
.cell {
    -GtkCheckButton-indicator-size: 16;
    -GtkWidget-focus-line-width: 0;

    background-color: @base_color;
    border-radius: 0;
    border-width: 0;
}

.cell:selected {
}

row:hover {
}

row:insensitive {
}

row:selected {
    background-image: -gtk-gradient (linear, left bottom, left top,
                                     from (shade (@selected_bg_color, 1.06)),
                                     to (shade (@selected_bg_color, 0.94)));
    border-top-color: shade (@selected_bg_color, 0.88);
    border-style: solid;
    border-width: 1px 0 0 0;

    color: @selected_fg_color;
    /*text-shadow: 0 -1px shade (@selected_bg_color, 0.7);*/
}

row:selected:focused {
}

row:selected:backdrop {
    background-image: -gtk-gradient (linear, left bottom, left top,
                                     from (shade (@backdrop_selected_bg_color, 1.06)),
                                     to (shade (@backdrop_selected_bg_color, 0.94)));
    border-top-color: shade (@backdrop_selected_bg_color, 0.9);

    color: @backdrop_selected_fg_color;
    /*text-shadow: 0 -1px shade (@selected_bg_color, 0.7);*/
}

/*******************
 * check and radio *
 *******************/
.check,
.radio,
.check:insensitive,
.radio:insensitive {

    background-color: transparent;
    border-style: none;
    margin: 1px 0;
}

GtkCheckButton:hover,
GtkCheckButton:active:hover,
GtkCheckButton:selected,
GtkCheckButton:selected:focus {
    background-color: transparent;
}

.menu .radio * {
    box-shadow: none;
}

/*****************
 * column-header *
 *****************/
column-header .button,
column-header .button:active {
    border-radius: 0;
    border-width: 0 1px 1px 0;
    border-image: none;
}

column-header .button {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.06)),
                                     to (shade (@bg_color, 1.04)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@bg_color, 0.99)),
                                 to (shade (@bg_color, 0.9))) 1;
    box-shadow: inset -1px 0 shade (@bg_color, 1.1),
                inset 0 -1px shade (@bg_color, 1.1);

    text-shadow: 0 1px alpha (shade (@bg_color, 1.25), 0.4);
}

column-header .button:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.04)),
                                     to (shade (@bg_color, 1.02)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@bg_color, 0.94)),
                                 to (shade (@bg_color, 0.88))) 1;
    box-shadow: inset -1px 0 shade (@bg_color, 1.03),
                inset 0 -1px shade (@bg_color, 1.03);
}

column-header .button:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.13)),
                                     to (shade (@bg_color, 1.08)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@bg_color, 0.99)),
                                 to (shade (@bg_color, 0.9))) 1;
}

column-header .button:hover:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.1)),
                                     to (shade (@bg_color, 1.06)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@bg_color, 0.99)),
                                 to (shade (@bg_color, 0.9))) 1;
}

column-header:nth-child(last) .button {
    border-width: 0 0 1px 0;
}

/****************
 * Content view *
 ****************/
.content-view.view {
    background-color: shade (@bg_color, 1.01);
}

.content-view.view:prelight {
    background-color: shade (@bg_color, 1.03);
}

.content-view.view:selected,
.content-view.view:active {
}

.content-view.view:insensitive {
    background-color: @bg_color;
}

.content-view.view:backdrop {
    background-color: @bg_color;
}

.content-view.view:selected:backdrop {
    background-color: @backdrop_selected_bg_color;
}

GdMainIconView.content-view {
    -GdMainIconView-icon-size: 40;
}

GtkIconView.content-view.check {
    background-color: transparent;
}

GtkIconView.content-view.check:active {
    background-color: transparent;
}

.content-view.view.check,
.content-view.view.check:active {
    background-color: transparent;
}

GtkIconView.content-view.check:prelight,
GtkIconView.content-view.check:insensitive,
GtkIconView.content-view.check:backdrop,
GtkIconView.content-view.check:selected {
    background-color: transparent;
}

/****************
 * drawing area *
 ****************/
/*
GtkDrawingArea {
    background-color: transparent;
}
*/

/*********
 * entry *
 *********/
GtkComboBox.combobox-entry .button,
.entry {
    -GtkWidget-focus-line-width: 0;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@base_color, 0.96)),
                                     to (@base_color));
    padding: 5px 7px;
    color: @text_color;
}

GtkComboBox.combobox-entry .button:backdrop,
.entry:backdrop {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (mix (shade (@base_color, 0.96), @bg_color, 0.5)),
                                     to (mix (@base_color, @bg_color, 0.5)));
    color: @backdrop_text_color;
}

.entry:selected,
.entry:selected:focused {
    background-color: @selected_bg_color;
    color: @selected_fg_color;
}

.entry:focused {
}

GtkComboBox.combobox-entry .button:insensitive,
.entry:insensitive {
    background-color: #f5f5f5;
    background-image: none;
    color: mix (@text_color, @base_color, 0.4);
}

GtkComboBox.combobox-entry .button:insensitive:backdrop,
.entry:insensitive:backdrop {
    background-color: mix (#f5f5f5, @bg_color, 0.5);
    color: mix (@text_color, @base_color, 0.4);
}

.primary-toolbar .entry.progressbar,
.primary-toolbar .entry.progressbar,
.entry.progressbar {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 0.8)),
                                     color-stop (0.1, shade (@selected_bg_color, 0.9)),
                                     to (shade (@selected_bg_color, 1.1)));
    border-width: 0;
    color: @selected_fg_color;
}

/************
 * expander *
 ************/
.expander {
    color: @fg_color;
}

/*********
 * frame *
 *********/
.frame {
    border-radius: 0px;
    border-width: 1px;
    border-style: solid;
    border-color: shade (@bg_color, 0.82);
    border-image: none;
}

.frame:backdrop {
    border-color: shade (@bg_color, 0.88);
}

/************
 * iconview *
 ************/
GtkIconView.view.cell:selected,
GtkIconView.view.cell:selected:focused {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 1.0)),
                                     to (shade (@selected_bg_color, 0.9)));
    border-radius: 5px;
    border-style: solid;
    border-width: 1px;
    border-color: shade (@selected_bg_color, 0.8);
    border-bottom-color: shade (@selected_bg_color, 0.7);
    color: @selected_fg_color;
    box-shadow: inset 1px 0 shade (@selected_bg_color, 1.05),
                inset -1px 0 shade (@selected_bg_color, 1.05),
                inset 0 1px shade (@selected_bg_color, 1.08),
                inset 0 -1px shade (@selected_bg_color, 1.0);
}

.rubberband {
    background-color: alpha (@selected_bg_color, 0.35);
    border-color: @selected_bg_color;
    border-radius: 0;
    border-style: solid;
    border-width: 1px;
}

/*********
 * image *
 *********/
GtkImage,
GtkImage:insensitive {
    background-color: transparent;
}

/***********
 * infobar *
 ***********/
.info {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@info_bg_color, 1.04)),
                                     to (shade (@info_bg_color, 0.96)));
    border-style: solid;
    border-width: 1px;
    color: @info_fg_color;
    border-color: shade (@info_bg_color, 0.8);
    border-bottom-color: shade (@info_bg_color, 0.75);
    box-shadow: inset 1px 0 shade (@info_bg_color, 1.08),
                inset -1px 0 shade (@info_bg_color, 1.08),
                inset 0 1px shade (@info_bg_color, 1.1),
                inset 0 -1px shade (@info_bg_color, 1.04);
}

.warning {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@warning_bg_color, 1.04)),
                                     to (shade (@warning_bg_color, 0.96)));
    border-style: solid;
    border-width: 1px;
    color: @warning_fg_color;
    border-color: shade (@warning_bg_color, 0.8);
    border-bottom-color: shade (@warning_bg_color, 0.75);
    box-shadow: inset 1px 0 shade (@warning_bg_color, 1.08),
                inset -1px 0 shade (@warning_bg_color, 1.08),
                inset 0 1px shade (@warning_bg_color, 1.1),
                inset 0 -1px shade (@warning_bg_color, 1.04);
}

.question {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@question_bg_color, 1.04)),
                                     to (shade (@question_bg_color, 0.96)));
    border-style: solid;
    border-width: 1px;
    color: @question_fg_color;
    border-color: shade (@question_bg_color, 0.8);
    border-bottom-color: shade (@question_bg_color, 0.75);
    box-shadow: inset 1px 0 shade (@question_bg_color, 1.08),
                inset -1px 0 shade (@question_bg_color, 1.08),
                inset 0 1px shade (@question_bg_color, 1.1),
                inset 0 -1px shade (@question_bg_color, 1.04);
}

.error {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@error_bg_color, 1.04)),
                                     to (shade (@error_bg_color, 0.96)));
    border-style: solid;
    border-width: 1px;
    color: @error_fg_color;
    border-color: shade (@error_bg_color, 0.8);
    border-bottom-color: shade (@error_bg_color, 0.75);
    box-shadow: inset 1px 0 shade (@error_bg_color, 1.08),
                inset -1px 0 shade (@error_bg_color, 1.08),
                inset 0 1px shade (@error_bg_color, 1.1),
                inset 0 -1px shade (@error_bg_color, 1.04);
}

/*********
 * label *
 *********/
GtkLabel,
GtkLabel:insensitive {
    background-color: transparent;
}

/********
 * menu *
 ********/
GtkTreeMenu.menu,
.toolbar .primary-toolbar .menu,
GtkMenuToolButton.menu,
.primary-toolbar .button .menu,
.menu {
    background-image: none;
    background-color: @dark_bg_color;
    border-bottom-color: @combobox_color;
    border-left-color:@combobox_color;
    border-right-color: @combobox_color;
    border-top-color: @combobox_color;
    padding: 0;
    border-width: 1px;
    border-style: solid;
    color: @dark_fg_color;
}

.toolbar .menu,
GtkComboBox .menu {
    background-image: none;
    background-color: @bg_color;
    border-bottom-color: shade (@bg_color, 0.66);
    border-left-color: shade (@bg_color, 0.7);
    border-right-color: shade (@bg_color, 0.7);
    border-top-color: shade (@bg_color, 0.8);
    border-style: solid;
    padding: 0;
    color: @fg_color;
}

.menu:selected {
    background-color: @selected_bg_color;
}

.menu.button:hover,
.menu.button:active,
.menu.button:active:insensitive,
.menu.button:insensitive,
.menu.button {
    background-color: shade (@dark_bg_color, 1.08);
    background-image: none;
    border-radius: 0;
    border-style: none;
    border-width: 0px;
}

/***********
 * menubar *
 ***********/
.menubar {
    -GtkWidget-window-dragging: true;
    background-color: @bg_color;
    background-image: none;
    border-width: 0;
    color: @dark_fg_color;
    text-shadow: 0 -1px shade (@dark_bg_color, 0.6);
}

.menubar:backdrop {
    color: @backdrop_dark_fg_color;
    text-shadow: 0 -1px shade (@dark_bg_color, 0.8);
}

/***************
 * menubaritem *
 ***************/
.menubar.menuitem:hover,
.menubar .menuitem:hover {
    border-style: none;
    border-radius: 4px 4px 0 0;
    border-width: 0 0 0 0;
    background-image: none;
    background-color: @selected_bg_color;
    box-shadow: none;
    color: @selected_fg_color;
    text-shadow: 0 -1px shade (@dark_bg_color, 0.7);
}

/************
 * menuitem *
 ************/
.menuitem {
    border-radius: 0;
    border-style: solid;
    border-width: 1px;
    padding: 3px 2px 3px 2px;
    text-shadow: none;
}

.menuitem {
    /*color: @dark_fg_color;*/
}

/* Workaround for lp:949368 */
GtkComboBox .menuitem * {
    color: @fg_color;
}

GtkComboBox .menuitem *:hover {
    color: @selected_fg_color;
}

.menuitem:hover,
.menu .menuitem:hover {
    border-radius: 0px;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 1.1)),
                                     to (shade (@selected_bg_color, 0.9)));
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@selected_bg_color, 0.7)),
                                 to (shade (@selected_bg_color, 0.7))) 1;
    border-image-width: 1px;
    box-shadow: inset 1px 0 shade (@selected_bg_color, 1.02),
                inset -1px 0 shade (@selected_bg_color, 1.02),
                inset 0 1px shade (@selected_bg_color, 1.16),
                inset 0 -1px shade (@selected_bg_color, 0.96);

    color: @selected_fg_color;
    text-shadow: 0 -1px shade (@selected_bg_color, 0.7);
}

.menuitem.check:active,
.menuitem.radio:active {
    color: @fg_color;
}

.menu .menuitem.check:hover,
.menu .menuitem.radio:hover {
    box-shadow: none;
}

GtkTreeMenu.menu .menuitem:insensitive,
GtkTreeMenu.menu .menuitem *:insensitive,
.toolbar .primary-toolbar .menu .menuitem:insensitive,
.toolbar .primary-toolbar .menu .menuitem *:insensitive,
GtkMenuToolButton.menu .menuitem:insensitive,
GtkMenuToolButton.menu .menuitem *:insensitive,
.primary-toolbar .button .menu .menuitem:insensitive,
.primary-toolbar .button .menu .menuitem *:insensitive,
.menuitem:insensitive,
.menuitem *:insensitive {
    color: mix (@dark_fg_color, @dark_bg_color, 0.5);
    text-shadow: 0 -1px shade (@dark_bg_color, 0.6);
}

.toolbar .menu .menuitem:insensitive,
.toolbar .menu .menuitem *:insensitive,
GtkComboBox .menu .menuitem:insensitive,
GtkComboBox .menu .menuitem *:insensitive {
    color: mix (@fg_color, @bg_color, 0.5);
    text-shadow: 0 1px shade (@bg_color, 1.14);
}

.menuitem GtkCalendar,
.menuitem GtkCalendar.button,
.menuitem GtkCalendar.header,
.menuitem GtkCalendar.view {
    background-color: @dark_bg_color;
    background-image: none;
    border-radius: 0;
    border-style: solid;
    border-width: 0;
    padding: 0;
    color: @dark_fg_color;
}

.menuitem GtkCalendar {
    background-color: shade (@dark_bg_color, 1.3);
    background-image: none;
}

.menuitem .entry {
    background-color: shade (@dark_bg_color, 1.3);
    background-image: none;
    color: @dark_fg_color;
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@dark_bg_color, 0.75)),
                                 to (shade (@dark_bg_color, 0.9))) 1;
    border-image-width: 1px;
}

.primary-toolbar GtkScale.trough,
.menuitem GtkScale.trough {
    background-color: @dark_bg_color;
    background-image: none;
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (shade (@dark_bg_color, 0.75)),
                                 to (shade (@dark_bg_color, 1.15))) 1;
    border-image-width: 1px;
}

.menuitem .accelerator {
    color: alpha (@dark_fg_color, 0.5);
}

.menuitem .accelerator:hover {
    color: alpha (@selected_fg_color, 0.8);
}

.menuitem .accelerator:insensitive {
    color: alpha (mix (@dark_fg_color, @dark_bg_color, 0.5), 0.5);
    text-shadow: 0 -1px shade (@dark_bg_color, 0.7);
}

/************
 * notebook *
 ************/
.notebook {
    background-color: shade (@bg_color, 1.02);
    background-image: none;
    border-radius: 3px;
    padding: 2px;
    background-clip: border-box;
    border-color: shade (@bg_color, 0.82);
    border-width: 1px;
    border-style: solid;
}

.notebook tab {
    background-image: none;
    background-color: transparent;
    border-style: solid;
    border-image: -gtk-gradient (linear, left top, left bottom,
                                 from (alpha (shade (@bg_color, 0.9), 0.0)),
                                 to (shade (@bg_color, 0.9))) 1;
    border-image-width: 0 1px;
    border-color: transparent;
    border-width: 0;
    box-shadow: none;
}

.notebook tab:active {
    border-color: shade (@bg_color, 0.82);
    border-style: solid;
    border-width: 1px;
    background-color: shade (@bg_color, 1.02);
    background-image: none;
    color: @fg_color;
}

.notebook tab GtkLabel {
    padding: 1px 1px 2px 1px;
}

.notebook tab {
    color: shade (@bg_color, 0.48);
}

.notebook tab.top:active {
    padding: 3px 7px 1px 7px;
}

.notebook tab.top {
    padding: 2px 5px 0 5px;
}

.notebook tab.right:active {
    padding: 4px 6px 4px 1px;
}

.notebook tab.right {
    padding: 3px 4px 3px 0;
    border-image: -gtk-gradient (linear, right top, left top,
                                 from (alpha (shade (@bg_color, 0.9), 0.0)),
                                 to (shade (@bg_color, 0.9))) 1;
    border-image-width: 1px 0;
}

.notebook tab.bottom:active {
    padding: 1px 7px 4px 7px;
}

.notebook tab.bottom {
    padding: 0 5px 3px 5px;
    border-image: -gtk-gradient (linear, left bottom, left top,
                                 from (alpha (shade (@bg_color, 0.9), 0.0)),
                                 to (shade (@bg_color, 0.9))) 1;
    border-image-width: 0 1px;
}

.notebook tab.left:active {
    padding: 4px 1px 4px 6px;
}

.notebook tab.left {
    padding: 3px 0 3px 4px;
    border-image: -gtk-gradient (linear, left top, right top,
                                 from (alpha (shade (@bg_color, 0.9), 0.0)),
                                 to (shade (@bg_color, 0.9))) 1;
    border-image-width: 1px 0;
}

.notebook tab .button {
    padding: 0;
}

.notebook GtkDrawingArea {
        background-color: shade (@bg_color, 1.02);
}

/******************
 * pane separator *
 ******************/
.sidebar .pane-separator,
.pane-separator {
    background-color: transparent;
    border-color: shade (@bg_color, 0.84);
}

/*************************
 * progressbar and scale *
 *************************/
GtkScale,
GtkProgressBar {
    border-radius: 10px;
    border-width: 0px;
    padding: 1px;
}

.scale.trough {
    margin: 7px 0 6px 0;
}

.scale.trough.vertical {
    margin: 0 7px 0 6px;
}

.menubar .menuitem .scale.highlight.left,
.scale.highlight.left,
.progressbar,
.progressbar row,
.progressbar row:hover,
.progressbar row:selected,
.progressbar row:selected:focused {
    border-radius: 8px;
    border-width: 0px;
    background-image: none;
    background-color: @link_color;
    border-style: solid;
}

.progressbar:backdrop,
.progressbar row:backdrop,
.progressbar row:hover:backdrop,
.progressbar row:selected:backdrop,
.progressbar row:selected:focused:backdrop,
.scale.highlight.bottom:backdrop,
.progressbar.vertical:backdrop {
    border-radius: 8px;
    border-width: 0px;
    background-image: none;
    background-color: @toolbar_final;
}

.scale.highlight.left:insensitive {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 0.95)),
                                     to (shade (@bg_color, 0.85)));
}

.scale.highlight.bottom:insensitive {
    background-image: -gtk-gradient (linear, left top, right top,
                                     from (shade (@bg_color, 0.95)),
                                     to (shade (@bg_color, 0.85)));
}

.trough,
.trough row,
.trough row:hover,
.trough row:selected,
.trough row:selected:focused {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#d1d1d1),
                                     to (#e8e8e8));
    border-style: solid;
    border-width: 1px;
    color: @text_color;
}

.trough.vertical {
    background-image: -gtk-gradient (linear, left top, right top,
                                     from (#d1d1d1),
                                     to (#e8e8e8));
}

/* level bars as used for password quality or remaining power */

GtkLevelBar {
    -GtkLevelBar-min-block-width: 34;
    -GtkLevelBar-min-block-height: 3;
}

GtkLevelBar.vertical {
    -GtkLevelBar-min-block-width: 3;
    -GtkLevelBar-min-block-height: 34;
}

.level-bar.trough {
    padding: 2px;
}

.level-bar.fill-block {
    border-width: 1px;
    border-style: solid;
    border-color: @selected_bg_color;
    background-color: @link_color;
}

.level-bar.indicator-continuous.fill-block {
    padding: 2px;
    border-radius: 2px;
}

.level-bar.fill-block:backdrop,
.level-bar.fill-block.level-high:backdrop,
.level-bar.fill-block.level-low:backdrop {
    background-color: #b0b0b0;
    border-color: #b0b0b0;
    background-image: none;
}


.level-bar.indicator-discrete.fill-block.horizontal {
    margin: 0 1px;
}

.level-bar.indicator-discrete.fill-block.vertical {
    margin: 1px 0;
}

.level-bar.fill-block.level-high {
    border-color: shade(@success_color, 0.85);
    background-image: linear-gradient(to bottom,
                                      shade(@success_color, 1.2),
                                      @success_color 75%,
                                      shade(@success_color, 0.95)
                                      );
}

.level-bar.fill-block.level-low {
    border-color: shade(@warning_bg_color, 0.80);
    background-image: linear-gradient(to bottom,
                                      shade(@warning_bg_color, 1.3),
                                      @warning_bg_color 75%,
                                      shade(@warning_bg_color, 0.90)
                                      );
}

.level-bar.fill-block.empty-fill-block {
    background-color: transparent;
    background-image: none;
    border-color: alpha(@bg_color, 0.1);
}

.level-bar.fill-block.empty-fill-block:backdrop {
    border-color: transparent;
    background-color: transparent;
}

GtkScale {
    -GtkRange-slider-width: 18;
    -GtkRange-trough-border: 0;
    -GtkScale-slider-length: 14;
    -GtkWidget-focus-line-width: 0;
}

GtkScale.vertical {
    -GtkScale-slider-length: 13;
}

.scale.slider {
    background-color: transparent;
}

.scale.trough.highlight {
    background-color: @link_color;
    background-image: none;
}

.scale.trough.highlight:insensitive {
    background-color: #b5b5b5;
    background-image: none;
}

.scale.trough.highlight.left {
    margin: 7px 0 7px 0;
}

.scale.trough.highlight:backdrop {
    background-color: #dcdcdc;
    background-image: none;
}


.scale.trough.highlight.bottom {
    margin: 0 7px 0 7px;
}

GtkScale.mark {
    border-color: shade (@bg_color, 0.8);
}

/**************
 * Scrollbars *
 **************/

.scrollbar {
    -GtkRange-slider-width:     9;
    -GtkRange-stepper-size:     0;
    -GtkRange-stepper-spacing:  0;
    -GtkRange-trough-border:    0;

    -GtkScrollbar-has-backward-stepper: 0;
    -GtkScrollbar-has-forward-stepper: 0;
    
    -GtkScrollbar-min-slider-length: 30;	
}

.scrollbar.trough.vertical {
    border-radius:      0;
	border-width:      0;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.00)),
                                     to (shade (@bg_color, 1.10)));

	-unico-outer-stroke-width: 			0;
	-unico-inner-stroke-width:          0 0 0 0;
	-unico-inner-stroke-gradient: -gtk-gradient (linear, left top, left bottom,
                                           from (shade (@bg_color, 0.96)),
                                           to (shade (@bg_color, 0.96)));    
}

.scrollbar.trough.horizontal {
    border-radius:      0;
	border-width:      0;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 1.00)),
                                     to (shade (@bg_color, 1.10)));

	-unico-outer-stroke-width: 			0;
	-unico-inner-stroke-width:          0 0 0 0;
    -unico-inner-stroke-gradient: -gtk-gradient (linear, left top, left bottom,
                                           from (shade (@base_color, 0.96)),
                                           to (shade (@base_color, 0.96))); 
}

.scrollbar.slider,
.scrollbar.button {
    border-width:              	0;
    border-radius:              10px;
	background-color:         alpha (#000, 0.25);
}

.scrollbar.slider:prelight {
	background-color:         alpha (#000, 0.42);
}

.scrollbar.slider:insensitive {
    -GtkRange-slider-width: 0;
}

.scrollbar.trough:insensitive {
    -GtkRange-trough-border: 3;
}

/* overlay scrollbar */
OsThumb:selected,
OsScrollbar:selected {
    background-color: @selected_bg_color;
}

OsThumb:active,
OsScrollbar:active {
    background-color: shade (@bg_color, 0.6);
}

OsThumb:insensitive,
OsScrollbar:insensitive {
    background-color: shade (@bg_color, 0.85);
}

/*******************
 * scrolled window *
 *******************/
.ubuntu-online-accounts.frame,
GtkScrolledWindow.frame {
    border-top-color: shade (@bg_color, 0.84);
    border-right-color: shade (@bg_color, 0.76);
    border-bottom-color: shade (@bg_color, 0.86);
    border-left-color: shade (@bg_color, 0.76);
    border-radius: 0;
    border-style: solid;
}

.ubuntu-online-accounts.frame {
    border-top-width: 0;
}

/*************
 * separator *
 *************/
.separator {
    border-width: 1px;
    border-style: solid;
    border-image: none;
    border-color: shade (@bg_color, 0.92);
    border-bottom-color: alpha (shade (@bg_color, 1.26), 0.6);
    border-right-color: alpha (shade (@bg_color, 1.26), 0.6);
}

GtkTreeView.view.separator,
GtkTreeView.separator,
.separator,
.separator:hover {
    color: shade (@bg_color, 0.92);
}

.separator.horizontal {
    border-width: 1px 0 1px 0;
}

.separator.vertical {
    border-width: 0 1px 0 1px;
}

GtkComboBox .separator {
    -GtkWidget-wide-separators: true;
    -GtkWidget-horizontal-separator: 0;
    -GtkWidget-vertical-separator: 0;
}

.button .separator,
.button.separator {
    border-color: shade (@button_bg_color, 0.9);
    border-bottom-color: alpha (shade (@bg_color, 1.26), 0.6);
    border-right-color: alpha (shade (@bg_color, 1.26), 0.6);
}

.button .separator:insensitive,
.button.separator:insensitive {
    border-color: shade (@button_insensitive_bg_color, 0.96);
    border-bottom-color: alpha (shade (@bg_color, 1.26), 0.3);
    border-right-color: alpha (shade (@bg_color, 1.26), 0.3);
}

.menuitem.separator {
    -GtkMenuItem-horizontal-padding: 0;
}

GtkTreeMenu .menuitem.separator,
.toolbar .primary-toolbar .menuitem.separator,
GtkMenuToolButton .menuitem.separator,
.primary-toolbar .button .menuitem.separator,
.menuitem.separator {
    border-color: shade (@bg_color, 0.99);
    border-bottom-color: @combobox_color;
    border-right-color: @bg_color;
}

.toolbar .menuitem.separator,
GtkComboBox .menuitem.separator {
    border-color: shade (@bg_color, 0.99);
    border-bottom-color: @combobox_color;
    border-right-color: @bg_color;
}

/***********
 * sidebar *
 ***********/
.sidebar,
.sidebar .view {
}

.sidebar row:selected {
    text-shadow: 0 1px shade (@selected_bg_color, 0.7);
}

.sidebar .frame {
    border-width: 0;
}

/**************
 * spinbutton *
 **************/
.spinbutton.button:active,
.spinbutton.button:insensitive,
.spinbutton.button {
    border-radius: 0;
}

.spinbutton.button:active:nth-child(last),
.spinbutton.button:insensitive:nth-child(last)
.spinbutton.button:nth-child(last),
.spinbutton.button:active:backdrop:nth-child(last),
.spinbutton.button:insensitive:backdrop:nth-child(last),
.spinbutton.button:backdrop:nth-child(last) {
    border-radius: 0 7px 7px 0;
}

.spinbutton.button,
.spinbutton.button:active,
.spinbutton.button:backdrop,
.spinbutton.button:active:backdrop,
.spinbutton.button:hover,
.spinbutton.button:hover:backdrop {
    background-image: none;
    background-color: transparent;
    border-image: none;
    border-width: 0 0 0 1px;
    border-left-color: alpha (shade (@bg_color, 0.6), 0.22);
}

.spinbutton.button:active {
    background-image: -gtk-gradient (radial, center center, 0.0, center center, 0.5,
                                     from (alpha (@selected_bg_color, 0.2)),
                                     to (alpha (@selected_bg_color, 0.0)));
}

.spinbutton.button:insensitive,
.spinbutton.button:insensitive:backdrop {
    border-left-color: alpha (shade (@bg_color, 0.6), 0.18);

    color: shade (@bg_color, 0.66);
}

.spinbutton,
.spinbutton:hover {
    color: @fg_color;
}

/***********
 * spinner *
 ***********/
.menu.spinner,
.primary-toolbar .spinner,
.primary-toolbar .spinner {
    color: @selected_bg_color;
}

.spinner:active {
     transition: 750ms linear loop;
}

/*************
 * statusbar *
 *************/
GtkStatusbar {
}

/**********
 * switch *
 **********/
GtkSwitch {
    border-radius: 8px;
    padding: 0;
}

GtkSwitch.trough {
    border-radius: 8px;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (#cecece),
                                     to (#e8e8e8));

    color: @fg_color;
    text-shadow: 0 1px alpha (shade (@bg_color, 1.25), 0.5);
}

GtkSwitch.trough:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@selected_bg_color, 0.93)),
                                     to (shade (@selected_bg_color, 0.99)));

    color: @selected_fg_color;
    text-shadow: 0 1px shade (@selected_bg_color, 0.7);
}

/* XXX temporary */
GtkSwitch.trough:backdrop,
GtkSwitch.trough:insensitive {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@bg_color, 0.93)),
                                     to (shade (@bg_color, 0.99)));

    color: shade (@bg_color, 0.6);
    text-shadow: 0 1px alpha (shade (@bg_color, 1.25), 0.5);
}

GtkSwitch.slider {
    padding: 1px;
    border-radius: 6px;
    border-style: solid;
}

GtkSwitch.slider:insensitive {
}

/************
 * textview *
 ************/
GtkTextView {
    background-color: @base_color;
}

/***********
 * tooltip *
 ***********/
.tooltip {
    background-image: -gtk-gradient (radial, center 0, 0, center 0, 0.8,
                                     from (alpha (mix (@tooltip_bg_color, #ffffff, 0.2), 0.86)),
                                     to (alpha (@tooltip_bg_color, 0.86)));
    border-color: alpha (#ffffff, 0.2);
    border-radius: 5px;
    border-style: solid;
    border-width: 1px;
    color: @tooltip_fg_color;
}

.tooltip * {
    background-color: transparent;
}

/************
 * treeview *
 ************/
GtkTreeView.dnd {
    border-color: shade (@selected_bg_color, 1.12);
    border-radius: 2px;
    border-width: 1px;
    border-style: solid;
}

GtkTreeView .entry {
    background-image: none;
    /*border-radius: 0;*/
}

GtkTreeView row:nth-child(even){
    /*background-color: @base_color;*/
}

GtkTreeView row:nth-child(odd) {
    /*background-color: shade (@base_color, 0.965);*/
}

/************
 * viewport *
 ************/
GtkViewport.frame {
    border-width: 0;
}
