style "chrome-gtk-frame"
{
    ChromeGtkFrame::frame-color = "#dcdcdc"
    ChromeGtkFrame::inactive-frame-color = "#dcdcdc"

    ChromeGtkFrame::incognito-frame-color = "#dcdcdc"
    ChromeGtkFrame::incognito-inactive-frame-color = "#dcdcdc"
    
    ChromeGtkFrame::scrollbar-trough-color = "#dcdcdc"
    ChromeGtkFrame::scrollbar-slider-normal-color = "#b0b0b0"
    ChromeGtkFrame::scrollbar-slider-prelight-color = "#777777"
    
}

class "ChromeGtkFrame" style "chrome-gtk-frame"
