* {
	-GtkButton-child-displacement-x: 1;
	-GtkButton-child-displacement-y: 1;
	-GtkButton-default-border: 0;
	-GtkButton-image-spacing: 0;
	-GtkButton-interior-focus: true;
	-GtkButton-inner-border: 3;  
	-GtkCheckButton-indicator-size: 16;
	-GtkCheckMenuItem-indicator-size: 14;
	-GtkComboBox-arrow-scaling: 0.5;
	-GtkEntry-inner-border: 2;
	-GtkEntry-progress-border: 0; 
	-GtkExpander-expander-size: 10;   
	-GtkHTML-link-color: @link_color;
	-GtkIMHtml-hyperlink-color: @link_color;
	-GtkMenu-horizontal-padding: 0;
	-GtkMenu-vertical-padding: 0;  
	-GtkMenuItem-arrow-scaling: 0.5;
	-GtkMenuBar-internal-padding: 0;
	-GtkNotebook-tab-overlap: -1;
	-GtkPaned-handle-size: 0;
	-GtkProgressBar-min-horizontal-bar-height: 10;
	-GtkProgressBar-min-vertical-bar-width: 10;
	-GtkRange-trough-border: 1;
	-GtkRange-slider-width: 11;
	-GtkRange-stepper-size: 13;
	-GtkRange-trough-under-steppers: 1;
	-GtkRange-stepper-spacing: 0;
	-GtkScale-trough-border: 0;
	-GtkScale-trough-side-details: 1;
	-GtkScrollbar-activate-slider: 1;
	-GtkScrollbar-trough-border: 0;
	-GtkScrollbar-slider-width: 11;
	-GtkScrollbar-min-slider-length: 30;
	-GtkScrollbar-has-forward-stepper: 0;
	-GtkScrollbar-has-backward-stepper: 0;
	-GtkScrollbar-has-secondary-forward-stepper: 0;
	-GtkScrollbar-has-secondary-backward-stepper: 0;
	-GtkScrolledWindow-scrollbar-spacing: 0;
	-GtkScrolledWindow-scrollbars-within-bevel: 1;
	-GtkSeparatorMenuItem-horizontal-padding: 0;
	-GtkTextView-error-underline-color: @error_color;
	-GtkToolButton-icon-spacing: 6;
	-GtkToolItemGroup-expander-size: 11;
	-GtkToolbar-internal-padding: 0;
	-GtkTreeView-expander-size: 8;
	-GtkTreeView-vertical-separator: 0;
	-GtkWidget-wide-separators: 1;
	-GtkWidget-separator-width: 2;
	-GtkWidget-separator-height: 2;
	-GtkWidget-focus-padding: 0;
	-GtkWidget-focus-line-width: 1;
	-GtkWidget-link-color: @link_color;
	-GtkWidget-visited-link-color: @link_color;
	-GtkWindow-resize-grip-width: 0;
	-GtkWindow-resize-grip-height: 0;
	-WnckTasklist-fade-overlay-rect: 0;

	border-width: 1;
	padding: 1;

	engine: unico;

	-unico-inner-stroke-color: rgba (0, 0, 0, 0);
	-unico-focus-border-color: alpha (#fff, 0.0);
	-unico-focus-border-radius: 2;
	-unico-focus-fill-color: alpha (#fff, 0.0);
	-unico-focus-outer-stroke-color: alpha (#fff, 0.0);
}

/***************
 * Base States *
 ***************/

GtkWindow {
	color: @theme_fg_color;
}

* {
	background-color: @theme_bg_color;
	-unico-inner-stroke-style: none;
	-unico-outer-stroke-style: none;
}

*:hover {
	background-color: shade (@theme_bg_color, 1.02);
	color: @theme_fg_color;
}

*:selected {
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
}

*:selected:focused {
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
}

*:insensitive {
	background-color: @insensitive_bg_color;
	color: @insensitive_fg_color;
	border-color: @insensitive_border_color;
}

*:active {
	background-color: shade (@theme_bg_color, 0.915);
}

.background {
	border-style: none;
	border-width: 0;
	border-radius: 0;
}

.tooltip {
	padding: 4 4;
	border-style: solid;
	border-width: 1;
	border-color: shade (@theme_tooltip_bg_color, 0.80);
	background-color: @theme_tooltip_bg_color;
	color: @theme_tooltip_fg_color;
}

.grip {
	background-color: shade (@inactive_frame_color, 0.93);
}

.rubberband {
	background-color: alpha (@theme_selected_bg_color, 0.35);
	border-color: @theme_selected_bg_color;
	border-style: solid;
	border-width: 1;
	border-radius: 2;
}

.pane-separator {
	border-style: none;
	border-width: 0;
	color: shade (@inactive_frame_color, 0.80);
}

.pane-separator:prelight,
.pane-separator:selected {
	color: @theme_text_color;
}

GtkStatusbar {
	padding: 5;
	color: @theme_fg_color;
	-GtkStatusbar-shadow-type: none;
}

GtkStatusbar .frame {
	border-width: 0;
}
