UnityPanelWidget,
.unity-panel {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.3)),
                                     to (shade (@dark_bg_color, 1.0)));
    border-top-color: shade (@dark_bg_color, 1.4);
    border-style: solid;
    border-width: 1px 0 0 0;

    -unico-border-gradient: none;
}

.unity-panel.menubar,
.unity-panel .menubar {
}

.unity-panel.menuitem,
.unity-panel .menuitem {
    border-width: 1px 1px 0 1px;

    icon-shadow: 0 1px shade (@dark_bg_color, 1.06);
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.5)),
                                     to (shade (@dark_bg_color, 1.02)));

    color: @fg_color;

    -unico-border-gradient: -gtk-gradient (linear, left top, left bottom,
                                           from (shade (@dark_bg_color, 0.98)),
                                           to (shade (@dark_bg_color, 0.88)));
    -unico-inner-stroke-gradient: -gtk-gradient (linear, left top, left bottom,
                                                 from (shade (@dark_bg_color, 1.6)),
                                                 to (shade (@dark_bg_color, 1.06)));
}
