### This file styles Nautilus elementary. nautilus.rc is for Nautilus normal. ###

style "nautilus-window-base" { bg[NORMAL]	= @base_color }

style "nautilus-sidebar" = "murrine-sidebar" {
	GtkTreeView::horizontal_separator = 15
	GtkTreeView::vertical_separator	= 2
}
style "nautilus-sidebar-other" = "nautilus-sidebar" {
	xthickness = 0
	bg[NORMAL] = @bg_color
}
style "nautilus-extra-view" {
	xthickness = 0
	ythickness = 0
	engine "pixmap" {
		image {
			function	= FLAT_BOX
		    	file		= "Nautilus/extra-widget.png"
		    	stretch		= TRUE
		    	border		= { 0, 0, 4, 4 }
			}
		}
}
style "nautilus-statusbar" {
	xthickness = 1
	ythickness = 2

	bg[NORMAL]	= @bg_color
	bg[PRELIGHT]	= @bg_color
	bg[SELECTED]	= @bg_color
	base[SELECTED]	= @base_color
	fg[NORMAL]	= @fg_color
	fg[PRELIGHT]	= @fg_color
	fg[SELECTED]	= @fg_color
	fg[ACTIVE]	= @fg_color
	fg[INSENSITIVE]	= @fg_color

	engine "murrine" {}
}
style "nautilus-scale" {
	ythickness = 0
	xthickness = 4
	GtkRange ::trough-border	= 0
	GtkScale ::trough-side-details	= 0
	engine "pixmap" {
		image {
			function	= BOX
			detail		= "trough"
			file		= "Nautilus/trough.png"
			border		= { 10, 10, 5, 15 }
			}	
		image {
			function	= SLIDER
			overlay_file	= "Nautilus/slider.png"
			overlay_stretch	= FALSE
    			}
  		}
}
style "nautilus-breadcrumbs" {
	fg[NORMAL]	= @fg_color
	fg[PRELIGHT]	= @fg_color
	fg[SELECTED]	= @selected_fg_color
	fg[ACTIVE]	= @fg_color
	fg[INSENSITIVE]	= darker (@bg_color)

	xthickness = 6
	ythickness = 0
	GtkButton::child-displacement-y	= 0
	GtkButton::inner-border		= { 0, 11, 0, 0}
	engine "pixmap" {	
		image {
			function	= BOX
			recolorable	= TRUE
			state		= PRELIGHT
			file		= "Nautilus/breadcrumb_prelight.png"
			border		= { 3, 13, 3, 3 }
			stretch		= TRUE
			}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= NORMAL
			file		= "Nautilus/breadcrumb_normal.png"
			border		= { 3, 13, 3, 3 }
			stretch		= TRUE
			}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= ACTIVE
			file		= "Nautilus/breadcrumb_active.png"
			border		= { 3, 13, 3, 3 }
			stretch		= TRUE
			}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= INSENSITIVE
			file		= "Nautilus/breadcrumb_normal.png"
			border		= { 3, 13, 3, 3 }
			stretch		= TRUE
			}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= SELECTED
			file		= "Nautilus/breadcrumb_active.png"
			border		= { 3, 13, 3, 3 }
			stretch		= TRUE
			}
		}
}

style "nautilus-left-slider" {
	xthickness = 0
	ythickness = 0
	engine "pixmap" {
		image {
			function	= BOX
			file		= "Nautilus/left_slider_normal.png"
			border		= { 3, 3, 3, 3 }
			stretch		= TRUE
			}
		}
}

style "nautilus-right-slider" {	
	xthickness = 0
	ythickness = 0
	engine "pixmap" {
		image {
			function	= BOX
			file		= "Nautilus/right_slider_normal.png"
			border		= { 3, 3, 3, 3 }
			stretch		= TRUE
			}
		}
}
style "nautilus-toolbar" 
{
	xthickness = 1
	ythickness = 1
	bg_pixmap[NORMAL] = "Nautilus/nautilus-toolbar.png"
	engine "pixmap" {
		image {
			function	= BOX
			file		= "Nautilus/nautilus-toolbar.png"
			border		= { 100, 1, 0, 36 }
			stretch		= TRUE
			}
    		}
}

style "Nautilus-icons" {
	stock["gtk-go-back"] 		= { { "stock_back.png", *, *, *}}
	stock["gtk-go-back-rtl"] 	= { { "stock_back.png", *, *, *}}
	stock["gtk-previous"] 		= { { "stock_back.png", *, *, *}}
	stock["gtk-go-forward"] 	= { { "stock_forward.png", *, *, *}}
	stock["gtk-go-forward-rtl"] 	= { { "stock_forward.png", *, *, *}}
	stock["gtk-home"] 		= { { "stock_home.png", *, *, *}}
	stock["gtk-refresh"] 		= { { "stock_refresh.png", *, *, *}}
	stock["gtk-stop"] 		= { { "stock_stop.png", *, *, *}}
	stock["gtk-find"] 		= { { "stock_find.png", *, *, *}}
}
style "toolbuttons" = "murrine-default" {
	GtkWidget::focus-padding = 2 # For nautilus elementary. Setting this in the global settings of the theme causes the Firefox tabs to jump a little bit.
  	xthickness = 1
	ythickness = 2
	engine "pixmap" {
		image {
			function	= BOX
			recolorable	= TRUE
			state		= NORMAL
			file		= "dummy.png"
			border		= { 5, 5, 5, 5 }
			stretch		= TRUE
			}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= PRELIGHT
			file		= "dummy.png"
			border		= { 5, 5, 5, 5 }
			stretch		= TRUE
			}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= ACTIVE
			file		= "dummy.png"
			border		= { 5, 5, 5, 5 }
			stretch		= TRUE
			}  
		image {
			function	= BOX
			recolorable	= TRUE
			state		= INSENSITIVE
			file		= "dummy.png"
			border		= { 5, 5, 5, 5 }
			stretch		= TRUE
			}  
		}
}

style "pixmap-mode-button" {
	engine "pixmap" {	
		image { function = BOX state = PRELIGHT		file = "Nautilus/mode_prelight.png" border = { 3, 13, 3, 3 } stretch = TRUE }
		image { function = BOX state = NORMAL		file = "Nautilus/mode_normal.png"   border = { 3, 13, 3, 3 } stretch = TRUE }
	    	image { function = BOX state = ACTIVE		file = "Nautilus/mode_pressed.png"  border = { 3, 13, 3, 3 } stretch = TRUE }  
		image { function = BOX state = INSENSITIVE	file = "Nautilus/mode_normal.png"   border = { 3, 13, 3, 3 } stretch = TRUE } 
	    	image { function = BOX state = SELECTED		file = "Nautilus/mode_pressed.png"  border = { 3, 13, 3, 3 } stretch = TRUE }
		}
}

widget_class 	"*Nautilus*Toolbar*Button"		style "toolbuttons"
widget 		"Nautilus*Toolbar"			style "nautilus-toolbar"
widget_class 	"*Nautilus*GtkImage*" 			style "Nautilus-icons" # We only want these icons in Nautilus.
widget		"*NautilusNavigationWindow"		style "nautilus-window-base"
widget		"*Nautilus*Splitter"			style "pixmap-sidebar-handle-left"
widget_class	"*Nautilus*View"			style "murrine-thin"
widget_class	"*Nautilus*NautilusSidePane*"		style "nautilus-sidebar"
widget_class	"*Nautilus*NautilusSidePane*Scrolled*"	style "murrine-scrollbar"
widget_class	"*Nautilus*Statusbar*"			style "nautilus-statusbar"
widget_class	"*Nautilus*Scale*"			style "nautilus-scale"

widget_class	"*Nautilus*Notebook"			style "murrine-thin"

widget 		"*ModeButton*"                          style "pixmap-mode-button"
widget "*.nautilus-extra-view-widget" 			style : highest "nautilus-extra-view"
widget_class 	"*NautilusPathBar.*ToggleButton*"	style "nautilus-breadcrumbs" 

widget 		"Nautilus*left_slider*"			style "nautilus-left-slider" 
widget 		"Nautilus*right_slider*"		style "nautilus-right-slider"
