.nautilus-canvas-item {
    border-radius: 5px;
}

.nautilus-canvas-item.dim-label,
.nautilus-list-dim-label {
    color: mix (@theme_fg_color, @theme_bg_color, 0.50);
}

.nautilus-canvas-item.dim-label:selected,
.nautilus-list-dim-label:selected {
    color: mix (@theme_selected_fg_color, @theme_selected_bg_color, 0.20);
}

.nautilus-desktop.nautilus-canvas-item {
    color: @theme_selected_fg_color;
    text-shadow: 1px 1px black;
}

.nautilus-desktop.nautilus-canvas-item:active {
    color: @theme_text_color;
}

.nautilus-desktop.nautilus-canvas-item:selected {
    color: @theme_selected_fg_color;
}

.nautilus-desktop.nautilus-canvas-item:active,
.nautilus-desktop.nautilus-canvas-item:prelight,
.nautilus-desktop.nautilus-canvas-item:selected {
    text-shadow: none;
}

.nautilus-desktop.nautilus-canvas-item:selected:backdrop {
    color: @theme_unfocused_selected_fg_color;
}

.nautilus-circular-button {
  border-radius: 20px;
  outline-radius: 20px;
}

/* Toolbar */

/* Here we use the .button background-image colors from Adwaita, but ligthen them,
 * since is not possible to use lighten () in common css. */
@keyframes needs_attention_keyframes {
    0% {background-image: linear-gradient(to bottom, #fafafa, #ededed 40%,  #e0e0e0); border-color: @borders; }
    /* can't do animation-direction, so holding the color on two keyframes */
    30% {background-image: linear-gradient(to bottom, @theme_base_color); border-color: @theme_fg_color; } 
    90% {background-image: linear-gradient(to bottom, @theme_base_color); border-color: @theme_fg_color; }
    100% {background-image: linear-gradient(to bottom, #fafafa, #ededed 40%,  #e0e0e0); border-color: @borders; }
}
.nautilus-operations-button-needs-attention {
  animation: needs_attention_keyframes 2s ease-in-out;
}
.nautilus-operations-button-needs-attention-multiple {
  animation: needs_attention_keyframes 3s ease-in-out;
  animation-iteration-count: 3;
}

/* Floating status bar */
.floating-bar {
  padding: 2px;
  background-color: @theme_base_color;
  border-width: 1px;
  border-style: solid solid none;
  border-color: @borders;
  border-radius: 3px 3px 0 0;
}

.floating-bar.bottom.left { /* axes left border and border radius */
  border-left-style: none;
  border-top-left-radius: 0;
}
.floating-bar.bottom.right { /* axes right border and border radius */
  border-right-style: none;
  border-top-right-radius: 0;
}

.floating-bar:backdrop {
  background-color: @theme_unfocused_base_color;
  border-color: @unfocused_borders;
}

.floating-bar .button {
    padding: 4px;
}

.search-bar {
    box-shadow: none;
}

@define-color disk_space_unknown #888a85;
@define-color disk_space_used #729fcf;
@define-color disk_space_free #eeeeec;

.disk-space-display {
    border-style: solid;
    border-width: 2px;
}

.disk-space-display.unknown {
    background-color: @disk_space_unknown;
    border-color: shade(@disk_space_unknown, 0.7);
}

.disk-space-display.used {
    background-color: @disk_space_used;
    border-color: shade(@disk_space_used, 0.7);
}

.disk-space-display.free {
    background-color: @disk_space_free;
    border-color: shade(@disk_space_free, 0.7);
}

/* View */
NautilusListView .view {
    border-bottom: 1px solid @theme_bg_color;
}
