/* Fallback Mode Panel */
PanelWidget,
PanelApplet,
PanelToplevel {
    padding: 0;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.15)),
                                     to (shade (@dark_bg_color, 0.95)));

    color: @dark_fg_color;
}

.gnome-panel-menu-bar,
PanelApplet > GtkMenuBar.menubar,
PanelApplet > GtkMenuBar.menubar.menuitem,
PanelMenuBar.menubar,
PanelMenuBar.menubar.menuitem {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.15)),
                                     to (shade (@dark_bg_color, 0.95)));
}

PanelAppletFrame { 
    background-color: @dark_bg_color;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.15)),
                                     to (shade (@dark_bg_color, 0.95)));
}

PanelApplet .button {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.15)),
                                     to (shade (@dark_bg_color, 0.95)));    
    border-color: shade (@dark_bg_color, 0.9);
    border-radius: 0;
    border-width: 0 1px 0 1px;

    text-shadow: none;

    -unico-border-gradient: none;
    -unico-glow-radius: 0;
    -unico-inner-stroke-width: 0px;
    -unico-outer-stroke-width: 0px;
}

PanelApplet .button:prelight:active,
PanelApplet .button:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.7)),
                                     to (shade (@dark_bg_color, 0.8))); 
    border-color: shade (@dark_bg_color, 0.9);
    border-radius: 0;
    border-width: 0 1px 0 1px;

    -unico-border-gradient: none;
    -unico-glow-radius: 0;
    -unico-inner-stroke-width: 0;
    -unico-outer-stroke-width: 0;
}

PanelApplet .button:prelight {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.2)),
                                     to (shade (@dark_bg_color, 1.0))); 
    border-color: shade (@dark_bg_color, 0.9);
    border-radius: 0;
    border-width: 0 1px 0 1px;

    -unico-border-gradient: none;
    -unico-glow-radius: 0;
    -unico-inner-stroke-width: 0;
    -unico-outer-stroke-width: 0;
}

ClockBox {
    text-shadow: 0 1px shade (@dark_bg_color, 1.08);
}

WnckPager, WnckTasklist {
    background-color: @dark_bg_color;
}
