########################################################################
# Entry
########################################################################

style "entry"
{
	GtkWidget::interior_focus = 0
  GtkEntry::inner-border = {1, 1, 1, 1}
	
	engine "pixmap"
	{
### Entry ###
		image
		{
			function = SHADOW
			detail = "entry"
			file = "images/entry.png"
			border = {2, 2, 2, 2}
			stretch	= TRUE
		}
		
### Focus ###
		image
    	{
			function = FOCUS
			detail = "entry"
			file = "images/entry-active.png"
			border = {2, 2, 2, 2}
			stretch	= TRUE
    	}
	}
}

class "GtkEntry*" style "entry"

########################################################################
# Panel
########################################################################

style "theme-panel"
{
	xthickness = 4
	ythickness = 0
	bg_pixmap[NORMAL] = "images/panel-bg.png"

	fg[NORMAL]	= "#000000"
	fg[PRELIGHT]	= "#ffffff"
	fg[ACTIVE]	= "#f5f5f5"
	text[NORMAL]	= "#000000"
	text[PRELIGHT]	= "#ffffff"
	text[ACTIVE]	= "#f5f5f5"
	
	engine "pixmap" {
		image {
			function	= BOX
			recolorable	= TRUE
			state		= NORMAL
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= PRELIGHT
			file		= "images/panel-button-hover.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= ACTIVE
			file		= "images/panel-button-active.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= SELECTED
			file		= "images/panel-button-active.png"
			border		= { 4, 4, 1, 1 }
			stretch		= TRUE
		}
		image {
			function	= BOX
			recolorable	= TRUE
			state		= INSENSITIVE
		}
		image {
			function	= ARROW
			recolorable	= TRUE
			arrow_direction	= DOWN
		}
	}
}

style "theme-panel-light"
{
	xthickness = 1
	ythickness = 0

	fg[NORMAL] = @fg_color
}

style "theme-panel-text"
{
	fg[NORMAL]	= "#000000"
	fg[PRELIGHT]	= "#333333"
	fg[ACTIVE]	= "#f5f5f5"
	text[NORMAL]	= "#f5f5f5"
	text[PRELIGHT]	= "#ffffff"
	text[ACTIVE]	= "#f5f5f5"
}

style "theme-main-menu-text" = "theme-panel-text"
{
	fg[PRELIGHT]	= "#ffffff"
	text[PRELIGHT]	= "#ffffff"
}

style "theme-panel-handle" 
{
	engine "pixmap" {    
		image {
			function = HANDLE
		}    
		image {
			function = HANDLE
		}
	}
}

widget "*PanelWidget*"			style "theme-panel"
widget "*PanelApplet*"			style "theme-panel"
widget "*fast-user-switch*"		style "theme-panel"
widget "*CPUFreq*Applet*"		style "theme-panel"
widget "*indicator-applet*"		style "theme-panel"
class "PanelApp*"			style "theme-panel"
class "PanelToplevel*"			style "theme-panel"
widget_class "*PanelToplevel*"		style "theme-panel"
# widget_class "*notif*"			style "theme-panel"
# widget_class "*Notif*"			style "theme-panel"
widget_class "*Tray*"			style "theme-panel" 
widget_class "*tray*"			style "theme-panel"
widget_class "*computertemp*"		style "theme-panel"
widget_class "*Applet*Tomboy*"		style "theme-panel"
widget_class "*Applet*Netstatus*"	style "theme-panel"

# Fixes for tooltip text in some apps.
widget_class "*Notif*Beagle*"	style "theme-panel-light"
widget_class "*Notif*Brasero*"	style "theme-panel-light"

# XFCE panel theming.
widget "*Xfce*Panel*"	style "theme-panel"
class "*Xfce*Panel*"	style "theme-panel"

# lxpanel and fbpanel
widget "*.tclock.*"		style "theme-panel"
widget "*.taskbar.*"		style "theme-panel"
widget_class "*GtkBgbox*"	style "theme-panel"

# Make sure panel text color doesn't change
widget_class "*Panel*MenuBar*"		style "theme-main-menu-text"
widget_class "*Panel*<GtkMenuBar>*"	style "theme-main-menu-text"
widget "*.clock-applet-button.*"	style "theme-panel-text"
widget "*PanelApplet*"			style "theme-panel-text"

# Hide ugly handle
class "PanelAppletFrame" style:highest "theme-panel-handle"

# The following removes the arrows from the panel

style "panel-arrow-remove" {
engine "pixmap" {
	image {
		function	= ARROW
		recolorable	= TRUE
		overlay_file	= "images/arrow-blank.png"
		overlay_border	= {2,2,2,2}
		overlay_stretch	= FALSE
		arrow_direction	= UP
		}
	image {
		function	= ARROW
		recolorable	= TRUE
		overlay_file	= "images/arrow-blank.png"
		overlay_border	= {2,2,2,2}
		overlay_stretch	= FALSE
		arrow_direction	= DOWN
		}
	}
}

widget_class "*PanelToplevel*" style "panel-arrow-remove"

########################################################################
# Menu
########################################################################

style "dark"
{
	bg[NORMAL]   = "#e0e0e0"
	bg[PRELIGHT] = shade (1.05, "#e0e0e0")
	bg[SELECTED] = @selected_bg_color
	bg[ACTIVE]   = shade (0.95, "#e0e0e0")
	bg[INSENSITIVE]   = "#e0e0e0"
}

style "menubar" = "dark" {
	# those two lines were added to fix firefox's menubar item text
	bg[SELECTED] = "#8FB2CF"
	fg[SELECTED] = @selected_fg_color

	engine "murrine" {
		textstyle = 1
		text_shade = 1.23
		gradient_shades = {1.0, 1.0, 1.0, 1.0}
		lightborder_shade = 1.0
	}
}

style "menubar_item" = "menu_item" {
	bg[PRELIGHT] = "#8FB2CF"
	fg[PRELIGHT] = @selected_fg_color

	engine "murrine" {
		gradient_shades = {1.00, 1.0, 1.0, 1.0}
#		glowstyle = 5
		border_shades = { 1.0, 1.0 }
		glow_shade = 1.00
		lightborderstyle = 3
		lightborder_shade = 1.2
		roundness = 4
	}
}

########################################################################
# Scrollbar
########################################################################

style "default" {

	GtkScrollbar		::has-backward-stepper		= 0  
	GtkScrollbar		::has-forward-stepper		= 1
	GtkScrollbar		::min-slider-length		= 30
	GtkScrollbar		::slider-width			= 9
	GtkScrollbar		::trough-border			= 3
	GtkScrollbar		::activate-slider 		= 0
	GtkScrollbar		::trough-side-details		= 0
	GtkScrollbar		::stepper-size          	= 1
	
	GtkScrolledWindow	::scrollbar-spacing		= 0
	GtkScrolledWindow	::scrollbars-within-bevel	= 1

}

style "scrollbar" {
	bg[SELECTED]	= shade (0.70, @base_color)		# color indicador
	bg[NORMAL]	= shade (0.90, @bg_color)		# color borde indicador

	fg[NORMAL]	= shade (1.00, @base_color)
	fg[PRELIGHT]	= shade (1.00, @base_color)
	fg[ACTIVE]	= shade (1.00, @base_color)
	fg[SELECTED]	= shade (1.00, @base_color)
	fg[INSENSITIVE]	= shade (1.00, @base_color)
	
	engine "murrine" {
        roundness               = 10
        gradient_shades		= {1.0,1.0,1.0,1.0}
        highlight_shade		= 1.0
        glow_shade              = 1.0
        #reliefstyle            = 0
        prelight_shade          = .75
        gradient_colors         = FALSE
        lightborder_shade       = 1.0
        lightborderstyle        = 0
        trough_shades           = {1.05, 1.13}
        border_shades           = {1.32, 1.32}
        contrast                = 0.00
	colorize_scrollbar	= TRUE
	scrollbarstyle = 0
	}
}

style "hscrollbar" {
}

style "vscrollbar" {
}

style "overlay_scrollbar"
{
	bg[SELECTED] = shade (1.0, @selected_bg_color)
	bg[INSENSITIVE] = shade (0.85, @bg_color)
	bg[ACTIVE] = shade (0.6, @bg_color)
}

style "scale" = "button" {
	bg[NORMAL] = @bg_color
	bg[PRELIGHT] = shade (1.06, @bg_color)
	bg[ACTIVE] = shade (0.94, @bg_color)

	engine "murrine" {
		contrast = 0.6
		border_shades = {0.9, 0.8}
		roundness = 5
		lightborder_shade = 1.32
		gradient_shades = {1.1, 1.0, 1.0, 0.8}
		handlestyle = 2
		trough_border_shades = {0.9, 1.4}
		glow_shade = 1.0
#		reliefstyle = 2
#		shadow_shades = { 1.0, 0.9 }
	}
}

########################################################################
# Toolbar
########################################################################

##########################################################################
# Toolbar
##########################################################################

style "toolbar" {
	engine "pixmap"
	{
		image 
		{
	  		function = BOX
			recolorable = TRUE
	  		file = "images/toolbar.png"
	  		border 	= {1,1,1,1}
        	stretch = TRUE
		}
		
		image 
		{
			function = HANDLE
		    overlay_file = "images/handle-horiz.png"
		    overlay_stretch = FALSE
		    orientation	= HORIZONTAL
		}
        	
        image 
        {
			function = HANDLE
		    overlay_file = "images/handle-vert.png"
		    overlay_stretch = FALSE
		    orientation	= VERTICAL
		}
	}
}

class "*Toolbar*" style "toolbar"
class "*Handle*" style "toolbar"
class "*Paned*" style "toolbar"

